export declare type ChartOption = PieChartOption | BarChartOption | LineChartOption | BarLineChartOption;
export interface BaseChartOption {
    title?: string;
    height?: string;
    hideLegend?: boolean;
}
export interface PieChartOption extends BaseChartOption {
    type: 'pie';
    title?: string;
}
export interface BarChartOption extends BaseChartOption {
    type: 'bar';
    xTitle?: string;
    yTitle?: string;
    labels: string[];
    datasets: {
        label: string;
        data: number[];
        borderColor?: string;
        backgroundColor?: string;
    }[];
    beginAtZero?: boolean;
    labelWidth?: number;
}
export interface LineChartOption extends BaseChartOption {
    type: 'line';
    xTitle?: string;
    yTitle?: string;
    labels: string[];
    datasets: {
        label: string;
        data: number[];
        borderColor?: string;
        backgroundColor?: string;
    }[];
    beginAtZero?: boolean;
    labelWidth?: number;
}
export interface BarLineChartOption extends BaseChartOption {
    type: 'barline';
    xTitle?: string;
    yTitle?: string;
    yRightTitle?: string;
    labels: string[];
    datasets: {
        type: 'bar' | 'line';
        yAlign?: 'left' | 'right';
        label: string;
        data: number[];
        borderColor?: string;
        backgroundColor?: string;
    }[];
    beginAtZero?: boolean;
    labelWidth?: number;
}
