import { __decorate, __awaiter, __rest } from 'tslib';
import { NgModule, ɵɵdefineInjectable, Injectable, ɵɵinject, EventEmitter, ChangeDetectorRef, Input, Output, ViewChild, Component, ViewEncapsulation, Pipe, ViewChildren, ChangeDetectionStrategy, Directive, TemplateRef, ViewContainerRef } from '@angular/core';
import { DatePipe, CommonModule } from '@angular/common';
import { HttpHeaders, HttpClient, HttpClientModule } from '@angular/common/http';
import { FormGroup, FormControl, Validators, NG_VALIDATORS, NG_ASYNC_VALIDATORS, FormsModule, ReactiveFormsModule } from '@angular/forms';
import { DeviceDetectorService, DeviceDetectorModule } from 'ngx-device-detector';
import { CKEditorModule } from 'ckeditor4-angular';
import { MatFormFieldModule } from '@angular/material/form-field';
import { MatTooltipModule } from '@angular/material/tooltip';
import { MatInputModule } from '@angular/material/input';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatSlideToggleModule } from '@angular/material/slide-toggle';
import { MatSelectModule } from '@angular/material/select';
import { MatRadioModule } from '@angular/material/radio';
import { MatAutocompleteModule, MatAutocompleteTrigger } from '@angular/material/autocomplete';
import { MatIconModule } from '@angular/material/icon';
import { MatMenuModule } from '@angular/material/menu';
import { MatChipsModule } from '@angular/material/chips';
import { MatButtonModule } from '@angular/material/button';
import { MatDialogModule, MatDialog } from '@angular/material/dialog';
import { MatBottomSheetModule, MatBottomSheet } from '@angular/material/bottom-sheet';
import { MatProgressSpinnerModule } from '@angular/material/progress-spinner';
import { timeout, startWith, map } from 'rxjs/operators';
import { v4 } from 'uuid';
import $$1 from 'jquery';
import swal from 'sweetalert2';
import md5 from 'md5';
import XLSX from 'xlsx';
import { saveAs } from 'file-saver';
import 'bootstrap';
import * as hash from 'object-hash';
import hash__default from 'object-hash';
import 'jquery-datetimepicker';
import { Subscription } from 'rxjs';
import * as Chart from 'chart.js';
import { ENTER, COMMA } from '@angular/cdk/keycodes';
import { DomSanitizer } from '@angular/platform-browser';
import moment from 'moment';
import 'daterangepicker';

let MaterialModule = class MaterialModule {
};
MaterialModule = __decorate([
    NgModule({
        imports: [
            MatTooltipModule,
            MatFormFieldModule,
            MatInputModule,
            MatSelectModule,
            MatAutocompleteModule,
            MatCheckboxModule,
            MatSlideToggleModule,
            MatRadioModule,
            MatIconModule,
            MatMenuModule,
            MatChipsModule,
            MatButtonModule,
            MatDialogModule,
            MatBottomSheetModule,
            MatProgressSpinnerModule
        ],
        exports: [
            MatTooltipModule,
            MatFormFieldModule,
            MatInputModule,
            MatSelectModule,
            MatAutocompleteModule,
            MatCheckboxModule,
            MatSlideToggleModule,
            MatRadioModule,
            MatIconModule,
            MatMenuModule,
            MatChipsModule,
            MatButtonModule,
            MatDialogModule,
            MatBottomSheetModule,
            MatProgressSpinnerModule
        ]
    })
], MaterialModule);

let ConfigurationService = class ConfigurationService {
    constructor() {
    }
    setConfig(configurationOption) {
        this.option = configurationOption;
    }
    getApiConfiguration() {
        this.option = this.option || {};
        this.option.api = this.option.api || {};
        this.option.api.host = this.option.api.host || location.origin;
        this.option.api.localStorageKey = this.option.api.localStorageKey || 'a9b9b57f-cfea-49d8-988b-9e96f486b7c4';
        this.option.api.tokenHeaderKey = this.option.api.tokenHeaderKey || 'Token';
        return this.option.api;
    }
    getExcelConfiguration() {
        if (this.option && this.option.excel) {
            return this.option.excel;
        }
        return null;
    }
    getSettingConfiguration() {
        if (this.option && this.option.setting) {
            return this.option.setting;
        }
        return null;
    }
    getGridConfiguration() {
        if (this.option && this.option.grid) {
            return this.option.grid;
        }
        return null;
    }
    getTranslateConfiguration() {
        var _a;
        return (_a = this.option) === null || _a === void 0 ? void 0 : _a.translate;
    }
};
ConfigurationService.ɵprov = ɵɵdefineInjectable({ factory: function ConfigurationService_Factory() { return new ConfigurationService(); }, token: ConfigurationService, providedIn: "root" });
ConfigurationService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ConfigurationService);

let TranslateService = class TranslateService {
    constructor(configurationService) {
        var _a, _b;
        this.configurationService = configurationService;
        this.undeclaredLanguage = {};
        this.dictionary = {};
        this.translate = (keyWord, language) => {
            var _a;
            keyWord = keyWord.toString().trim();
            language = language || this.currentLanguage;
            if (!keyWord || !language) {
                return keyWord;
            }
            if (!((_a = this.dictionary[language]) === null || _a === void 0 ? void 0 : _a[keyWord])) {
                if (!this.undeclaredLanguage[keyWord]) {
                    this.undeclaredLanguage[keyWord] = true;
                }
                return keyWord;
            }
            return this.dictionary[language][keyWord];
        };
        this.setDictionary = (language, keyWord, value) => {
            if (!this.dictionary[language]) {
                this.dictionary[language] = {
                    [keyWord]: value
                };
            }
            else {
                this.dictionary[language][keyWord] = value;
            }
        };
        this.setDictionaries = (language, dictionary) => {
            this.dictionary[language] = dictionary;
        };
        this.setDefaultLanguage = (language) => {
            this.currentLanguage = language;
        };
        this.getUndeclaredLanguage = () => this.undeclaredLanguage;
        const translateConfiguration = this.configurationService.getTranslateConfiguration();
        if (translateConfiguration) {
            this.currentLanguage = translateConfiguration.defaultLanguage;
            this.dictionary = ((_b = (_a = translateConfiguration).initializeDictionary) === null || _b === void 0 ? void 0 : _b.call(_a)) || {};
        }
    }
};
TranslateService.ctorParameters = () => [
    { type: ConfigurationService }
];
TranslateService = __decorate([
    Injectable()
], TranslateService);

let NotifyService = class NotifyService {
    constructor(translateService) {
        this.translateService = translateService;
        this.notifyId = 'N' + v4();
        this.alert = {
            success: (message) => {
                swal.fire({
                    icon: 'success',
                    title: this.translateService.translate('Success'),
                    html: message || 'Done!'
                });
            },
            warning: (message) => {
                swal.fire({
                    icon: 'warning',
                    title: this.translateService.translate('Warning'),
                    html: message || 'Something went wrong!'
                });
            },
            error: (message) => {
                swal.fire({
                    icon: 'error',
                    title: this.translateService.translate('Error'),
                    html: message || 'Something went wrong!'
                });
            },
            image: (imageUrl, imageWidth, imageHeight, option = {}) => {
                swal.fire({
                    title: option.title,
                    html: option.message,
                    imageUrl,
                    imageWidth,
                    imageHeight,
                });
            }
        };
        this.notify = {
            success: (message, delay) => {
                // tslint:disable-next-line: max-line-length
                const style = `border-radius: 5px; margin: 0; padding: 12px; z-index: 99999; top: 5px; right: 5px; display: none; position: fixed;color: #4F8A10; background-color: #DFF2BF`;
                // tslint:disable-next-line: max-line-length
                const html = `<div id="${this.notifyId}" style="${style}"><i class="fa fa-check"></i> ${message || this.translateService.translate('Success')}</div>`;
                this.showNotify(html, delay);
            },
            warning: (message, delay) => {
                // tslint:disable-next-line: max-line-length
                const style = `border-radius: 5px; margin: 0; padding: 12px; z-index: 99999; top: 5px; right: 5px; display: none; position: fixed;color: #9F6000; background-color: #FEEFB3`;
                // tslint:disable-next-line: max-line-length
                const html = `<div id="${this.notifyId}" style="${style}"><i class="fa fa-exclamation-triangle"></i> ${message || this.translateService.translate('Warning')}</div>`;
                this.showNotify(html, delay);
            },
            error: (message, delay) => {
                // tslint:disable-next-line: max-line-length
                const style = `border-radius: 5px; margin: 0; padding: 12px; z-index: 99999; top: 5px; right: 5px; display: none; position: fixed;color: #D8000C; background-color: #FFD2D2`;
                // tslint:disable-next-line: max-line-length
                const html = `<div id="${this.notifyId}" style="${style}"><i class="fa fa-times"></i> ${message || this.translateService.translate('Error')}</div>`;
                this.showNotify(html, delay);
            }
        };
        this.confirmDelete = () => this.confirm(this.translateService.translate('Delete record(s)'));
        this.confirmApprove = () => this.confirm(this.translateService.translate('Approve record(s)'));
        this.confirmWithInput = (title, option = {}) => {
            return new Promise(resolve => {
                swal.fire({
                    title,
                    input: 'textarea',
                    inputPlaceholder: 'Tối đa 225 ký tự...',
                    inputAttributes: {
                        'aria-label': 'Tối đa 225 ký tự'
                    },
                    showCancelButton: true,
                    confirmButtonColor: '#3085d6',
                    cancelButtonColor: '#adadad',
                    confirmButtonText: option.yesTitle || this.translateService.translate('Yes'),
                    cancelButtonText: option.noTitle || this.translateService.translate('No'),
                    reverseButtons: true,
                    inputValidator: (value) => {
                        var _a;
                        if (!value || ((_a = value) === null || _a === void 0 ? void 0 : _a.length) > 255) {
                            return 'Vui lòng nhập lý do tối đa 255 ký tự!';
                        }
                    },
                    allowOutsideClick: () => false
                }).then((result) => {
                    if (result.value) {
                        resolve(result.value);
                    }
                });
            });
        };
    }
    confirm(message, option = {}) {
        return new Promise(resolve => {
            swal.fire({
                title: option.title || this.translateService.translate('Confirm'),
                html: message,
                icon: 'question',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#adadad',
                confirmButtonText: option.yesTitle || this.translateService.translate('Yes'),
                cancelButtonText: option.noTitle || this.translateService.translate('No'),
                reverseButtons: true
            }).then(result => {
                if (result.value) {
                    resolve();
                }
            });
        });
    }
    showNotify(html, delay) {
        if ($$1(`#${this.notifyId}`).length === 0) {
            $$1('body').append(html);
            const element = $$1(`#${this.notifyId}`);
            element.slideDown(200);
            setTimeout(() => {
                $$1('body').children(`#${this.notifyId}`).remove();
            }, delay || 5000);
        }
    }
};
NotifyService.ctorParameters = () => [
    { type: TranslateService }
];
NotifyService.ɵprov = ɵɵdefineInjectable({ factory: function NotifyService_Factory() { return new NotifyService(ɵɵinject(TranslateService)); }, token: NotifyService, providedIn: "root" });
NotifyService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], NotifyService);

let ApiService = class ApiService {
    constructor(httpClient, notifyService, configurationService, translateService) {
        this.httpClient = httpClient;
        this.notifyService = notifyService;
        this.configurationService = configurationService;
        this.translateService = translateService;
        this.uploadId = 'U' + v4();
        this.init = () => {
            const apiConfiguration = this.configurationService.getApiConfiguration();
            this.host = apiConfiguration.host;
            this.tokenHeaderKey = apiConfiguration.tokenHeaderKey;
            this.setCustomHeader = apiConfiguration.setCustomHeader;
            this.beforeRemote = apiConfiguration.beforeRemote;
            this.afterRemote = apiConfiguration.afterRemote;
        };
        this.uploadSingle = (url, option) => {
            return new Promise((resolve, reject) => {
                if ($$1(`#${this.uploadId}`).length) {
                    $$1('body').children(`#${this.uploadId}`).remove();
                }
                $$1('body').append(`<input id="${this.uploadId}" style="display: none" type="file" />`);
                $$1(`#${this.uploadId}`).on('change', (evt) => {
                    try {
                        const target = evt.target;
                        const fileToUpload = target.files.item(0);
                        this.upload(url, fileToUpload, option).then(resolve).catch(reject);
                    }
                    catch (error) {
                        reject(error);
                    }
                });
                $$1(`#${this.uploadId}`).trigger('click');
            });
        };
        this.upload = (url, file, option) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            const { translate } = this.translateService;
            const lastDot = file.name.lastIndexOf('.');
            if (lastDot === -1) {
                const message = this.translateService.translate(`Invalid file extension`);
                this.notifyService.notify.warning(message);
                throw new Error(message);
            }
            const extension = file.name.substring(lastDot + 1);
            if (option) {
                if (((_a = option.extensions) === null || _a === void 0 ? void 0 : _a.length) && !option.extensions.some(e => e.toUpperCase() === extension.toUpperCase())) {
                    const message = `[${file.name}] ${translate('Uploaded file is not match extension')} ${option.extensions.join(', ')}`;
                    this.notifyService.notify.warning(message);
                    throw new Error(message);
                }
                if (option.maxSizeInMb > 0 && option.maxSizeInMb * 1024 * 1024 < file.size) {
                    const message = `[${file.name}] ${translate('Max file size')} ${option.maxSizeInMb} Mbs`;
                    this.notifyService.notify.warning(message);
                    throw new Error(message);
                }
                if (option.validator && option.validator(file.name)) {
                    const message = option.validator(file.name);
                    this.notifyService.notify.warning(message);
                    throw new Error(message);
                }
            }
            const formData = new FormData();
            formData.append('file', file, file.name);
            return yield this.post(url, formData, this.defaultHeader);
        });
        this.setTokenHeaderValue = (tokenHeaderValue) => {
            localStorage.setItem(this.key, JSON.stringify({ tokenHeaderValue }));
        };
        this.getTokenHeaderValue = () => {
            return this.token;
        };
    }
    get key() {
        var _a;
        const apiConfiguration = this.configurationService.getApiConfiguration();
        return ((_a = apiConfiguration) === null || _a === void 0 ? void 0 : _a.localStorageKey) || 'a9b9b57f-cfea-49d8-988b-9e96f486b7c4';
    }
    get token() {
        try {
            const { tokenHeaderValue } = JSON.parse(localStorage.getItem(this.key));
            return tokenHeaderValue;
        }
        catch (err) {
            return '';
        }
    }
    get defaultHeader() {
        let httpHeaders = new HttpHeaders();
        if (this.tokenHeaderKey) {
            httpHeaders = httpHeaders.set(this.tokenHeaderKey, this.token);
        }
        return httpHeaders;
    }
    get headers() {
        if (this.setCustomHeader) {
            return this.setCustomHeader(this.defaultHeader);
        }
        return this.defaultHeader;
    }
    post(url, body, headers) {
        this.init();
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        headers = headers || this.headers;
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'POST',
                headers,
                body
            });
        }
        return new Promise((resolve, reject) => {
            this.httpClient.post(encodeURI(url), body, {
                observe: 'response',
                headers
            }).pipe(timeout(600000)).toPromise().then(result => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'POST',
                        headers,
                        body,
                        statusCode: result.status,
                        result: result.body
                    });
                }
                if (result.ok) {
                    resolve(result.body);
                }
                else {
                    reject(result.body);
                }
            }).catch((httpErrorResponse) => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'POST',
                        headers,
                        body,
                        statusCode: httpErrorResponse.status,
                        result: httpErrorResponse.error
                    });
                }
                reject(httpErrorResponse);
            });
        });
    }
    put(url, body, headers) {
        this.init();
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        headers = headers || this.headers;
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'PUT',
                headers,
                body
            });
        }
        return new Promise((resolve, reject) => {
            this.httpClient.put(encodeURI(url), body, {
                observe: 'response',
                headers
            }).pipe(timeout(600000)).toPromise().then(result => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'PUT',
                        headers,
                        body,
                        statusCode: result.status,
                        result: result.body
                    });
                }
                if (result.ok) {
                    resolve(result.body);
                }
                else {
                    reject(result.body);
                }
            }).catch((httpErrorResponse) => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'PUT',
                        headers,
                        body,
                        statusCode: httpErrorResponse.status,
                        result: httpErrorResponse.error
                    });
                }
                reject(httpErrorResponse);
            });
        });
    }
    get(url, headers, options) {
        this.init();
        headers = headers || this.headers;
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'GET',
                headers
            });
        }
        return new Promise((resolve, reject) => {
            var _a, _b;
            if (((_a = options) === null || _a === void 0 ? void 0 : _a.responseType) && options.responseType !== 'json') {
                this.httpClient.get(encodeURI(url), { observe: 'body', headers, responseType: (_b = options) === null || _b === void 0 ? void 0 : _b.responseType })
                    .toPromise().then(result => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: null,
                            result
                        });
                    }
                    resolve(result);
                }).catch((httpErrorResponse) => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: httpErrorResponse.status,
                            result: httpErrorResponse.error
                        });
                    }
                    reject(httpErrorResponse.error);
                });
            }
            else {
                this.httpClient.get(encodeURI(url), { observe: 'response', headers }).toPromise().then(result => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: result.status,
                            result: result.body
                        });
                    }
                    if (result.ok) {
                        resolve(result.body);
                    }
                    else {
                        reject(result.body);
                    }
                }).catch((httpErrorResponse) => {
                    if (this.afterRemote) {
                        this.afterRemote({
                            url,
                            method: 'GET',
                            headers,
                            statusCode: httpErrorResponse.status,
                            result: httpErrorResponse.error
                        });
                    }
                    reject(httpErrorResponse.error);
                });
            }
        });
    }
    delete(url, headers) {
        this.init();
        headers = headers || this.headers;
        if (!url.startsWith('http')) {
            url = this.host + url;
        }
        if (this.beforeRemote) {
            this.beforeRemote({
                url,
                method: 'DELETE',
                headers
            });
        }
        return new Promise((resolve, reject) => {
            this.httpClient.delete(encodeURI(url), { observe: 'response', headers }).toPromise().then(result => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'DELETE',
                        headers,
                        statusCode: result.status,
                        result: result.body
                    });
                }
                if (result.ok) {
                    resolve(result.body);
                }
                else {
                    reject(result.body);
                }
            }).catch((httpErrorResponse) => {
                if (this.afterRemote) {
                    this.afterRemote({
                        url,
                        method: 'DELETE',
                        headers,
                        statusCode: httpErrorResponse.status,
                        result: httpErrorResponse.error
                    });
                }
                reject(httpErrorResponse.error);
            });
        });
    }
    get hasTokenHeaderValue() {
        return !!this.token;
    }
    clearToken() {
        localStorage.removeItem(this.key);
    }
    getHost() {
        return this.host;
    }
};
ApiService.ctorParameters = () => [
    { type: HttpClient },
    { type: NotifyService },
    { type: ConfigurationService },
    { type: TranslateService }
];
ApiService.ɵprov = ɵɵdefineInjectable({ factory: function ApiService_Factory() { return new ApiService(ɵɵinject(HttpClient), ɵɵinject(NotifyService), ɵɵinject(ConfigurationService), ɵɵinject(TranslateService)); }, token: ApiService, providedIn: "root" });
ApiService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ApiService);

let UtilityService = class UtilityService {
    constructor(notifyService) {
        this.notifyService = notifyService;
        this.handle = {
            error: (err) => {
                if (typeof (err) === 'string') {
                    this.notifyService.notify.warning(err);
                }
                else if (typeof (err) === 'object') {
                    let message = err.error || err.message || err.ExceptionMessage || err.Message || 'UNKNOWN ERROR';
                    if (typeof (err.json) === 'function') {
                        err = err.json();
                        if (err) {
                            message = err.error || err.message || err.ExceptionMessage || err.Message || 'UNKNOWN ERROR';
                        }
                    }
                    this.notifyService.notify.warning(message);
                }
                else {
                    console.error(err);
                    this.notifyService.notify.warning('UNKNOWN ERROR');
                }
            }
        };
        this.hashMD5 = (key) => md5(key);
        this.arrayToObject = (items, key) => {
            return items.reduce((obj, item) => { obj[item[key]] = item; return obj; }, {});
        };
        this.isUuid = (key) => {
            key = key || '';
            return key.length === 36;
            // const regex = new Regex('[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}');
            // return regex.test(key);
        };
    }
    changeAliasLowerCase(alias) {
        let str = alias || '';
        str = str.toString().toLowerCase();
        str = str.replace(/à|á|ạ|ả|ã|â|ầ|ấ|ậ|ẩ|ẫ|ă|ằ|ắ|ặ|ẳ|ẵ/g, 'a');
        str = str.replace(/è|é|ẹ|ẻ|ẽ|ê|ề|ế|ệ|ể|ễ/g, 'e');
        str = str.replace(/ì|í|ị|ỉ|ĩ/g, 'i');
        str = str.replace(/ò|ó|ọ|ỏ|õ|ô|ồ|ố|ộ|ổ|ỗ|ơ|ờ|ớ|ợ|ở|ỡ/g, 'o');
        str = str.replace(/ù|ú|ụ|ủ|ũ|ư|ừ|ứ|ự|ử|ữ/g, 'u');
        str = str.replace(/ỳ|ý|ỵ|ỷ|ỹ/g, 'y');
        str = str.replace(/đ/g, 'd');
        str = str.replace(/!|@|%|\^|\*|\(|\)|\+|\=|\<|\>|\?|\/|,|\.|\:|\;|\'|\"|\&|\#|\[|\]|~|\$|_|`|-|{|}|\||\\/g, ' ');
        str = str.replace(/ + /g, ' ');
        str = str.trim();
        return str;
    }
};
UtilityService.ctorParameters = () => [
    { type: NotifyService }
];
UtilityService.ɵprov = ɵɵdefineInjectable({ factory: function UtilityService_Factory() { return new UtilityService(ɵɵinject(NotifyService)); }, token: UtilityService, providedIn: "root" });
UtilityService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], UtilityService);

let ExcelService = class ExcelService {
    constructor(configurationService, notifyService) {
        this.configurationService = configurationService;
        this.notifyService = notifyService;
        this.importId = 'I' + v4();
        this.import = () => {
            return new Promise((resolve, reject) => {
                if ($$1(`#${this.importId}`).length) {
                    $$1('body').children(`#${this.importId}`).remove();
                }
                $$1('body').append(`<input id="${this.importId}" style="display: none" type="file" />`);
                $$1(`#${this.importId}`).on('change', (evt) => {
                    try {
                        const target = evt.target;
                        if (target.files.length !== 1) {
                            throw new Error('Cannot use multiple files');
                        }
                        const reader = new FileReader();
                        reader.onload = (e) => {
                            const bstr = e.target.result;
                            const wb = XLSX.read(bstr, { type: 'binary' });
                            const wsname = wb.SheetNames[0];
                            const ws = wb.Sheets[wsname];
                            const lines = (XLSX.utils.sheet_to_json(ws, { header: 1 }));
                            const records = [];
                            const headers = lines[0];
                            lines.splice(0, 1);
                            lines.forEach(line => {
                                const record = {};
                                let hasValue = false;
                                headers.forEach((header, index) => {
                                    record[header] = line[index];
                                    if (line[index] !== undefined && line[index] !== null && line[index].toString()) {
                                        hasValue = true;
                                    }
                                    if (typeof (record[header]) === 'string') {
                                        record[header] = record[header].trim();
                                    }
                                    if (record[header] === '') {
                                        record[header] = null;
                                    }
                                });
                                if (hasValue) {
                                    records.push(record);
                                }
                            });
                            resolve({
                                items: records,
                                file: target.files[0]
                            });
                        };
                        reader.readAsBinaryString(target.files[0]);
                    }
                    catch (error) {
                        reject(error);
                    }
                });
                $$1(`#${this.importId}`).trigger('click');
            });
        };
        this.export = (exportInfo) => {
            /* Worksheet */
            const worksheet = XLSX.utils.json_to_sheet(exportInfo.data, { cellDates: true });
            /* Workbook */
            const workbook = XLSX.utils.book_new();
            /* Add worksheet to workbook */
            XLSX.utils.book_append_sheet(workbook, worksheet, exportInfo.sheetName || 'Default');
            const wbout = XLSX.write(workbook, { bookType: 'xlsx', type: 'binary' });
            const fileName = exportInfo.fileName ? exportInfo.fileName + this.current() : v4() + '.xlsx';
            saveAs(new Blob([this.s2ab(wbout)], { type: 'application/octet-stream' }), fileName);
        };
        this.current = () => {
            const now = new Date();
            const year = now.getFullYear();
            const month = (now.getMonth() + 1).toString().padStart(2, '0');
            const day = now.getDate().toString().padStart(2, '0');
            const hour = now.getHours().toString().padStart(2, '0');
            const minute = now.getMinutes().toString().padStart(2, '0');
            const second = now.getSeconds().toString().padStart(2, '0');
            return `${year}-${month}-${day} ${hour}:${minute}:${second}`;
        };
        this.s2ab = (s) => {
            const buffer = new ArrayBuffer(s.length);
            const view = new Uint8Array(buffer);
            for (let i = 0; i < s.length; ++i) {
                // tslint:disable-next-line: no-bitwise
                view[i] = s.charCodeAt(i) & 0xFF;
            }
            return buffer;
        };
        this.generateExcelTemplate = (excelTemplate) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.generateTemplate(excelTemplate).catch(err => {
                this.notifyService.notify.error(err);
                return {
                    filePath: ''
                };
            });
        });
        this.uploadTemplate = (key, validator) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.uploadTemplate(key, validator);
        });
        this.downloadTemplate = (filePath, fileName) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            yield this.configuration.downloadTemplate(filePath, fileName);
        });
        this.generateExcelDataByTemplate = (filePath, columns, items, fileName) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            const result = yield this.configuration.generateExcelDataByTemplate(filePath, columns, items).catch(err => {
                this.notifyService.notify.error(err);
                return {
                    filePath: ''
                };
            });
            if ((_a = result) === null || _a === void 0 ? void 0 : _a.filePath) {
                yield this.configuration.downloadTemplate(result.filePath, fileName || `${v4()}.xlsx`);
            }
        });
        this.getFiles = (key) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.getFiles(key);
        });
        this.remove = (key, name) => __awaiter(this, void 0, void 0, function* () {
            if (!this.configuration) {
                this.notifyService.notify.warning('Please init excel configuration');
                return;
            }
            return yield this.configuration.remove(key, name);
        });
    }
    get configuration() {
        return this.configurationService.getExcelConfiguration();
    }
};
ExcelService.ctorParameters = () => [
    { type: ConfigurationService },
    { type: NotifyService }
];
ExcelService.ɵprov = ɵɵdefineInjectable({ factory: function ExcelService_Factory() { return new ExcelService(ɵɵinject(ConfigurationService), ɵɵinject(NotifyService)); }, token: ExcelService, providedIn: "root" });
ExcelService = __decorate([
    Injectable({
        providedIn: 'root'
    })
], ExcelService);

let LoadingService = class LoadingService {
    constructor() {
        this.loadingId = 'L' + v4();
        this.progressId = 'P' + v4();
        this.start = (element = 'body') => {
            $$1(element).append(this.loadingNormal);
        };
        this.stop = () => {
            $$1('body').children(`#${this.loadingId}`).remove();
        };
    }
    // Loading
    get loadingNormal() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100vh;width:100vw;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;"><i class="fa fa-5x fa-spinner fa-pulse" style="margin-top:calc(50vh - 2.5rem);margin-left:calc(50vw - 2.5rem)"></i></div>`;
    }
    get loadingSearching() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100%;width:100%;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;background-image:url(../assets/images/loading/searching.gif);background-position:center;background-repeat:no-repeat;"></div>`;
    }
    get loadingRalph() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100%;width:100%;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;background-image:url(../assets/images/loading/ralph.gif);background-position:center;background-repeat:no-repeat;"></div>`;
    }
    get loadingFiveBalls() {
        // tslint:disable-next-line: max-line-length
        return `<div id="${this.loadingId}" style="top:0;left:0;height:100%;width:100%;position:absolute;opacity:0.6;background:#FFFFFF;z-index: 99999;background-image:url(../assets/images/loading/five-balls.gif);background-position:center;background-repeat:no-repeat;"></div>`;
    }
    startProgress(title, current, max) {
        this.max = max;
        let html = `<div id="${this.progressId}" class="modal fade" data-backdrop="static" data-keyboard="false" tabindex="-1" role="dialog" aria-hidden="true" style="padding-top:15%; overflow-y:visible;">
                        <div class="modal-dialog modal-m">
                            <div class="modal-content">
                                <div class="modal-header"><h3 style="margin:0;">${title} (<span id="abcd">${current}</span>/${max})</h3></div>
                            <div class="modal-body">
                                <div class="progress">
                                    <div id="cde" class="progress-bar progress-bar-striped progress-bar-animated" role="progressbar" style="width: ${current / 100}%"></div>
                                </div>
                            </div>
                        </div>
                    </div>`;
        $$1('body').append(html);
        $$1(`#${this.progressId}`).modal('show');
    }
    updateProgress(current) {
        $$1(`#${this.progressId}`).find('#abcd').html(current.toString());
        $$1(`#${this.progressId}`).find('#cde').css('width', `${current * 100 / this.max}%`);
    }
    stopProgress() {
        $$1(`#${this.progressId}`).modal('hide');
        setTimeout(() => {
            $$1(`#${this.progressId}`).remove();
        }, 1000);
    }
};
LoadingService = __decorate([
    Injectable()
], LoadingService);

let InputControlComponent = class InputControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.name = v4();
        this.appearance = 'legacy ';
        this.type = 'text';
        this.step = 0.01;
        this.modelChange = new EventEmitter();
        this.icon = 'fa fa-search';
        // tslint:disable-next-line: no-output-native
        this.click = new EventEmitter();
        this.sdClick = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.sdFocus = new EventEmitter();
        this.keyupEnter = new EventEmitter();
        this.reValidate = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.onFocus = () => {
            this.sdFocus.emit();
        };
        this.blur = () => {
            $(this.control.nativeElement).trigger('blur');
        };
    }
    set model(value) {
        this._model = value;
        this.ref.detectChanges();
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    onChange(value) {
        this._model = value;
        this.modelChange.emit(this._model);
        this.change.emit(this._model);
        this.sdChange.emit(this._model);
    }
    onKeyupEnter() {
        this.keyupEnter.emit(this._model);
    }
    onClick() {
        this.click.emit(this._model);
        this.sdClick.emit(this._model);
    }
};
InputControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], InputControlComponent.prototype, "appearance", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "placeholder", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "step", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "model", null);
__decorate([
    Output()
], InputControlComponent.prototype, "modelChange", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "maxlength", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "pattern", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "icon", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "validator", void 0);
__decorate([
    Input()
], InputControlComponent.prototype, "tooltip", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "click", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "sdClick", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "sdChange", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "sdFocus", void 0);
__decorate([
    Output()
], InputControlComponent.prototype, "keyupEnter", void 0);
__decorate([
    ViewChild('control')
], InputControlComponent.prototype, "control", void 0);
__decorate([
    ViewChild('formModel')
], InputControlComponent.prototype, "formModel", void 0);
InputControlComponent = __decorate([
    Component({
        selector: 'sd-input-control',
        template: "<mat-form-field class=\"sd-form\" [ngClass]=\"{'sd-form-with-information':tooltip}\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input class=\"sd-input\" #formModel=\"ngModel\" [type]=\"type\" [name]=\"name\" #control matInput\r\n    placeholder=\"{{placeholder || label}}\" [ngModel]=\"_model\" (ngModelChange)=\"onChange($event)\"\r\n    (keyup.enter)=\"onKeyupEnter()\" (focus)=\"onFocus()\" [required]=\"required\" [maxlength]=\"maxlength\" [pattern]=\"pattern\"\r\n    [disabled]=\"disabled\" [sdCustomValidator]=\"validator\" autocomplete=\"off\">\r\n  <span class=\"mr-1\" *ngIf=\"maxlength\" matSuffix>{{_model?.length || 0}}/{{maxlength}}</span>\r\n  <i *ngIf=\"click?.observers?.length || sdClick?.observers?.length\" [className]=\"icon\" (click)=\"onClick()\"\r\n    style=\"cursor:pointer\" matSuffix></i>\r\n\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.maxlength\">\r\n    {{'Max length' | sdTranslate}} <strong>{{maxlength}}</strong>\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.pattern\">\r\n    {{'Pattern error' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.customValidator\">\r\n    <strong>{{formModel?.errors?.customValidator}}</strong>\r\n  </mat-error>\r\n</mat-form-field>\r\n<div *ngIf=\"tooltip\" class=\"sd-information\">\r\n  <i class=\"fa fa-info-circle fa-fw\" [matTooltip]=\"_model | inputTooltipPipe:tooltip\" (click)=\"sdTooltip.toggle()\" #sdTooltip=\"matTooltip\"></i>\r\n</div>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}"]
    })
], InputControlComponent);

const defaultGridOption = {
    type: undefined,
    items: [],
    filter: {
        type: 'inline',
        disabled: false
    },
    sortable: true,
    paginate: {
        pageSize: 50,
        pageCount: 5
    },
    exportable: true,
    commands: [],
    columns: []
};

let HandlerLocal = class HandlerLocal {
    constructor(datePipe) {
        this.datePipe = datePipe;
        this.filter = (localItems, filterInfo) => {
            const items = localItems.filter(item => {
                for (const column of filterInfo.columns) {
                    const filterValue = (filterInfo.rawFilter[column.field] || '').toString().trim().toLowerCase();
                    const columnValue = (item[column.field] || '').toString().trim().toLowerCase();
                    if (filterValue) {
                        if (!columnValue) {
                            return false;
                        }
                        if (column.type === 'string') {
                            if (columnValue.indexOf(filterValue) === -1) {
                                return false;
                            }
                        }
                        else if (column.type === 'values' || column.type === 'radio') {
                            if (columnValue !== filterValue) {
                                return false;
                            }
                        }
                        else if (column.type === 'number') {
                            const fValue = +filterValue.replace('>=', '').replace('<=', '').replace('>', '').replace('<', '');
                            const cValue = +columnValue;
                            if (fValue || fValue === 0) {
                                if (!cValue && cValue !== 0) {
                                    return false;
                                }
                                if (filterValue.indexOf('>=') > -1 && cValue < fValue) {
                                    return false;
                                }
                                else if (filterValue.indexOf('<=') > -1 && cValue > fValue) {
                                    return false;
                                }
                                else if (filterValue.indexOf('<') > -1 && cValue >= fValue) {
                                    return false;
                                }
                                else if (filterValue.indexOf('>') > -1 && cValue <= fValue) {
                                    return false;
                                }
                                else if (cValue !== fValue) {
                                    return false;
                                }
                            }
                        }
                        else if (column.type === 'bool') {
                            if (filterValue === '1' && columnValue !== '1' && columnValue !== 'true') {
                                return false;
                            }
                            else if (filterValue === '0' && columnValue !== '0' && columnValue !== 'false') {
                                return false;
                            }
                        }
                        else if (column.type === 'date' || column.type === 'datetime') {
                            const date = this.datePipe.transform(filterValue, 'yyyy/MM/dd');
                            const fromDate = new Date(date);
                            const toDate = new Date(date);
                            toDate.setDate(toDate.getDate() + 1);
                            if (new Date(columnValue).getTime() < fromDate.getTime() || new Date(columnValue).getTime() >= toDate.getTime()) {
                                return false;
                            }
                        }
                    }
                }
                return true;
            });
            // Sort
            if (filterInfo.orderBy && filterInfo.orderDirection) {
                const column = filterInfo.columns.find(e => e.field === filterInfo.orderBy);
                if (column) {
                    const { type, field } = column;
                    items.sort((current, next) => {
                        if (type === 'number') {
                            return (current[field] || 0) - (next[field] || 0);
                        }
                        if (type === 'date' || type === 'datetime' || type === 'time') {
                            const d1 = new Date(current[field] || '').getTime();
                            const d2 = new Date(current[field] || '').getTime();
                            return d1 - d2;
                        }
                        return (current[field] || '') - (next[field] || '');
                    });
                    if (filterInfo.orderDirection === 'DESC') {
                        items.reverse();
                    }
                }
            }
            return {
                items,
                total: items.length
            };
        };
    }
};
HandlerLocal.ctorParameters = () => [
    { type: DatePipe }
];
HandlerLocal.ɵprov = ɵɵdefineInjectable({ factory: function HandlerLocal_Factory() { return new HandlerLocal(ɵɵinject(DatePipe)); }, token: HandlerLocal, providedIn: "root" });
HandlerLocal = __decorate([
    Injectable({
        providedIn: 'root'
    })
], HandlerLocal);

let HandlerDotnet = class HandlerDotnet {
    constructor() {
        this.mapRequest = (filterInfo) => {
            const result = {
                whereClause: '1>0',
                pageSize: filterInfo.pageSize,
                pageNumber: filterInfo.pageNumber,
                orderBy: filterInfo.orderBy,
                orderDirection: filterInfo.orderDirection,
                filter: {}
            };
            if (filterInfo.customFilter) {
                // Nếu custom filter là string
                if (typeof (filterInfo.customFilter) === 'string') {
                    result.whereClause += ` AND ${filterInfo.customFilter}`;
                }
                else if (typeof (filterInfo.customFilter) === 'function') {
                    result.whereClause += ` AND ${filterInfo.customFilter()}`;
                }
            }
            const executeColumnNoChildren = (column) => {
                if (!filterInfo.rawFilter[column.field]) {
                    return;
                }
                result.filter[column.field] = filterInfo.rawFilter[column.field];
                if (column.type === 'string') {
                    const filterValue = filterInfo.rawFilter[column.field].toString();
                    // Kiểm tra có phải Guid ko?
                    if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                        return;
                    }
                    if (this.isGuid(filterInfo.rawFilter[column.field])) {
                        result.whereClause += ` AND ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                    }
                    else if (filterValue.startsWith('!=')) {
                        result.whereClause += ` AND ${column.field} != "${filterValue.substring(2, filterValue.length)}"`;
                    }
                    else if (filterValue.startsWith('=')) {
                        result.whereClause += ` AND ${column.field} = "${filterValue.substring(1, filterValue.length)}"`;
                    }
                    else if (filterValue.startsWith('%')) {
                        result.whereClause += ` AND ${column.field}.EndsWith("${filterValue.substring(1, filterValue.length)}")`;
                    }
                    else if (filterValue.endsWith('%')) {
                        result.whereClause += ` AND ${column.field}.StartsWith("${filterValue.substring(0, filterValue.length - 1)}")`;
                    }
                    else {
                        result.whereClause += ` AND ${column.field}.Contains("${filterValue}")`;
                    }
                }
                else if (column.type === 'number') {
                    const value = +(filterInfo.rawFilter[column.field].replace('>=', '').replace('<=', '').replace('>', '').replace('<', '').trim());
                    if (filterInfo.rawFilter[column.field].indexOf('>=') > -1) {
                        result.whereClause += ` AND ${column.field} >= ${value}`;
                    }
                    else if (filterInfo.rawFilter[column.field].indexOf('<=') > -1) {
                        result.whereClause += ` AND ${column.field} <= ${value}`;
                    }
                    else if (filterInfo.rawFilter[column.field].indexOf('>') > -1) {
                        result.whereClause += ` AND ${column.field} > ${value}`;
                    }
                    else if (filterInfo.rawFilter[column.field].indexOf('<') > -1) {
                        result.whereClause += ` AND ${column.field} < ${value}`;
                    }
                    else {
                        result.whereClause += ` AND ${column.field} = ${value}`;
                    }
                }
                else if (column.type === 'bool') {
                    if (filterInfo.rawFilter[column.field] === '0' || filterInfo.rawFilter[column.field] === '1') {
                        result.whereClause += ` AND ${column.field} = ${filterInfo.rawFilter[column.field] === '1' ? 'true' : 'false'}`;
                    }
                }
                else if (column.type === 'values') {
                    if (filterInfo.rawFilter[column.field]) {
                        // Kiểm tra có phải Guid ko?
                        if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                            return;
                        }
                        if (this.isGuid(filterInfo.rawFilter[column.field])) {
                            result.whereClause += ` AND ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                        }
                        else {
                            result.whereClause += ` AND ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                        }
                    }
                }
                else if (column.type === 'radio') {
                    if (filterInfo.rawFilter[column.field]) {
                        result.whereClause += ` AND ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                    }
                }
                else if (column.type === 'date' || column.type === 'datetime') {
                    // "DateTime(yyyy,mm,dd,HH,mm,ss)"
                    // generate fromDate, toDate
                    let date = new Date(filterInfo.rawFilter[column.field]);
                    // From Date
                    date = new Date(date.getFullYear(), date.getMonth(), date.getDate(), 0, 0, 0);
                    result.whereClause += ` AND ${column.field} >= DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                    // To Date
                    date.setDate(date.getDate() + 1);
                    result.whereClause += ` AND ${column.field} < DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                }
            };
            const executeColumnChildren = (columnChildren) => {
                let flag = false;
                for (const column of columnChildren.children) {
                    if (filterInfo.rawFilter[column.field]) {
                        executeColumnNoChildren(column);
                        flag = true;
                    }
                }
                if (flag) {
                    return;
                }
                if (!filterInfo.rawFilter[columnChildren.field]) {
                    return;
                }
                result.filter[columnChildren.field] = filterInfo.rawFilter[columnChildren.field];
                let whereClause = '';
                for (const column of columnChildren.children) {
                    if (column.type === 'string') {
                        const filterValue = filterInfo.rawFilter[column.field].toString();
                        // Kiểm tra có phải Guid ko?
                        if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                            return;
                        }
                        if (this.isGuid(filterInfo.rawFilter[column.field])) {
                            whereClause += ` OR ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                        }
                        else if (filterValue.startsWith('!=')) {
                            whereClause += ` OR ${column.field} != "${filterValue.substring(2, filterValue.length)}"`;
                        }
                        else if (filterValue.startsWith('=')) {
                            whereClause += ` OR ${column.field} = "${filterValue.substring(1, filterValue.length)}"`;
                        }
                        else if (filterValue.startsWith('%')) {
                            whereClause += ` OR ${column.field}.EndsWith("${filterValue.substring(1, filterValue.length)}")`;
                        }
                        else if (filterValue.endsWith('%')) {
                            whereClause += ` OR ${column.field}.StartsWith("${filterValue.substring(0, filterValue.length - 1)}")`;
                        }
                        else {
                            whereClause += ` OR ${column.field}.Contains("${filterValue}")`;
                        }
                    }
                    else if (column.type === 'number') {
                        const value = +(filterInfo.rawFilter[column.field].replace('>=', '').replace('<=', '').replace('>', '').replace('<', '').trim());
                        if (!Number.isNaN(value)) {
                            if (filterInfo.rawFilter[column.field].indexOf('>=') > -1) {
                                whereClause += ` OR ${column.field} >= ${value}`;
                            }
                            else if (filterInfo.rawFilter[column.field].indexOf('<=') > -1) {
                                whereClause += ` OR ${column.field} <= ${value}`;
                            }
                            else if (filterInfo.rawFilter[column.field].indexOf('>') > -1) {
                                whereClause += ` OR ${column.field} > ${value}`;
                            }
                            else if (filterInfo.rawFilter[column.field].indexOf('<') > -1) {
                                whereClause += ` OR ${column.field} < ${value}`;
                            }
                            else {
                                whereClause += ` OR ${column.field} = ${value}`;
                            }
                        }
                    }
                    else if (column.type === 'bool') {
                        if (filterInfo.rawFilter[column.field] === '0' || filterInfo.rawFilter[column.field] === '1') {
                            whereClause += ` OR ${column.field} = ${filterInfo.rawFilter[column.field] === '1' ? 'true' : 'false'}`;
                        }
                    }
                    else if (column.type === 'values') {
                        if (filterInfo.rawFilter[column.field]) {
                            // Kiểm tra có phải Guid ko?
                            if (column.isGuid && !this.isGuid(filterInfo.rawFilter[column.field])) {
                                return;
                            }
                            if (this.isGuid(filterInfo.rawFilter[column.field])) {
                                whereClause += ` OR ${column.field} = GUID("${filterInfo.rawFilter[column.field]}")`;
                            }
                            else {
                                whereClause += ` OR ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                            }
                        }
                    }
                    else if (column.type === 'radio') {
                        if (filterInfo.rawFilter[column.field]) {
                            whereClause += ` OR ${column.field} = "${filterInfo.rawFilter[column.field]}"`;
                        }
                    }
                    else if (column.type === 'date' || column.type === 'datetime') {
                        // "DateTime(yyyy,mm,dd,HH,mm,ss)"
                        // generate fromDate, toDate
                        let date = new Date(filterInfo.rawFilter[column.field]);
                        // From Date
                        date = new Date(date.getFullYear(), date.getMonth(), date.getDate(), 0, 0, 0);
                        whereClause += ` OR ${column.field} >= DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                        // To Date
                        date.setDate(date.getDate() + 1);
                        whereClause += ` OR ${column.field} < DateTime(${date.getFullYear()},${date.getMonth() + 1},${date.getDate()})`;
                    }
                }
                if (whereClause.trim().startsWith('OR')) {
                    whereClause = whereClause.trim().substr(2);
                    result.whereClause += ` AND(${whereClause})`;
                }
            };
            filterInfo.columns.forEach(column => {
                if (column.type !== 'children') {
                    executeColumnNoChildren(column);
                }
                else {
                    executeColumnChildren(column);
                }
            });
            return result;
        };
        this.mapResponse = (res) => {
            const { items, total } = res;
            return {
                items,
                total
            };
        };
        this.isGuid = (key) => {
            return key.length === 36;
            // const regex = new Regex('[0-9a-fA-F]{8}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{4}\-[0-9a-fA-F]{12}');
            // return regex.test(key);
        };
    }
};
HandlerDotnet.ɵprov = ɵɵdefineInjectable({ factory: function HandlerDotnet_Factory() { return new HandlerDotnet(); }, token: HandlerDotnet, providedIn: "root" });
HandlerDotnet = __decorate([
    Injectable({
        providedIn: 'root'
    })
], HandlerDotnet);

let EditorHandlerPipe = class EditorHandlerPipe {
    transform(value, item, gridOption) {
        const visible = (column) => {
            if (column.type === 'children') {
                return false;
            }
            let isDisabled = false;
            // Kiểm tra xem có bị disabled hay không?
            if (column.editor) {
                isDisabled = typeof (column.editor.disabled) === 'function' ? column.editor.disabled(item) : column.editor.disabled;
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            if (typeof (gridOption.editor) === 'object') {
                if (typeof (gridOption.editor.disabled) === 'function') {
                    isDisabled = gridOption.editor.disabled(item);
                }
                else {
                    isDisabled = gridOption.editor.disabled;
                }
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            // Hiển thị editor nếu dòng đó:
            // Đang được edit: editingStatus
            return item.editingStatus
                // Được thiết lập alwayDisplay
                || (column.editor && column.editor.alwayDisplay)
                // Editable có thuộc tính type inline
                || (gridOption.editor && typeof (gridOption.editor) === 'object' && gridOption.editor.type === 'inline');
        };
        item.editorHandler = item.editorHandler || {};
        for (const column of gridOption.columns) {
            item.editorHandler.disabled = false;
            item.editorHandler[column.field] = {};
            if (typeof (gridOption.editor) === 'object') {
                if (typeof (gridOption.editor.disabled) === 'function') {
                    item.editorHandler.disabled = gridOption.editor.disabled(item);
                }
                else {
                    item.editorHandler.disabled = gridOption.editor.disabled;
                }
            }
            else {
                item.editorHandler.disabled = false;
            }
            if (item.editorHandler.disabled) {
                item.editorHandler[column.field].visible = false;
            }
            else {
                item.editorHandler[column.field].visible = visible(column);
            }
        }
        return true;
    }
};
EditorHandlerPipe = __decorate([
    Pipe({
        name: 'editorHandler'
    })
], EditorHandlerPipe);

let GridImportExcelComponent = class GridImportExcelComponent {
    constructor() { }
    set columns(gridColumns) {
        const columns = [];
        gridColumns.forEach(column => {
            var _a;
            if (column.ignoreImport) {
                return;
            }
            if (column.type === 'string' || column.type === 'color') {
                columns.push({
                    type: 'string',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'number') {
                columns.push({
                    type: 'number',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'bool') {
                columns.push({
                    type: 'bool',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'date') {
                columns.push({
                    type: 'date',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'datetime' || column.type === 'time') {
                columns.push({
                    type: 'datetime',
                    field: column.field,
                    title: column.title,
                    width: column.width
                });
            }
            else if (column.type === 'values') {
                columns.push({
                    type: 'values',
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    values: column.values.map(e => e.value),
                });
            }
            else if (column.type === 'radio') {
                columns.push({
                    type: 'radio',
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    values: column.values.map(e => e[column.valueField])
                });
            }
            if (column.type === 'children' && ((_a = column.children) === null || _a === void 0 ? void 0 : _a.length)) {
                column.children.forEach(childColumn => {
                    if (childColumn.ignoreImport) {
                        return;
                    }
                    if (childColumn.type === 'string' || childColumn.type === 'color') {
                        columns.push({
                            type: 'string',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'number') {
                        columns.push({
                            type: 'number',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'bool') {
                        columns.push({
                            type: 'bool',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'date') {
                        columns.push({
                            type: 'date',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'datetime' || childColumn.type === 'time') {
                        columns.push({
                            type: 'datetime',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width
                        });
                    }
                    else if (childColumn.type === 'values') {
                        columns.push({
                            type: 'values',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width,
                            values: childColumn.values.map(e => e.value),
                        });
                    }
                    else if (childColumn.type === 'radio') {
                        columns.push({
                            type: 'radio',
                            field: childColumn.field,
                            title: childColumn.title,
                            width: childColumn.width,
                            values: childColumn.values.map(e => e[childColumn.valueField])
                        });
                    }
                });
            }
        });
        this.option = {
            key: `GridImport${this.key}`,
            columns,
            onAccept: this.accept
        };
    }
    open() {
        if (this.control) {
            this.control.open();
        }
    }
};
__decorate([
    Input()
], GridImportExcelComponent.prototype, "key", void 0);
__decorate([
    Input()
], GridImportExcelComponent.prototype, "accept", void 0);
__decorate([
    Input()
], GridImportExcelComponent.prototype, "columns", null);
__decorate([
    ViewChild('control')
], GridImportExcelComponent.prototype, "control", void 0);
GridImportExcelComponent = __decorate([
    Component({
        selector: 'sd-grid-import-excel',
        template: "<sd-upload-excel-control *ngIf=\"key && option\" [option]=\"option\" #control></sd-upload-excel-control>",
        styles: [""]
    })
], GridImportExcelComponent);

let GridPopupExportExcelComponent = class GridPopupExportExcelComponent {
    constructor(ref, loadingService, excelService, notifyService, translateService) {
        this.ref = ref;
        this.loadingService = loadingService;
        this.excelService = excelService;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.prefix = 'Popup Export Excel';
        this.key = '';
        this.columns = [];
        this.extendColumns = [];
        this.excelConfigs = [];
        this.exportByTemplate = new EventEmitter();
        this.initDefaultTemplate = () => __awaiter(this, void 0, void 0, function* () {
            const excelColumns = [];
            const extendColumns = this.extendColumns || [];
            const columns = [...this.columns, ...extendColumns];
            for (const column of columns) {
                if (column.type === 'children') {
                    for (const childColumn of column.children) {
                        if (childColumn.type !== 'image') {
                            excelColumns.push({
                                field: childColumn.field,
                                title: childColumn.title,
                                description: childColumn.description,
                                width: childColumn.width
                            });
                        }
                    }
                }
                else if (column.type !== 'image') {
                    excelColumns.push({
                        field: column.field,
                        title: column.title,
                        description: column.description,
                        width: column.width
                    });
                }
            }
            return yield this.excelService.generateExcelTemplate({
                columns: excelColumns
            });
        });
        this.generateTemplate = () => __awaiter(this, void 0, void 0, function* () {
            var _a;
            this.loadingService.start();
            const result = yield this.initDefaultTemplate().finally(this.loadingService.stop);
            if ((_a = result) === null || _a === void 0 ? void 0 : _a.filePath) {
                this.excelService.downloadTemplate(result.filePath, `${this.fullKey}.xlsx`);
            }
        });
        this.onExportByTemplate = (excelConfig) => {
            const excelColumns = [];
            const extendColumns = this.extendColumns || [];
            const columns = [...this.columns, ...extendColumns];
            for (const column of columns) {
                if (column.type === 'children') {
                    for (const childColumn of column.children) {
                        if (childColumn.type !== 'image') {
                            excelColumns.push({
                                field: childColumn.field,
                                title: childColumn.title,
                                description: childColumn.description,
                                width: childColumn.width
                            });
                        }
                    }
                }
                else if (column.type !== 'image') {
                    excelColumns.push({
                        field: column.field,
                        title: column.title,
                        description: column.description,
                        width: column.width
                    });
                }
            }
            this.exportByTemplate.emit({
                excelConfig,
                excelColumns
            });
            this.ref.detectChanges();
        };
        this.uploadTemplate = () => __awaiter(this, void 0, void 0, function* () {
            const excelConfig = yield this.excelService.uploadTemplate(this.fullKey, this.validator);
            this.excelConfigs.push({
                name: excelConfig.name,
                fullPath: excelConfig.fullPath,
                removable: true
            });
            this.ref.detectChanges();
        });
        this.downloadTemplate = (excelConfig) => {
            this.excelService.downloadTemplate(excelConfig.fullPath, excelConfig.name);
        };
        this.removeTemplate = (excelConfig) => {
            this.notifyService.confirm(this.translateService.translate('Remove template')).then(() => __awaiter(this, void 0, void 0, function* () {
                this.loadingService.start();
                yield this.excelService.remove(this.fullKey, excelConfig.name).finally(this.loadingService.stop);
                const idx = this.excelConfigs.indexOf(excelConfig);
                this.excelConfigs.splice(idx, 1);
                this.ref.detectChanges();
            }));
        };
        this.exportDefault = () => __awaiter(this, void 0, void 0, function* () {
            this.loadingService.start();
            const result = yield this.initDefaultTemplate().finally(this.loadingService.stop);
            const excelColumns = [];
            const extendColumns = this.extendColumns || [];
            const columns = [...this.columns, ...extendColumns];
            for (const column of columns) {
                if (column.type === 'children') {
                    for (const childColumn of column.children) {
                        if (childColumn.type !== 'image') {
                            excelColumns.push({
                                field: childColumn.field,
                                title: childColumn.title,
                                width: childColumn.width
                            });
                        }
                    }
                }
                else if (column.type !== 'image') {
                    excelColumns.push({
                        field: column.field,
                        title: column.title,
                        width: column.width
                    });
                }
            }
            this.exportByTemplate.emit({
                excelConfig: {
                    fullPath: result.filePath,
                    name: `[${this.fullKey}] Default.xlsx`
                },
                excelColumns
            });
            this.ref.detectChanges();
        });
    }
    get fullKey() {
        if (!this.key) {
            return '';
        }
        return hash({
            prefix: this.prefix,
            key: this.key
        });
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
    }
    open() {
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.fullKey) {
                yield this.exportDefault();
                return;
            }
            yield this.loadConfiguration();
            this.modal.open();
            this.ref.detectChanges();
        });
    }
    loadConfiguration() {
        return __awaiter(this, void 0, void 0, function* () {
            this.excelConfigs = [];
            this.excelConfigs = yield this.excelService.getFiles(this.fullKey);
        });
    }
};
GridPopupExportExcelComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: LoadingService },
    { type: ExcelService },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridPopupExportExcelComponent.prototype, "modal", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "key", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "extendColumns", void 0);
__decorate([
    Input()
], GridPopupExportExcelComponent.prototype, "validator", void 0);
__decorate([
    Output()
], GridPopupExportExcelComponent.prototype, "exportByTemplate", void 0);
GridPopupExportExcelComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-export-excel',
        template: "<sd-modal-control width=\"sm\" [title]=\"'Export excel' | sdTranslate\" #modal>\r\n  <sd-modal-body>\r\n    <!-- <div class=\"mt-2\">\r\n      <button class=\"btn btn-success btn-sm mr-2\" (click)=\"exportDefault()\">\r\n        <i class=\"fa fa-download fa-fw mr-1\"></i>\r\n        {{'Export' | sdTranslate}}\r\n      </button>\r\n      <span>{{'Default Template' | sdTranslate}}</span>\r\n    </div> -->\r\n    <div *ngFor=\"let excelConfig of excelConfigs\" class=\"mt-2\">\r\n      <button class=\"btn btn-success btn-sm mr-2\" (click)=\"onExportByTemplate(excelConfig)\">\r\n        <i class=\"fa fa-download fa-fw mr-1\"></i>\r\n        {{'Export' | sdTranslate}}\r\n      </button>\r\n      <button *ngIf=\"excelConfig.removable\" class=\"btn btn-danger btn-sm mr-2\" (click)=\"removeTemplate(excelConfig)\">\r\n        <i class=\"fa fa-trash fa-fw mr-1\"></i>\r\n        {{'Delete template' | sdTranslate}}\r\n      </button>\r\n      <span>{{excelConfig.name}}</span>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <div class=\"mr-auto\">\r\n      <button type=\"button\" class=\"btn btn-success btn-sm mr-2\" (click)=\"generateTemplate()\">\r\n        <i class=\"fa fa-download fa-fw mr-1\"></i>{{'Generate template' | sdTranslate}}</button>\r\n      <button type=\"button\" class=\"btn btn-warning btn-sm mr-2\" (click)=\"uploadTemplate()\">\r\n        <i class=\"fa fa-plus fa-fw mr-1\"></i>{{'Add template' | sdTranslate}}</button>\r\n    </div>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}"]
    })
], GridPopupExportExcelComponent);

let GridControlComponent = class GridControlComponent {
    constructor(ref, deviceService, handlerLocal, handlerDotnet, utilityService, translateService, configurationService, datePipe, loadingService, apiService, excelService, notifyService, editorVisiblePipe) {
        var _a;
        this.ref = ref;
        this.handlerLocal = handlerLocal;
        this.handlerDotnet = handlerDotnet;
        this.utilityService = utilityService;
        this.translateService = translateService;
        this.configurationService = configurationService;
        this.datePipe = datePipe;
        this.loadingService = loadingService;
        this.apiService = apiService;
        this.excelService = excelService;
        this.notifyService = notifyService;
        this.editorVisiblePipe = editorVisiblePipe;
        this.isMobileOrTablet = false;
        this.displayKey = 'SDCUSTOM';
        this.localItems = [];
        this.items = [];
        this.filter = {};
        this.externalFilter = {};
        this.currentPage = 1;
        this.hiddenPaginate = false;
        this.showInlineFilter = true;
        this.quickFilters = [];
        // Paginate
        this.pages = [1];
        this.pageCount = 5;
        this.totalPage = 1;
        // Loading
        this.isLoading = false;
        this.viewItems = [];
        this.fixedColumns = [];
        this.normalColumns = [];
        this.columns = [];
        this.isCheckedAll = false;
        this.selectedItems = [];
        this.selectedItem = null;
        this.rowHandler = {
            click: (item) => {
                this.selectedItem = item;
                if (this.gridOption.onClickRow) {
                    this.gridOption.onClickRow(item);
                }
            },
            dblClick: (item) => {
                this.selectedItem = item;
                if (this.gridOption.onDblClickRow) {
                    this.gridOption.onDblClickRow(item);
                }
            }
        };
        this.setOption = (option) => {
            var _a, _b, _c, _d;
            delete this.gridOption;
            const gridConfiguration = this.configurationService.getGridConfiguration();
            if (!((_a = option.filter) === null || _a === void 0 ? void 0 : _a.type) && ((_c = (_b = gridConfiguration) === null || _b === void 0 ? void 0 : _b.filter) === null || _c === void 0 ? void 0 : _c.type)) {
                if (!option.filter) {
                    option.filter = {
                        type: gridConfiguration.filter.type
                    };
                }
                else {
                    option.filter.type = gridConfiguration.filter.type;
                }
            }
            this.gridOption = Object.assign(Object.assign({}, defaultGridOption), option);
            switch (this.gridOption.type) {
                case 'local':
                    this.handler = this.handlerLocal;
                    break;
                case 'dotnet':
                    this.handler = this.handlerDotnet;
                    break;
                case 'custom':
                    this.handler = this.gridOption.handlerCustom || ((_d = gridConfiguration) === null || _d === void 0 ? void 0 : _d.handlerCustom);
                    if (!this.handler) {
                        this.notifyService.notify.warning(`Handler custom was not found`);
                        return;
                    }
                    break;
            }
            // Loại bỏ những command bị ẩn
            this.gridOption.commands = this.gridOption.commands.filter(command => {
                const hidden = command.hidden;
                if (hidden !== undefined) {
                    if (typeof (hidden) === 'boolean') {
                        return !hidden;
                    }
                    else if (typeof (hidden) === 'function') {
                        return !hidden();
                    }
                }
                else {
                    return true;
                }
            });
            this.sdGridConfig.setOption({
                key: option.key,
                pageSize: this.gridOption.paginate.pageSize,
                columns: this.gridOption.columns
            });
            this.initExternalFilter();
            this.resize();
            this.detectChanges();
        };
        this.reload = (gridItems) => __awaiter(this, void 0, void 0, function* () {
            var _b, _c, _d;
            if (this.isLoading) {
                return;
            }
            this.isLoading = true;
            try {
                if (this.gridOption.type !== 'local') {
                    const handler = this.handler;
                    const filter = handler.mapRequest(this.getFilterInfo(this.currentPage, this.gridOption.paginate.pageSize));
                    if (this.gridOption.method === 'GET') {
                        const queryString = Object.keys(filter).map(key => key + '=' + filter[key]).join('&');
                        const url = this.gridOption.url.includes('?') ? `${this.gridOption.url}&${queryString}` : `${this.gridOption.url}?${queryString}`;
                        const response = yield this.apiService.get(url);
                        const { items, total } = handler.mapResponse(response);
                        this.items = items;
                        this.total = total;
                    }
                    else {
                        const response = yield this.apiService.post(this.gridOption.url, filter);
                        const { items, total } = handler.mapResponse(response);
                        this.items = items;
                        this.total = total;
                    }
                }
                else {
                    const handler = this.handler;
                    if (typeof (this.gridOption.items) === 'function') {
                        if (Array.isArray(gridItems)) {
                            this.localItems = gridItems;
                        }
                        else {
                            const results = this.gridOption.items();
                            if (results instanceof Promise) {
                                this.localItems = yield results;
                            }
                            else {
                                this.localItems = results;
                            }
                        }
                    }
                    else {
                        this.gridOption.items = gridItems || this.gridOption.items;
                        this.localItems = this.gridOption.items;
                    }
                    const response = handler.filter(this.localItems, {
                        customFilter: this.gridOption.filter.customFilter,
                        rawFilter: this.filter,
                        columns: this.gridOption.columns,
                        rawExternalFilter: this.externalFilter,
                        externalFilters: (_b = this.gridOption.filter) === null || _b === void 0 ? void 0 : _b.externalFilters,
                        orderBy: this.orderBy,
                        orderDirection: this.orderDirection,
                        pageNumber: this.currentPage,
                        pageSize: this.gridOption.paginate.pageSize
                    });
                    this.items = response.items;
                    this.total = response.total;
                }
                this.items.forEach(item => item.originItem = Object.assign({}, item));
                if (this.gridOption.onReloadCompleted) {
                    this.gridOption.onReloadCompleted(this.items);
                }
                this.generatePaginate();
                this.generateViewItems();
                this.generateEditorHandlers();
                this.generateSumarize();
                this.isLoading = false;
                $$1(this.gridBody.nativeElement).scrollTop(0);
                if (this.currentPage > 1 && !((_c = this.viewItems) === null || _c === void 0 ? void 0 : _c.length)) {
                    if (this.gridOption.type === 'local') {
                        if ((_d = this.localItems) === null || _d === void 0 ? void 0 : _d.length) {
                            this.selectPage(1);
                            return;
                        }
                    }
                    else {
                        if (this.total > 0) {
                            this.selectPage(1);
                            return;
                        }
                    }
                }
                this.detectChanges();
            }
            catch (error) {
                this.utilityService.handle.error(error);
                this.isLoading = false;
            }
        });
        this.clearFilter = () => {
            this.filter = {};
            this.externalFilter = {};
            this.initFilter();
            this.initExternalFilter();
            if (this.sdGridPopupFilter) {
                this.sdGridPopupFilter.filter = this.filter;
                this.sdGridPopupFilter.externalFilter = this.externalFilter;
            }
        };
        this.onClearFilter = () => {
            this.clearFilter();
            this.reload();
        };
        this.expandOrCollapse = (gridItem) => __awaiter(this, void 0, void 0, function* () {
            var _e, _f;
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation } = gridItem, item = __rest(gridItem, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation"]);
            if (!this.gridOption.subInformation) {
                return;
            }
            if ((_e = gridItem.subInformation) === null || _e === void 0 ? void 0 : _e.isOpened) {
                gridItem.subInformation.isOpened = false;
                return;
            }
            if (this.gridOption.subInformation.lazyLoading && !((_f = gridItem.subInformation) === null || _f === void 0 ? void 0 : _f.isLoaded)) {
                gridItem.subInformation.isLoading = true;
                try {
                    gridItem.subInformation.subItems = yield this.gridOption.subInformation.onLoad(item);
                    if (!Array.isArray(gridItem.subInformation.subItems)) {
                        this.notifyService.alert.warning(`Data is not an array`);
                        gridItem.subInformation.subItems = [];
                    }
                    gridItem.subInformation.isLoading = false;
                    gridItem.subInformation.isLoaded = true;
                    gridItem.subInformation.isOpened = true;
                    this.ref.detectChanges();
                }
                catch (err) {
                    this.utilityService.handle.error(err);
                    gridItem.subInformation.isLoading = false;
                    this.ref.detectChanges();
                }
                return;
            }
            if (this.gridOption.subInformation.lazyLoading === false && !gridItem.subInformation.isLoaded) {
                gridItem.subInformation.subItems = gridItem[this.gridOption.subInformation.field];
                if (!Array.isArray(gridItem.subInformation.subItems)) {
                    this.notifyService.alert.warning(`Data is not an array`);
                    gridItem.subInformation.subItems = [];
                }
                gridItem.subInformation.isLoaded = true;
                gridItem.subInformation.isOpened = true;
                return;
            }
            gridItem.subInformation.isOpened = true;
            this.ref.detectChanges();
        });
        //#region Editable
        this.onCreate = () => {
            var _a, _b, _c;
            const { editor } = this.gridOption;
            if (!editor) {
                return;
            }
            if (!((_a = editor) === null || _a === void 0 ? void 0 : _a.addable)) {
                return;
            }
            const item = {
                editingStatus: 'create',
                blinker: {},
                subInformation: {}
            };
            // Gán giá trị mặc định
            this.gridOption.columns.forEach(column => {
                if (column.type === 'values') {
                    item[column.field] = '';
                }
                else if (column.type === 'bool') {
                    item[column.field] = true;
                }
                else if (column.type === 'number') {
                    item[column.field] = 0;
                }
            });
            (_c = (_b = editor).onAdd) === null || _c === void 0 ? void 0 : _c.call(_b, item);
            // Đưa item lên dòng đầu tiên nếu type khác popup
            if (editor.type !== 'popup') {
                if (this.gridOption.type === 'local') {
                    this.items.splice(0, 0, item);
                }
                this.viewItems.splice(0, 0, item);
            }
            this.onUpdate(item);
        };
        this.onUpdate = (item) => {
            const { editor } = this.gridOption;
            item.editingStatus = item.editingStatus || 'update';
            item.temporary = Object.assign({}, item);
            this.generateEditorHanlder(item);
            if (editor.type === 'popup') {
                this.sdGridPopupEditor.open(item);
            }
        };
        this.onSave = (item) => __awaiter(this, void 0, void 0, function* () {
            const { editor } = this.gridOption;
            try {
                item.editorHandler.saving = true;
                if (editor.validate) {
                    const result = editor.validate(item);
                    if (result instanceof Promise) {
                        const message = yield result;
                        if (message) {
                            throw message;
                        }
                    }
                    else {
                        if (result) {
                            throw result;
                        }
                    }
                }
                if (editor.onSave) {
                    const result = editor.onSave(item);
                    if (result instanceof Promise) {
                        yield result;
                    }
                }
                if (item.editingStatus === 'create' && editor.type === 'popup') {
                    if (this.gridOption.type === 'local') {
                        this.items.splice(0, 0, item);
                    }
                    this.viewItems.splice(0, 0, item);
                }
                item.editingStatus = undefined;
                this.generateEditorHanlder(item);
            }
            catch (err) {
                this.notifyService.notify.warning(err);
            }
            finally {
                item.editorHandler.saving = false;
                this.ref.detectChanges();
            }
        });
        this.onCancel = (item) => {
            const { editor } = this.gridOption;
            if (item.editingStatus === 'create') {
                if (editor.type !== 'popup') {
                    if (this.gridOption.type === 'local') {
                        this.items.splice(0, 1);
                    }
                    this.viewItems.splice(0, 1);
                }
            }
            else {
                Object.assign(item, item.temporary);
                item.editingStatus = undefined;
                this.generateEditorHanlder(item);
                this.ref.detectChanges();
            }
        };
        this.initExternalFilter = () => {
            var _a, _b;
            if ((_b = (_a = this.gridOption.filter) === null || _a === void 0 ? void 0 : _a.externalFilters) === null || _b === void 0 ? void 0 : _b.length) {
                this.gridOption.filter.externalFilters.forEach(externalFilter => {
                    var _a, _b, _c, _d, _e, _f, _g, _h;
                    if (externalFilter.type === 'string') {
                        if (externalFilter.default) {
                            this.externalFilter[externalFilter.field] = (_a = externalFilter.default, (_a !== null && _a !== void 0 ? _a : ''));
                        }
                        return;
                    }
                    if (externalFilter.type === 'number') {
                        if (externalFilter.default) {
                            this.externalFilter[externalFilter.field] = (_b = externalFilter.default, (_b !== null && _b !== void 0 ? _b : undefined));
                        }
                        return;
                    }
                    if (externalFilter.type === 'daterange') {
                        this.externalFilter[externalFilter.field] = {
                            from: (_c = externalFilter.defaultFrom, (_c !== null && _c !== void 0 ? _c : undefined)),
                            to: (_d = externalFilter.defaultTo, (_d !== null && _d !== void 0 ? _d : undefined))
                        };
                        return;
                    }
                    if (externalFilter.type === 'numberrange') {
                        this.externalFilter[externalFilter.field] = {
                            from: (_e = externalFilter.defaultFrom, (_e !== null && _e !== void 0 ? _e : undefined)),
                            to: (_f = externalFilter.defaultTo, (_f !== null && _f !== void 0 ? _f : undefined))
                        };
                        return;
                    }
                    if (externalFilter.type === 'daterangefull') {
                        this.externalFilter[externalFilter.field] = {
                            from: (_g = externalFilter.defaultFrom, (_g !== null && _g !== void 0 ? _g : undefined)),
                            to: (_h = externalFilter.defaultTo, (_h !== null && _h !== void 0 ? _h : undefined))
                        };
                        return;
                    }
                });
            }
        };
        //#endregion
        this.onSearch = (searchValue, item, column) => {
            item[column.field] = searchValue;
        };
        this.onFilterConfigurationLoaded = (param) => {
            var _a;
            this.quickFilters = param.quickFilters || [];
            this.selectedQuickFilter = param.selectedQuickFilter || '';
            if (this.selectedQuickFilter) {
                const quickFilter = this.quickFilters.find(e => e.code === this.selectedQuickFilter);
                if (quickFilter) {
                    const f1 = JSON.stringify(quickFilter.filter);
                    const f2 = JSON.stringify(quickFilter.externalFilter);
                    this.filter = JSON.parse(f1);
                    this.externalFilter = JSON.parse(f2);
                }
            }
            if (this.showInlineFilter !== param.showInlineFilter) {
                this.showInlineFilter = (_a = param.showInlineFilter, (_a !== null && _a !== void 0 ? _a : true));
                this.resize();
            }
        };
        this.onSelectQuickFilter = (event) => {
            var _a, _b, _c;
            const quickFilter = this.quickFilters.find(e => e.code === event.value);
            if ((_a = quickFilter) === null || _a === void 0 ? void 0 : _a.code) {
                const f1 = JSON.stringify(quickFilter.filter);
                const f2 = JSON.stringify(quickFilter.externalFilter);
                this.selectedQuickFilter = (_b = quickFilter) === null || _b === void 0 ? void 0 : _b.code;
                this.filter = JSON.parse(f1);
                this.externalFilter = JSON.parse(f2);
                this.updateFilter();
            }
            else {
                this.selectedQuickFilter = '';
                this.onClearFilter();
            }
            (_c = this.sdGridPopupFilter) === null || _c === void 0 ? void 0 : _c.updateConfiguration(this.selectedQuickFilter);
        };
        this.getExportItems = () => __awaiter(this, void 0, void 0, function* () {
            var _g;
            if (this.isLoading) {
                return;
            }
            const pageNumber = 1;
            const pageSize = 10000;
            this.isLoading = true;
            try {
                if (this.gridOption.type !== 'local') {
                    const handler = this.handler;
                    const filter = handler.mapRequest(this.getFilterInfo(pageNumber, pageSize));
                    if (this.gridOption.method === 'GET') {
                        const queryString = Object.keys(filter).map(key => key + '=' + filter[key]).join('&');
                        const url = this.gridOption.url.includes('?') ? `${this.gridOption.url}&${queryString}` : `${this.gridOption.url}?${queryString}`;
                        const response = yield this.apiService.get(url);
                        return handler.mapResponse(response).items;
                    }
                    else {
                        const response = yield this.apiService.post(this.gridOption.url, filter);
                        return handler.mapResponse(response).items;
                    }
                }
                else {
                    let localItems = [];
                    const handler = this.handler;
                    if (typeof (this.gridOption.items) === 'function') {
                        const results = this.gridOption.items();
                        if (results instanceof Promise) {
                            localItems = yield results;
                        }
                        else {
                            localItems = results;
                        }
                    }
                    else {
                        localItems = this.gridOption.items;
                    }
                    const response = handler.filter(localItems, {
                        customFilter: this.gridOption.filter.customFilter,
                        rawFilter: this.filter,
                        columns: this.gridOption.columns,
                        rawExternalFilter: this.externalFilter,
                        externalFilters: (_g = this.gridOption.filter) === null || _g === void 0 ? void 0 : _g.externalFilters,
                        orderBy: this.orderBy,
                        orderDirection: this.orderDirection,
                        pageNumber,
                        pageSize
                    });
                    return response.items;
                }
            }
            catch (error) {
                this.utilityService.handle.error(error);
            }
            finally {
                this.isLoading = false;
                this.ref.detectChanges();
            }
        });
        this.getFilterInfo = (pageNumber, pageSize) => {
            var _a;
            for (const key of Object.keys(this.filter)) {
                if (typeof (this.filter[key]) === 'string') {
                    this.filter[key] = this.filter[key].trim();
                }
            }
            for (const key of Object.keys(this.externalFilter)) {
                if (typeof (this.externalFilter[key]) === 'string') {
                    this.externalFilter[key] = this.externalFilter[key].trim();
                }
            }
            return {
                customFilter: this.gridOption.filter.customFilter,
                rawFilter: this.filter,
                columns: this.gridOption.columns,
                rawExternalFilter: this.externalFilter,
                externalFilters: (_a = this.gridOption.filter) === null || _a === void 0 ? void 0 : _a.externalFilters,
                orderBy: this.orderBy,
                orderDirection: this.orderDirection,
                pageNumber,
                pageSize
            };
        };
        this.onExportByTemplate = (params) => __awaiter(this, void 0, void 0, function* () {
            var _h, _j;
            this.loadingService.start();
            let exportItems = yield this.getExportItems().finally(this.loadingService.stop);
            if ((_h = this.gridOption.export) === null || _h === void 0 ? void 0 : _h.mapping) {
                exportItems = this.gridOption.export.mapping(exportItems, params.excelConfig.name);
            }
            const columns = [...this.gridOption.columns, ...(((_j = this.gridOption.export) === null || _j === void 0 ? void 0 : _j.columns) || [])];
            const items = exportItems.map(item => {
                const obj = {};
                const handle = (column) => {
                    if (column.type === 'children') {
                        column.children.forEach(handle);
                    }
                    else if (column.transform) {
                        obj[column.field] = column.transform(item[column.field], item);
                    }
                    else if (item[column.field] === undefined || item[column.field] === null || item[column.field] === '') {
                        obj[column.field] = '';
                    }
                    else if (column.type === 'string' || column.type === 'number' || column.type === 'color') {
                        // Nếu cell là string hoặc number thì gán bằng chính nó
                        obj[column.field] = item[column.field];
                    }
                    else if (column.type === 'bool') {
                        // Nếu là bool thì gán bằng giá trị trueValue và falseValue (nếu có), mặc định là TRUE/FALSE
                        if (item[column.field]) {
                            obj[column.field] = column.trueValue || 'True';
                        }
                        else {
                            obj[column.field] = column.falseValue || 'False';
                        }
                    }
                    else if (column.type === 'date') {
                        // Nếu là date thì convert theo đúng format
                        const date = new Date(item[column.field]);
                        obj[column.field] = this.datePipe.transform(date, 'dd/MM/yyyy');
                    }
                    else if (column.type === 'datetime') {
                        // Nếu là datetime thì convert theo đúng format
                        const date = new Date(item[column.field]);
                        obj[column.field] = this.datePipe.transform(date, 'dd/MM/yyyy HH:mm:ss');
                    }
                    else if (column.type === 'time') {
                        // Nếu là time thì convert theo đúng format
                        const date = new Date(item[column.field]);
                        obj[column.field] = this.datePipe.transform(date, 'HH:mm:ss');
                    }
                    else if (column.type === 'values') {
                        // Nếu là values thì lấy giá trị của value được chọn
                        const data = column.values.find(e => e.value === item[column.field]);
                        if (data) {
                            obj[column.field] = data.text;
                        }
                        else {
                            obj[column.field] = item[column.field];
                        }
                    }
                    else if (column.type === 'radio') {
                        const data = column.values.find(e => e[column.valueField] === item[column.field]);
                        if (data) {
                            obj[column.field] = data[column.displayField];
                        }
                        else {
                            obj[column.field] = item[column.field];
                        }
                    }
                };
                columns.forEach(handle);
                return obj;
            });
            this.excelService.generateExcelDataByTemplate(params.excelConfig.fullPath, params.excelColumns, items, params.excelConfig.name);
        });
        this.onEditorChange = () => {
            this.ref.detectChanges();
        };
        this.onSelectPageSize = () => {
            this.reload();
        };
        this.noDataImage = (_a = this.configurationService.getGridConfiguration()) === null || _a === void 0 ? void 0 : _a.noDataImage;
        this.isMobileOrTablet = !deviceService.isDesktop();
        // this.ref.detach();
        // setInterval(() => {
        //   this.ref.markForCheck();
        // }, 1000);
        // ref.detach();
    }
    set option(value) {
        this.setOption(value);
    }
    ngAfterViewInit() {
        this.fixedHeadersSubcription = this.fixedHeaders.changes.subscribe(() => {
            const fixedHeaders = this.fixedHeaders.toArray();
            if (fixedHeaders.length > 0) {
                let left = $$1(fixedHeaders[0].nativeElement).outerWidth(true);
                for (let i = 1; i < fixedHeaders.length; i++) {
                    $$1(fixedHeaders[i].nativeElement).css({ left });
                    left += $$1(fixedHeaders[i].nativeElement).outerWidth(true);
                }
            }
        });
        this.fixedBodiesSubcription = this.fixedBodies.changes.subscribe(() => {
            const fixedBodies = this.fixedBodies.toArray();
            if (fixedBodies.length > 0) {
                const fixedPerRow = this.fixedBodies.length / this.viewItems.length;
                let left = $$1(fixedBodies[0].nativeElement).outerWidth(true);
                for (let i = 1; i < fixedBodies.length; i++) {
                    if (i % fixedPerRow === 0) {
                        left = 0;
                    }
                    $$1(fixedBodies[i].nativeElement).css({ left });
                    left += $$1(fixedBodies[i].nativeElement).outerWidth(true);
                }
            }
        });
    }
    ngOnDestroy() {
        var _a, _b;
        (_a = this.fixedHeadersSubcription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
        (_b = this.fixedBodiesSubcription) === null || _b === void 0 ? void 0 : _b.unsubscribe();
    }
    reloadItem(data) {
        Object.keys(data).forEach(id => {
            const item = this.items.find(e => !!e.id && e.id === id);
            if (item) {
                this.gridOption.columns.forEach(column => {
                    if (item[column.field] !== undefined && data[id][column.field] !== undefined && item[column.field] !== data[id][column.field]) {
                        this.blink(item, column.field);
                    }
                });
                Object.assign(item, data[id]);
                this.generateEditorHanlder(item);
                this.stopBlink();
            }
        });
    }
    blink(item, field) {
        item.blinker = item.blinker || {};
        item.blinker[field] = true;
    }
    stopBlink() {
        setTimeout(() => {
            this.viewItems.forEach(item => {
                item.blinker = {};
            });
        }, 1500);
    }
    detectChanges() {
        this.ref.detectChanges();
        this.ref.markForCheck();
    }
    generateViewItems() {
        this.currentPage = this.currentPage || 1;
        delete this.viewItems;
        if (this.gridOption.type === 'local') {
            this.viewItems = this.items.filter((item, index) => {
                return index >= (this.currentPage - 1) * this.gridOption.paginate.pageSize
                    && index < this.currentPage * this.gridOption.paginate.pageSize;
            });
        }
        else {
            this.viewItems = this.items;
        }
        this.viewItems.forEach(item => {
            item.blinker = item.blinker || {};
            item.subInformation = item.subInformation || {};
        });
    }
    get editedItems() {
        return this.items.filter(item => {
            if (!item.originItem) {
                return true;
            }
            if (Object.keys(item.originItem).some(key => item.originItem[key] !== item[key])) {
                return true;
            }
            return false;
        }).map(item => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = item, result = __rest(item, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return result;
        });
    }
    selectPage(selectedPage) {
        if (this.isLoading) {
            return;
        }
        const page = +selectedPage || 1;
        if (this.currentPage !== page && page > 0 && page <= this.totalPage) {
            this.currentPage = page;
            if (this.gridOption.type === 'local') {
                this.reload(this.localItems);
            }
            else {
                this.reload();
            }
        }
    }
    updateFilter(param) {
        var _a, _b;
        if ((_a = param) === null || _a === void 0 ? void 0 : _a.filter) {
            this.filter = param.filter;
        }
        if ((_b = param) === null || _b === void 0 ? void 0 : _b.externalFilter) {
            this.externalFilter = param.externalFilter;
        }
        if (this.gridOption.type === 'local') {
            this.reload(this.localItems);
        }
        else {
            this.reload();
        }
    }
    generatePaginate() {
        const { pageSize } = this.gridOption.paginate;
        if (this.gridOption.type === 'local') {
            this.total = this.items.length;
        }
        this.pages = [];
        this.totalPage = Math.trunc(this.total / pageSize) + (this.total % pageSize === 0 ? 0 : 1);
        if (this.totalPage <= this.pageCount) {
            for (let i = 1; i <= this.totalPage; i++) {
                this.pages.push(i);
            }
        }
        else {
            if (this.currentPage < 3) {
                this.pages = [1, 2, 3, 4, 5];
            }
            else if (this.currentPage > this.totalPage - 2) {
                this.pages = [this.totalPage - 4, this.totalPage - 3, this.totalPage - 2, this.totalPage - 1, this.totalPage];
            }
            else {
                this.pages = [this.currentPage - 2, this.currentPage - 1, this.currentPage, this.currentPage + 1, this.currentPage + 2];
            }
        }
        this.hiddenPaginate = this.currentPage === 1 && this.total <= pageSize;
    }
    generateSumarize() {
        var _a;
        if (((_a = this.items) === null || _a === void 0 ? void 0 : _a.length) > 0) {
            const from = +this.gridOption.paginate.pageSize * (+this.currentPage - 1) + 1;
            const to = from + this.viewItems.length - 1;
            this.sumarize = `${from} - ${to} / ${this.total}`;
        }
        else {
            this.sumarize = this.translateService.translate('EMPTY');
        }
    }
    getItems() {
        return this.items;
    }
    //#region Checkable
    setSelectedItems() {
        this.selectedItems = this.items.filter(item => item.isChecked)
            .map(item => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = item, result = __rest(item, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return result;
        });
    }
    check(item, isCheckbox) {
        var _a, _b;
        if (!this.gridOption.checkable) {
            return;
        }
        if (!isCheckbox) {
            item.isChecked = !item.isChecked;
        }
        this.isCheckedAll = this.items.length === this.items.filter(e => e.isChecked).length;
        (_b = (_a = this.gridOption).onCheck) === null || _b === void 0 ? void 0 : _b.call(_a, this.items.filter(e => e.isChecked), item);
        this.setSelectedItems();
    }
    checkAll(isCheckedAll) {
        this.isCheckedAll = isCheckedAll;
        this.items.forEach(item => item.isChecked = this.isCheckedAll);
        if (this.gridOption.onCheck) {
            this.gridOption.onCheck(this.items.filter(item => item.isChecked));
        }
        this.setSelectedItems();
    }
    //#endregion
    //#region Sort
    sort(column) {
        var _a, _b;
        const sortable = (_a = this.gridOption.sortable, (_a !== null && _a !== void 0 ? _a : true));
        const columnSortable = (_b = column.sortable, (_b !== null && _b !== void 0 ? _b : true));
        if (!sortable || !columnSortable) {
            return;
        }
        if (this.orderBy === column.field) {
            this.orderDirection = this.orderDirection === 'ASC' ? 'DESC' : 'ASC';
        }
        else {
            this.orderBy = column.field;
            this.orderDirection = 'ASC';
        }
        if (this.gridOption.type === 'local') {
            this.reload(this.localItems);
        }
        else {
            this.reload();
        }
    }
    //#endregion
    // #region Resize Grid
    resize() {
        this.detectChanges();
        if (this.gridOption.height) {
            this.gridBody.nativeElement.style.height = this.gridOption.height;
        }
        else {
            this.gridBody.nativeElement.style.height = `${window.innerHeight - 300}px`;
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 0);
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 200);
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 500);
            setTimeout(() => {
                // Lấy offset top để điều chỉnh kích thước Grid vừa với màn hình
                const top = this.gridBody.nativeElement.getBoundingClientRect().top;
                // const top = $(this.gridBody.nativeElement).offset().top;
                const bottom = this.gridOption.hideFooter ? 0 : (this.isMobileOrTablet ? 45 : 55);
                const height = window.innerHeight - top - bottom;
                this.gridBody.nativeElement.style.height = `${height}px`;
            }, 1000);
        }
    }
    setHeight(height) {
        this.gridOption.height = height;
        this.resize();
    }
    // #endregion
    //#region Import, Export, Config
    loadConfig(configResult) {
        this.gridOption.paginate.pageSize = configResult.pageSize;
        this.gridOption.columns = configResult.columns;
        this.fixedColumns = configResult.fixedColumns;
        this.normalColumns = configResult.normalColumns;
        this.columns = [...this.fixedColumns, ...this.normalColumns];
        this.currentPage = 1;
        this.initFilter();
        this.initDictionaryColumnValues();
        this.reload();
    }
    initFilter() {
        this.gridOption.columns.forEach(column => {
            var _a;
            // Gán giá trị filter mặc định cho từng cột
            this.filter[column.field] = (_a = this.filter[column.field], (_a !== null && _a !== void 0 ? _a : ''));
        });
    }
    initDictionaryColumnValues() {
        this.gridOption.columns.forEach(column => {
            if (column.type === 'values') {
                column.dictionary = {};
                if (column.values) {
                    column.values.forEach(e => {
                        column.dictionary[e.value.toString()] = {
                            text: e.text,
                            icon: e.icon,
                            color: e.color,
                            backgroundColor: e.backgroundColor
                        };
                    });
                }
            }
            if (column.type === 'children') {
                column.children.forEach(childColumn => {
                    if (childColumn.type === 'values') {
                        childColumn.dictionary = {};
                        if (childColumn.values) {
                            childColumn.values.forEach(e => {
                                childColumn.dictionary[e.value.toString()] = {
                                    text: e.text,
                                    icon: e.icon,
                                    color: e.color,
                                    backgroundColor: e.backgroundColor
                                };
                            });
                        }
                    }
                });
            }
        });
    }
    //#endregion
    generateEditorHandlers() {
        this.viewItems.forEach(item => {
            this.generateEditorHanlder(item);
        });
    }
    generateEditorHanlder(item) {
        // item.editorHandler = item.editorHandler || {};
        this.editorVisiblePipe.transform(null, item, this.gridOption);
    }
    trackById(index, item) {
        return item.id;
    }
    get isFiltering() {
        return Object.values(this.filter).some(value => !!value);
    }
    onFilterPopup() {
        const f1 = JSON.stringify(this.filter);
        const f2 = JSON.stringify(this.externalFilter);
        const filter = JSON.parse(f1);
        const externalFilter = JSON.parse(f2);
        this.sdGridPopupFilter.open(this.fixedColumns, this.normalColumns, filter, externalFilter, this.gridOption.filter.externalFilters);
    }
    get invalidItems() {
        return this.items.filter(e => { var _a; return (_a = e.editorHandler) === null || _a === void 0 ? void 0 : _a.errorMessage; }).map(e => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = e, item = __rest(e, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return {
                item,
                message: e.editorHandler.errorMessage
            };
        });
    }
    get gridItems() {
        return this.items.map(e => {
            const { temporary, originItem, editorHandler, editingStatus, isChecked, subInformation, blinker } = e, item = __rest(e, ["temporary", "originItem", "editorHandler", "editingStatus", "isChecked", "subInformation", "blinker"]);
            return item;
        });
    }
};
GridControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: HandlerLocal },
    { type: HandlerDotnet },
    { type: UtilityService },
    { type: TranslateService },
    { type: ConfigurationService },
    { type: DatePipe },
    { type: LoadingService },
    { type: ApiService },
    { type: ExcelService },
    { type: NotifyService },
    { type: EditorHandlerPipe }
];
__decorate([
    ViewChildren('fixedHeader')
], GridControlComponent.prototype, "fixedHeaders", void 0);
__decorate([
    ViewChildren('fixedBody')
], GridControlComponent.prototype, "fixedBodies", void 0);
__decorate([
    ViewChild('fixedGridContainer')
], GridControlComponent.prototype, "fixedGridContainer", void 0);
__decorate([
    ViewChild('gridFixedBody')
], GridControlComponent.prototype, "gridFixedBody", void 0);
__decorate([
    ViewChild('gridContainer')
], GridControlComponent.prototype, "gridContainer", void 0);
__decorate([
    ViewChild('gridHeader')
], GridControlComponent.prototype, "gridHeader", void 0);
__decorate([
    ViewChild('gridBody')
], GridControlComponent.prototype, "gridBody", void 0);
__decorate([
    ViewChild('sdGridConfig', { static: true })
], GridControlComponent.prototype, "sdGridConfig", void 0);
__decorate([
    ViewChild('sdGridPopupEditor')
], GridControlComponent.prototype, "sdGridPopupEditor", void 0);
__decorate([
    ViewChild('sdGridPopupFilter')
], GridControlComponent.prototype, "sdGridPopupFilter", void 0);
__decorate([
    ViewChild(GridImportExcelComponent)
], GridControlComponent.prototype, "sdGridImportExcel", void 0);
__decorate([
    ViewChild(GridPopupExportExcelComponent)
], GridControlComponent.prototype, "sdGridPopupExportExcel", void 0);
__decorate([
    Input()
], GridControlComponent.prototype, "option", null);
GridControlComponent = __decorate([
    Component({
        selector: 'sd-grid-control',
        template: "<div class=\"clearfix\"></div>\r\n<mat-form-field class=\"sd-form\" *ngIf=\"quickFilters?.length\" appearance=\"outline\" style=\"width: 200px;\">\r\n  <mat-select [(ngModel)]=\"selectedQuickFilter\" (selectionChange)=\"onSelectQuickFilter($event)\">\r\n    <mat-option>{{'Quick filter' | sdTranslate}}</mat-option>\r\n    <mat-option *ngFor=\"let quickFilter of quickFilters\" [value]=\"quickFilter?.code\">\r\n      <span>{{quickFilter?.code}}</span>\r\n    </mat-option>\r\n  </mat-select>\r\n</mat-form-field>\r\n<sd-grid-desktop-inline-filter [externalFilters]=\"gridOption?.filter?.externalFilters\" [columns]=\"gridOption?.columns\"\r\n  [showInlineFilter]=\"showInlineFilter\" [filter]=\"filter\" [externalFilter]=\"externalFilter\" (sdChange)=\"updateFilter()\">\r\n</sd-grid-desktop-inline-filter>\r\n<div *ngIf=\"!isMobileOrTablet; else elseMobileOrTablet\" class=\"sd-box sd-box-primary\">\r\n  <div class=\"sd-box-body p-0\">\r\n    <div class=\"row mx-0\">\r\n      <div [ngClass]=\"{'c-loading': isLoading}\" class=\"table-responsive\" #gridBody style=\"position: relative;\">\r\n        <i [ngClass]=\"{'d-none': !isLoading}\" class=\"fa fa-5x fa-spinner fa-pulse c-loading-icon\"></i>\r\n        <table [ngClass]=\"{'c-loading-margin': isLoading}\" *ngIf=\"gridOption\"\r\n          class=\"table table-hover table-striped table-bordered c-table\" style=\"border:0!important;\">\r\n          <thead class=\"thead-light\">\r\n            <tr>\r\n              <th class=\"position-sticky c-sticky-all align-middle p-0\" style=\"width:4px; min-width: 4px;\" #fixedHeader>\r\n              </th>\r\n              <th class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\" #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.subInformation\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:30px;min-width: 30px;line-height: 3rem\" #fixedHeader>\r\n              </th>\r\n              <th *ngIf=\"gridOption?.subInformation\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.checkable\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:50px;min-width:50px;\" #fixedHeader>\r\n                <label class=\"custom-control custom-checkbox\">\r\n                  <input type=\"checkbox\" class=\"custom-control-input\" [(ngModel)]=\"isCheckedAll\"\r\n                    (change)=\"checkAll(isCheckedAll)\">\r\n                  <span class=\"custom-control-label\"></span>\r\n                </label>\r\n              </th>\r\n              <th *ngIf=\"gridOption?.checkable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.commands?.length\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                [ngStyle]=\"{'width':gridOption.commands.length*30 + 'px', 'min-width': gridOption.commands.length*30 + 'px'}\"\r\n                #fixedHeader>\r\n              </th>\r\n              <th *ngIf=\"gridOption?.commands?.length\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption.editor?.addable || gridOption.editor?.editable\"\r\n                class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:60px;min-width: 60px;line-height: 1.5\" #fixedHeader>\r\n                <div *ngIf=\"gridOption.editor.addable\" class=\"align-middle text-center\">\r\n                  <button type=\"button\" class=\"c-btn-icon\" (click)=\"onCreate()\">\r\n                    <i class=\"fa fa-plus\"></i>\r\n                  </button>\r\n                </div>\r\n              </th>\r\n              <th *ngIf=\"gridOption.editor\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <th *ngIf=\"gridOption?.numberable\" class=\"position-sticky c-sticky-all align-middle text-center p-0\"\r\n                style=\"width:50px;min-width:50px;\" #fixedHeader>\r\n                #\r\n              </th>\r\n              <th *ngIf=\"gridOption?.numberable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\"\r\n                #fixedHeader></th>\r\n              <ng-template ngFor let-column [ngForOf]=\"fixedColumns\">\r\n                <th class=\"position-sticky align-middle cursor-pointer c-cell c-sticky-all\" #fixedHeader\r\n                  [ngStyle]=\"{'width':column.width ? column.width : '','min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\">\r\n                  <span [title]=\"column.title\" class=\"c-header-title\"\r\n                    [ngStyle]=\"{'width':column.width && column.width !== 'auto' ? column.width : '400px'}\"\r\n                    (click)=\"sort(column)\">\r\n                    {{column.title}}\r\n                    <i *ngIf=\"column.type !== 'children' && gridOption.sortable !== false && column.sortable !== false && orderBy !== column.field\"\r\n                      class=\"fa fa-sort fa-fw\"></i>\r\n                    <i *ngIf=\"orderBy == column.field && orderDirection == 'ASC'\" class=\"fa fa-sort-asc fa-fw\"></i>\r\n                    <i *ngIf=\"orderBy == column.field && orderDirection == 'DESC'\" class=\"fa fa-sort-desc fa-fw\"></i>\r\n                  </span>\r\n                  <ng-container\r\n                    *ngIf=\"(showInlineFilter || gridOption?.filter?.type === 'inline') && !column?.preventFilter && !gridOption?.filter?.disabled\">\r\n                    <input\r\n                      *ngIf=\"column.type === 'string' || column.type === 'number' || column.type === 'color' || column.type === 'children'\"\r\n                      type=\"text\" class=\"form-control form-control-xs\" [(ngModel)]=\"filter[column.field]\"\r\n                      (keyup.enter)=\"updateFilter()\">\r\n                    <select *ngIf=\"column.type === 'bool'\" class=\"form-control form-control-xs\"\r\n                      [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                      <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                      <option value=\"1\">{{column.trueValue || 'True'}}</option>\r\n                      <option value=\"0\">{{column.falseValue || 'False'}}</option>\r\n                    </select>\r\n                    <sd-grid-autocomplete-control *ngIf=\"column.type === 'values' && column?.editor?.autocomplete\"\r\n                      [items]=\"column.values\" valueField=\"value\" displayField=\"text\" [(model)]=\"filter[column.field]\"\r\n                      (sdChange)=\"updateFilter()\">\r\n                    </sd-grid-autocomplete-control>\r\n                    <select class=\"form-control form-control-xs\"\r\n                      *ngIf=\"column.type == 'values' && !column?.editor?.autocomplete\"\r\n                      [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                      <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                      <option *ngFor=\"let data of column.values\" [value]=\"data.value\">{{data.text}}</option>\r\n                    </select>\r\n                    <select class=\"form-control form-control-xs\" *ngIf=\"column.type == 'radio'\"\r\n                      [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                      <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                      <option *ngFor=\"let data of column.values\" [value]=\"data[column.valueField]\">\r\n                        {{data[column.displayField]}}</option>\r\n                    </select>\r\n                    <sd-grid-date-picker-control\r\n                      *ngIf=\"column.type === 'date' || column.type === 'datetime' || column.type === 'time'\"\r\n                      [(model)]=\"filter[column.field]\" (sdChange)=\"updateFilter()\" type=\"date\">\r\n                    </sd-grid-date-picker-control>\r\n                  </ng-container>\r\n                </th>\r\n                <th class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-all\" #fixedHeader></th>\r\n              </ng-template>\r\n              <th *ngFor=\"let column of normalColumns\"\r\n                class=\"position-sticky align-middle cursor-pointer border-top-0 border-bottom-0 c-cell c-sticky-top\"\r\n                [ngStyle]=\"{'width':column.width ? column.width : '','min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\">\r\n                <span [title]=\"column.title\" class=\"c-header-title\"\r\n                  [ngStyle]=\"{'width':column.width && column.width !== 'auto' ? column.width : '400px'}\"\r\n                  (click)=\"sort(column)\">\r\n                  {{column.title}}\r\n                  <i *ngIf=\"column.type !== 'children' && gridOption.sortable !== false && column.sortable !== false && orderBy !== column.field\"\r\n                    class=\"fa fa-sort fa-fw\"></i>\r\n                  <i *ngIf=\"orderBy == column.field && orderDirection == 'ASC'\" class=\"fa fa-sort-asc fa-fw\"></i>\r\n                  <i *ngIf=\"orderBy == column.field && orderDirection == 'DESC'\" class=\"fa fa-sort-desc fa-fw\"></i>\r\n                </span>\r\n                <ng-container\r\n                  *ngIf=\"(showInlineFilter || gridOption?.filter?.type === 'inline') && !column?.preventFilter && !gridOption?.filter?.disabled\">\r\n                  <input\r\n                    *ngIf=\"column.type === 'string' || column.type === 'number' || column.type === 'color' || column.type === 'children'\"\r\n                    type=\"text\" class=\"form-control form-control-xs\" [(ngModel)]=\"filter[column.field]\"\r\n                    (keyup.enter)=\"updateFilter()\">\r\n                  <select *ngIf=\"column.type === 'bool'\" class=\"form-control form-control-xs\"\r\n                    [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                    <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                    <option value=\"1\">{{column.trueValue || 'TRUE'}}</option>\r\n                    <option value=\"0\">{{column.falseValue || 'FALSE'}}</option>\r\n                  </select>\r\n                  <sd-grid-autocomplete-control *ngIf=\"column.type === 'values' && column?.editor?.autocomplete\"\r\n                    [items]=\"column.values\" valueField=\"value\" displayField=\"text\" [(model)]=\"filter[column.field]\"\r\n                    (sdChange)=\"updateFilter()\">\r\n                  </sd-grid-autocomplete-control>\r\n                  <select class=\"form-control form-control-xs\"\r\n                    *ngIf=\"column.type == 'values' && !column?.editor?.autocomplete\" [(ngModel)]=\"filter[column.field]\"\r\n                    (change)=\"updateFilter()\">\r\n                    <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                    <option *ngFor=\"let data of column.values\" [value]=\"data.value\">{{data.text}}</option>\r\n                  </select>\r\n                  <select class=\"form-control form-control-xs\" *ngIf=\"column.type == 'radio'\"\r\n                    [(ngModel)]=\"filter[column.field]\" (change)=\"updateFilter()\">\r\n                    <option value=\"\">{{'All' | sdTranslate}}</option>\r\n                    <option *ngFor=\"let data of column.values\" [value]=\"data[column.valueField]\">\r\n                      {{data[column.displayField]}}</option>\r\n                  </select>\r\n                  <sd-grid-date-picker-control\r\n                    *ngIf=\"column.type === 'date' || column.type === 'datetime' || column.type === 'time'\"\r\n                    [(model)]=\"filter[column.field]\" (sdChange)=\"updateFilter()\" type=\"date\">\r\n                  </sd-grid-date-picker-control>\r\n                </ng-container>\r\n              </th>\r\n            </tr>\r\n          </thead>\r\n          <tbody>\r\n            <ng-container *ngFor=\"let item of viewItems; index as idx; trackBy: trackById\">\r\n              <tr>\r\n                <td class=\"position-sticky c-sticky-left p-0\"\r\n                  [ngClass]=\"{'c-error': (item.editingStatus && item.editorHandler?.errorMessage), 'c-selected': !(item.editingStatus && item.editorHandler?.errorMessage) && selectedItem === item}\"\r\n                  style=\"width:4px;min-width: 4px;left:0\" matTooltipPosition=\"after\"\r\n                  [matTooltip]=\"item.editingStatus ? item.editorHandler?.errorMessage:''\" #fixedBody>\r\n                </td>\r\n                <td class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\" #fixedBody></td>\r\n                <td *ngIf=\"gridOption.subInformation\" class=\"position-sticky text-center align-middle p-0 c-sticky-left\"\r\n                  style=\"width:30px;min-width: 30px;line-height: 3rem\" #fixedBody>\r\n                  <button *ngIf=\"!item.editingStatus\" (click)=\"expandOrCollapse(item)\" type=\"button\" class=\"c-btn-icon\">\r\n                    <i *ngIf=\"item.subInformation?.isLoading\" class=\"fa fa-spinner fa-spin\"></i>\r\n                    <i *ngIf=\"!item.subInformation?.isLoading\" class=\"fa\"\r\n                      [ngClass]=\"{'fa-caret-right': !item.subInformation?.isOpened, 'fa-caret-down': item.subInformation?.isOpened}\"></i>\r\n                  </button>\r\n                </td>\r\n                <td *ngIf=\"gridOption.subInformation\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.checkable\" class=\"position-sticky c-sticky-left align-middle p-0\" #fixedBody>\r\n                  <div *ngIf=\"!item.editingStatus\" class=\"align-middle text-center\" style=\"width:50px;min-width: 50px;\">\r\n                    <label class=\"custom-control custom-checkbox\">\r\n                      <input type=\"checkbox\" class=\"custom-control-input\" [(ngModel)]=\"item.isChecked\"\r\n                        (change)=\"check(item, true)\">\r\n                      <span class=\"custom-control-label\"></span>\r\n                    </label>\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.checkable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.commands?.length\" class=\"position-sticky c-sticky-left align-middle p-0\"\r\n                  #fixedBody>\r\n                  <div *ngIf=\"!item.editingStatus\" class=\"d-flex align-middle text-center justify-content-center\"\r\n                    [ngStyle]=\"{'width':gridOption.commands.length*30 + 'px', 'min-width': gridOption.commands.length*30 + 'px'}\">\r\n                    <ng-container *ngFor=\"let command of gridOption.commands\">\r\n                      <section *ngIf=\"!(item | commandHiddenByItem:command.hiddenByItem | async)\">\r\n                        <button *ngIf=\"!command.children?.length; else elseCommandChildren\"\r\n                          (click)=\"command.click(item)\" type=\"button\" class=\"c-btn-icon\"\r\n                          [matTooltip]=\"command.title | commandTitle:item\"\r\n                          [disabled]=\"command.disabled | commandDisabled:item\">\r\n                          <i class=\"{{command.icon | commandIcon:item}}\" aria-hidden=\"true\"></i>\r\n                        </button>\r\n                        <ng-template #elseCommandChildren>\r\n                          <ng-container\r\n                            *ngIf=\"command.children | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n                            <div *ngIf=\"filteredColumnCommands?.length\">\r\n                              <button [matMenuTriggerFor]=\"menu\" type=\"button\" class=\"c-btn-icon\"\r\n                                [matTooltip]=\"command.title\" [disabled]=\"command.disabled | commandDisabled:item\">\r\n                                <i class=\"{{command.icon | commandIcon:item}}\" aria-hidden=\"true\"></i>\r\n                              </button>\r\n                              <mat-menu #menu=\"matMenu\">\r\n                                <button mat-menu-item *ngFor=\"let childCommand of filteredColumnCommands\"\r\n                                  [disabled]=\"childCommand.disabled | commandDisabled:item\"\r\n                                  (click)=\"childCommand.click(item)\">\r\n                                  <i class=\"{{childCommand.icon | commandIcon:item}}\"></i>\r\n                                  <span> {{childCommand.title | commandTitle:item}}</span>\r\n                                </button>\r\n                              </mat-menu>\r\n                            </div>\r\n                          </ng-container>\r\n                        </ng-template>\r\n                      </section>\r\n                    </ng-container>\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.commands?.length\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.editor?.addable || gridOption.editor?.editable\"\r\n                  class=\"position-sticky c-sticky-left align-middle p-0\" #fixedBody>\r\n                  <div class=\"align-middle text-center\" style=\"width:60px;min-width: 60px;line-height: 1.5\">\r\n                    <button type=\"button\"\r\n                      *ngIf=\"!item.editingStatus && gridOption.editor?.type !== 'inline' && gridOption.editor?.editable\"\r\n                      type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Edit\" (click)=\"onUpdate(item)\"\r\n                      [disabled]=\"item.editorHandler?.disabled\">\r\n                      <i class=\"fa fa-pencil text-primary\" aria-hidden=\"true\"></i>\r\n                    </button>\r\n                    <button type=\"button\" *ngIf=\"item.editingStatus && gridOption.editor?.type !== 'inline'\"\r\n                      type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Save\" (click)=\"onSave(item)\"\r\n                      [disabled]=\"item.editorHandler?.errorMessage\">\r\n                      <i class=\"fa fa-fw text-success\"\r\n                        [ngClass]=\"{'fa-floppy-o': !item.editorHandler?.saving, 'fa-spinner': item.editorHandler?.saving, 'fa-spin': item.editorHandler?.saving}\"\r\n                        aria-hidden=\"true\"></i>\r\n                    </button>\r\n                    <button type=\"button\" *ngIf=\"item.editingStatus\" type=\"button\" class=\"c-btn-icon\" placement=\"top\"\r\n                      matTooltip=\"Cancel\" (click)=\"onCancel(item)\">\r\n                      <i class=\"fa fa-fw fa-times text-danger\" aria-hidden=\"true\"></i>\r\n                    </button>\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.editor\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <td *ngIf=\"gridOption.numberable\" class=\"position-sticky c-sticky-left align-middle p-0\" #fixedBody>\r\n                  <div *ngIf=\"!item.editingStatus\" class=\"align-middle text-center\" style=\"width:50px;min-width: 50px;\">\r\n                    {{gridOption.paginate?.pageSize * (currentPage - 1) + idx + 1}}\r\n                  </div>\r\n                </td>\r\n                <td *ngIf=\"gridOption.numberable\" class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\"\r\n                  #fixedBody></td>\r\n                <ng-template ngFor let-column [ngForOf]=\"fixedColumns\">\r\n                  <td class=\"position-sticky align-middle c-cell c-sticky-left\"\r\n                    [ngClass]=\"{'text-center': column.type !== 'string' && column.type !== 'number' && column.type !== 'children', 'text-right': column.type === 'number'}\"\r\n                    [ngStyle]=\"{'width':column.width ? column.width : '','min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\"\r\n                    (click)=\"rowHandler.click(item)\" #fixedBody>\r\n                    <ng-container *ngIf=\"column.type !== 'children';else elseColumnChildren\">\r\n                      <div *ngIf=\"item[column.field] | editorHandler:item:gridOption\" class=\"align-middle\"\r\n                        (dblclick)=\"rowHandler.dblClick(item)\">\r\n                        <div\r\n                          *ngIf=\"item.editorHandler[column.field].visible && gridOption.editor?.validate && !(item[column.field] | editorValidate:item:gridOption.editor.validate | async)\">\r\n                        </div>\r\n                        <ng-container *ngIf=\"item.editorHandler[column.field].visible;else columnView\">\r\n                          <sd-grid-desktop-column-edit [column]=\"column\" [item]=\"item\" (sdChange)=\"onEditorChange()\"></sd-grid-desktop-column-edit>\r\n                        </ng-container>\r\n                        <ng-template #columnView>\r\n                          <sd-grid-desktop-column-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-view>\r\n                        </ng-template>\r\n                      </div>\r\n                    </ng-container>\r\n                    <ng-template #elseColumnChildren>\r\n                      <sd-grid-desktop-column-children-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-children-view>\r\n                    </ng-template>\r\n                  </td>\r\n                  <td class=\"position-sticky h-100 p-0 c-sticky-spliter c-sticky-left\" #fixedBody></td>\r\n                </ng-template>\r\n                <td *ngFor=\"let column of normalColumns\" class=\"align-middle c-cell\" (click)=\"rowHandler.click(item)\"\r\n                  [ngClass]=\"{'text-center': column.type !== 'string' && column.type !== 'number' && column.type !== 'children', 'text-right': column.type === 'number'}\"\r\n                  (dblclick)=\"rowHandler.dblClick(item)\"\r\n                  [ngStyle]=\"{'width':column.width ? column.width : '', 'min-width': !column.width || column.width === 'auto' ? '400px' : column.width}\">\r\n                  <ng-container *ngIf=\"column.type !== 'children';else elseColumnChildren\">\r\n                    <div *ngIf=\"item[column.field] | editorHandler:item:gridOption\" class=\"align-middle\"\r\n                      (dblclick)=\"rowHandler.dblClick(item)\">\r\n                      <div\r\n                        *ngIf=\"item.editorHandler[column.field].visible && gridOption.editor?.validate && !(item[column.field] | editorValidate:item:gridOption.editor.validate | async)\">\r\n                      </div>\r\n                      <ng-container *ngIf=\"item.editorHandler[column.field].visible;else columnView\">\r\n                        <sd-grid-desktop-column-edit [column]=\"column\" [item]=\"item\" (sdChange)=\"onEditorChange()\"></sd-grid-desktop-column-edit>\r\n                      </ng-container>\r\n                      <ng-template #columnView>\r\n                        <sd-grid-desktop-column-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-view>\r\n                      </ng-template>\r\n                    </div>\r\n                  </ng-container>\r\n                  <ng-template #elseColumnChildren>\r\n                    <sd-grid-desktop-column-children-view [column]=\"column\" [item]=\"item\"></sd-grid-desktop-column-children-view>\r\n                  </ng-template>\r\n                </td>\r\n              </tr>\r\n              <tr *ngIf=\"gridOption?.subInformation && item?.subInformation?.isOpened\" class=\"c-no-hover\">\r\n                <td class=\"position-sticky c-sticky-left p-0\" style=\"width:4px;min-width: 4px;left:0\">\r\n                </td>\r\n                <td class=\"p-3\" colspan=\"100\">\r\n                  <sd-grid-sub-information [subItems]=\"item?.subInformation?.subItems\"\r\n                    [columns]=\"gridOption?.subInformation?.columns\"></sd-grid-sub-information>\r\n                </td>\r\n              </tr>\r\n            </ng-container>\r\n            <tr *ngIf=\"!viewItems?.length && !isLoading && noDataImage\">\r\n              <td class=\"c-empty\" colspan=\"100\">\r\n                <img [src]=\"noDataImage\">\r\n              </td>\r\n            </tr>\r\n          </tbody>\r\n        </table>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div *ngIf=\"!gridOption.hideFooter\" class=\"sd-box-footer clearfix\">\r\n    <sd-button *ngIf=\"sdGridPopupFilter\" class=\"mr-1\" [title]=\"'Filter' | sdTranslate\" icon=\"filter_list\" size=\"sm\" (action)=\"onFilterPopup()\"></sd-button>\r\n    <sd-button *ngIf=\"!gridOption?.hideReload\" class=\"mr-1\" [title]=\"'Reload' | sdTranslate\" icon=\"refresh\" size=\"sm\" (action)=\"reload()\"></sd-button>\r\n    <sd-button *ngIf=\"gridOption.onImportExcel\" class=\"mr-1\" [title]=\"'Import' | sdTranslate\" icon=\"publish\" size=\"sm\" (action)=\"sdGridImportExcel.open()\"></sd-button>\r\n    <sd-button *ngIf=\"sdGridPopupExportExcel\" class=\"mr-1\" [title]=\"'Export' | sdTranslate\" icon=\"get_app\" size=\"sm\" (action)=\"sdGridPopupExportExcel.open()\"></sd-button>\r\n    <sd-button *ngIf=\"gridOption.key\" class=\"mr-1\" [title]=\"'Configure' | sdTranslate\" icon=\"settings\" size=\"sm\" (action)=\"sdGridConfig.open()\"></sd-button>\r\n    <div class=\"row mr-0 ml-0 text-right pull-right\">\r\n      <ul class=\"pagination pagination-primary m-0\">\r\n        <li class=\"page-item disabled\">\r\n          <span> {{sumarize}} </span>\r\n        </li>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage > 1\" class=\"page-item\" (click)=\"selectPage(1)\">\r\n          <a class=\"page-link\">\r\n            {{'First' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage > 1\" class=\"page-item\" (click)=\"selectPage(currentPage-1)\">\r\n          <a class=\"page-link\">\r\n            {{'Previous' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n        <ng-container *ngIf=\"!hiddenPaginate\">\r\n          <li class=\"page-item\" [ngClass]=\"{'active':page === currentPage}\" *ngFor=\"let page of pages\"\r\n            (click)=\"selectPage(page)\">\r\n            <a class=\"page-link\">{{page}}</a>\r\n          </li>\r\n        </ng-container>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage < totalPage\" class=\"page-item\" (click)=\"selectPage(currentPage+1)\">\r\n          <a class=\"page-link\">\r\n            {{'Next' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n        <li *ngIf=\"!hiddenPaginate && currentPage < totalPage\" class=\"page-item\" (click)=\"selectPage(totalPage)\">\r\n          <a class=\"page-link\">\r\n            {{'Last' | sdTranslate | uppercase}}\r\n          </a>\r\n        </li>\r\n      </ul>\r\n    </div>\r\n  </div>\r\n</div>\r\n<ng-template #elseMobileOrTablet>\r\n  <div class=\"sd-box c-mobile-box\">\r\n    <div class=\"sd-box-body c-mobile-body\" [ngClass]=\"{'c-loading': isLoading}\" #gridBody>\r\n      <i [ngClass]=\"{'d-none': !isLoading}\" class=\"fa fa-4x fa-spinner fa-pulse c-loading-icon\"></i>\r\n      <ng-container *ngFor=\"let item of viewItems\">\r\n        <div class=\"c-mobile-item\" [ngClass]=\"{'c-mobile-item-selected':item.isChecked}\">\r\n          <ng-container *ngFor=\"let column of columns | filterMobile:item\">\r\n            <div *ngIf=\"column.type !== 'children'\" class=\"row c-mobile-row\" (click)=\"check(item)\">\r\n              <div class=\"col-5\">\r\n                <span class=\"c-mobile-title\">\r\n                  <!-- <i class=\"fa fa-circle fa-fw\" style=\"font-size: 10px;\"></i> -->\r\n                  {{item | columnTitle:column.title:column.dynamicTitle | async}}:\r\n                </span>\r\n              </div>\r\n              <div class=\"col-7\">\r\n                <ng-container *ngIf=\"column.type === 'string'\">\r\n                  <span *ngIf=\"!column.htmlTemplate; else elseUseTemplate\"\r\n                    [className]=\"item[column.field] | cellClassName:item:column\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                    <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                      (click)=\"column.click(item[column.field], item)\">{{item[column.field]}}</a>\r\n                    <ng-container *ngIf=\"!column.click\">\r\n                      {{item[column.field]}}</ng-container>\r\n                  </span>\r\n                  <ng-template #elseUseTemplate>\r\n                    <span class=\"c-mobile-value\"\r\n                      [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\"></span>\r\n                  </ng-template>\r\n                  <ng-container\r\n                    *ngIf=\"column.commands | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n                    <button *ngFor=\"let columnCommand of filteredColumnCommands\" (click)=\"columnCommand.click(item)\"\r\n                      type=\"button\" class=\"c-btn-icon\" [matTooltip]=\"columnCommand.title | commandTitle:item\">\r\n                      <i class=\"{{columnCommand.icon | commandIcon:item}}\" aria-hidden=\"true\"\r\n                        style=\"font-size: 14px;\"></i>\r\n                    </button>\r\n                  </ng-container>\r\n                </ng-container>\r\n                <span *ngIf=\"column.type === 'number'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'datetime'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'date'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{item[column.field] | date:'dd/MM/yyyy'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'time'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                  <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                    (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'HH:mm'}}</a>\r\n                  <ng-container *ngIf=\"!column.click\">\r\n                    {{item[column.field] | date:'HH:mm'}}</ng-container>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'bool'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n                  [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\"\r\n                  (click)=\"column.click && column.click(item[column.field], item)\">\r\n                  <span *ngIf=\"item[column.field]\" class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n                  <span *ngIf=\"!item[column.field]\" class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n                </span>\r\n                <span *ngIf=\"column.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                    class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"></span>\r\n                <ng-container *ngIf=\"column.type === 'values'\">\r\n                  <ng-container *ngIf=\"column?.dictionary[item[column.field]] as dic; else elseNotInDic\">\r\n                    <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status c-mobile-value\"\r\n                      [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n                      {{dic.text}}\r\n                    </span>\r\n                    <ng-template #elseNoStatus>\r\n                      <span class=\"c-mobile-value\">\r\n                        {{dic.text}}\r\n                      </span>\r\n                    </ng-template>\r\n                  </ng-container>\r\n                  <ng-template #elseNotInDic>\r\n                    <span class=\"c-mobile-value\">\r\n                      {{item[column.field]}}\r\n                    </span>\r\n                  </ng-template>\r\n                </ng-container>\r\n                <span *ngIf=\"column.type === 'radio'\" class=\"c-mobile-value\">{{item[column.field]}}</span>\r\n                <img *ngIf=\"column.type === 'image'\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n                  [height]=\"column.display?.height\" style=\"margin: 5px 0\"\r\n                  (click)=\"column.click && column.click(item[column.field], item)\">\r\n              </div>\r\n            </div>\r\n            <ng-container *ngIf=\"column.type === 'children' && column.children?.length\">\r\n              <div class=\"row c-mobile-row\" *ngFor=\"let childColumn of column.children | filterMobile:item\"\r\n                (click)=\"check(item)\">\r\n                <div class=\"col-5\">\r\n                  <span class=\"c-mobile-title\">\r\n                    <!-- <i class=\"fa fa-circle fa-fw\" style=\"font-size: 10px;\"></i> -->\r\n                    {{childColumn.title}}:\r\n                  </span>\r\n                </div>\r\n                <div class=\"col-7\">\r\n                  <ng-container *ngIf=\"childColumn.type === 'string'\">\r\n                    <span *ngIf=\"!childColumn.htmlTemplate; else elseUseTemplate\"\r\n                      [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                      [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"><a\r\n                        *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                        (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field]}}</a>\r\n                      <ng-container *ngIf=\"!childColumn.click\">\r\n                        {{item[childColumn.field]}}</ng-container>\r\n                    </span>\r\n                    <ng-template #elseUseTemplate>\r\n                      <span class=\"c-mobile-value\"\r\n                        [innerHTML]=\"(item[childColumn.field] | columnHtmlTemplate:item:childColumn.htmlTemplate) | safeHtml\"></span>\r\n                    </ng-template>\r\n                  </ng-container>\r\n                  <span *ngIf=\"childColumn.type === 'number'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{(item[childColumn.field] | valueTransform:item:childColumn) | number : '1.0-2'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{(item[childColumn.field] | valueTransform:item:childColumn) | number : '1.0-2'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'datetime'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'date'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{item[childColumn.field] | date:'dd/MM/yyyy'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'time'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n                    <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n                      (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'HH:mm'}}</a>\r\n                    <ng-container *ngIf=\"!childColumn.click\">\r\n                      {{item[childColumn.field] | date:'HH:mm'}}</ng-container>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'bool'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n                    (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n                    <span *ngIf=\"item[childColumn.field]\"\r\n                      class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n                    <span *ngIf=\"!item[childColumn.field]\"\r\n                      class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n                  </span>\r\n                  <span *ngIf=\"childColumn.type === 'color'\"\r\n                    [className]=\"item[childColumn.field] | cellClassName:item:childColumn:true\"\r\n                    [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n                    (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\"><input\r\n                      disabled=\"true\" type=\"color\" class=\"form-control c-input-xs\"\r\n                      [(ngModel)]=\"item[childColumn.field]\"></span>\r\n                  <ng-container *ngIf=\"childColumn.type === 'values'\">\r\n                    <ng-container *ngIf=\"childColumn?.dictionary[item[childColumn.field]] as dic; else elseNotInDic\">\r\n                      <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status c-mobile-value\"\r\n                        [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n                        {{dic.text}}\r\n                      </span>\r\n                      <ng-template #elseNoStatus>\r\n                        <span class=\"c-mobile-value\">\r\n                          {{dic.text}}\r\n                        </span>\r\n                      </ng-template>\r\n                    </ng-container>\r\n                    <ng-template #elseNotInDic>\r\n                      <span class=\"c-mobile-value\">\r\n                        {{item[childColumn.field]}}\r\n                      </span>\r\n                    </ng-template>\r\n                  </ng-container>\r\n                  <span *ngIf=\"childColumn.type === 'radio'\" class=\"c-mobile-value\">{{item[childColumn.field]}}</span>\r\n                  <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n                    [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\" style=\"margin: 5px 0\"\r\n                    (click)=\"column.click && column.click(item[column.field], item)\">\r\n                </div>\r\n              </div>\r\n            </ng-container>\r\n          </ng-container>\r\n          <div class=\"p-2\" *ngIf=\"gridOption?.subInformation && item?.subInformation?.isOpened\">\r\n            <sd-grid-sub-information [subItems]=\"item?.subInformation?.subItems\"\r\n              [columns]=\"gridOption?.subInformation?.columns\"></sd-grid-sub-information>\r\n          </div>\r\n          <div class=\"c-mobile-command\">\r\n            <div>\r\n              <i *ngIf=\"gridOption?.subInformation && item.subInformation?.isLoading\"\r\n                class=\"fa fa-spinner fa-spin ml-1 c-mobile-action\" (click)=\"expandOrCollapse(item)\"></i>\r\n              <i *ngIf=\"gridOption?.subInformation && !item.subInformation?.isLoading\" class=\"fa ml-1 c-mobile-action\"\r\n                [ngClass]=\"{'fa-plus': !item.subInformation?.isOpened, 'fa-minus': item.subInformation?.isOpened}\"\r\n                (click)=\"expandOrCollapse(item)\"></i>\r\n            </div>\r\n            <ng-container *ngIf=\"gridOption.commands | mobileCommandFilter:item | async; $implicit as filteredCommands\">\r\n              <div *ngIf=\"filteredCommands.length\">\r\n                <i [matMenuTriggerFor]=\"menu\" class=\"fa fa-navicon fa-fw c-mobile-action\"></i>\r\n                <mat-menu #menu=\"matMenu\">\r\n                  <button *ngFor=\"let command of filteredCommands\" mat-menu-item (click)=\"command.click(item)\"\r\n                    [disabled]=\"command.disabled | commandDisabled:item\">\r\n                    <i class=\"{{command.icon | commandIcon:item}}\"></i>\r\n                    <span> {{command.title | commandTitle:item}}</span>\r\n                  </button>\r\n                </mat-menu>\r\n              </div>\r\n            </ng-container>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n    </div>\r\n    <div *ngIf=\"!gridOption.hideFooter\" class=\"sd-box-footer clearfix\">\r\n      <button *ngIf=\"sdGridPopupFilter\" type=\"button\" class=\"c-btn-icon c-m-3\" (click)=\"onFilterPopup()\">\r\n        <i class=\"fa fa-filter fa-fw sd-text-info c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"!gridOption?.hideReload\" type=\"button\" class=\"c-btn-icon c-m-3\" (click)=\"reload()\">\r\n        <i class=\"fa fa-refresh fa-fw sd-text-info c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"gridOption.onImportExcel\" type=\"button\" class=\"c-btn-icon c-m-3\"\r\n        (click)=\"sdGridImportExcel.open()\">\r\n        <i class=\"fa fa-upload fa-fw sd-text-success c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"sdGridPopupExportExcel\" [disabled]=\"!viewItems?.length\" type=\"button\" class=\"c-btn-icon c-m-3\"\r\n        (click)=\"sdGridPopupExportExcel.open()\">\r\n        <i class=\"fa fa-download fa-fw sd-text-success c-mobile-action\"></i>\r\n      </button>\r\n      <button *ngIf=\"gridOption.key\" type=\"button\" class=\"c-btn-icon c-m-3\" (click)=\"sdGridConfig.open()\">\r\n        <i class=\"fa fa-cogs fa-fw sd-text-primary c-mobile-action\"></i>\r\n      </button>\r\n      <div class=\"row mr-0 ml-0 text-right pull-right\">\r\n        <div class=\"40px\">\r\n          <select class=\"form-control form-control-xs\" [(ngModel)]=\"gridOption.paginate.pageSize\"\r\n            (change)=\"onSelectPageSize()\">\r\n            <option value=\"10\">10</option>\r\n            <option value=\"25\">25</option>\r\n            <option value=\"50\">50</option>\r\n            <option value=\"100\">100</option>\r\n          </select>\r\n        </div>\r\n        <ul class=\"pagination pagination-primary m-0\">\r\n          <!-- <li class=\"page-item disabled\">\r\n            <span> {{sumarize}} </span>\r\n          </li> -->\r\n          <li class=\"page-item\" [ngClass]=\"{'disabled':currentPage === 1}\" (click)=\"selectPage(currentPage-1)\">\r\n            <a class=\"page-link\">\r\n              <i class=\"fa fa-angle-left\"></i>\r\n            </a>\r\n          </li>\r\n          <li class=\"page-item active\">\r\n            <a class=\"page-link\">{{currentPage}}</a>\r\n          </li>\r\n          <li class=\"page-item\" [ngClass]=\"{'disabled':currentPage === totalPage}\" (click)=\"selectPage(currentPage+1)\">\r\n            <a class=\"page-link\">\r\n              <i class=\"fa fa-angle-right\"></i>\r\n            </a>\r\n          </li>\r\n        </ul>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</ng-template>\r\n<!-- Modal Configure Grid -->\r\n<sd-grid-config (sdChange)=\"loadConfig($event)\" #sdGridConfig></sd-grid-config>\r\n<sd-grid-popup-editor (save)=\"onSave($event)\" #sdGridPopupEditor></sd-grid-popup-editor>\r\n<!-- Import Excel -->\r\n<sd-grid-import-excel *ngIf=\"gridOption?.onImportExcel\" [key]=\"gridOption?.key\" [columns]=\"gridOption?.columns\"\r\n  [accept]=\"gridOption?.onImportExcel\" #sdGridImportExcel></sd-grid-import-excel>\r\n<sd-grid-popup-export-excel *ngIf=\"gridOption.exportable\" [key]=\"gridOption?.key\" [columns]=\"gridOption?.columns\"\r\n  [extendColumns]=\"gridOption?.export?.columns\" [validator]=\"gridOption?.export?.validator\"\r\n  (exportByTemplate)=\"onExportByTemplate($event)\" #sdGridPopupExportExcel>\r\n</sd-grid-popup-export-excel>\r\n<sd-grid-popup-filter\r\n  *ngIf=\"!gridOption?.filter?.disabled && (isMobileOrTablet || gridOption?.filter?.type === 'popup' || gridOption?.filter?.externalFilters?.length)\"\r\n  [key]=\"gridOption?.key\" (accept)=\"updateFilter($event)\" [filterType]=\"gridOption?.filter?.type\"\r\n  (clear)=\"onClearFilter()\" #sdGridPopupFilter (loadInlineFilter)=\"onFilterConfigurationLoaded($event)\">\r\n</sd-grid-popup-filter>",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-text-primary{color:#c82c37!important}.sd-text-secondary{color:#919191!important}.sd-text-info{color:#00bcd4!important}.sd-text-success{color:#4caf50!important}.sd-text-warning{color:#ff9800!important}.sd-text-danger{color:#f44336!important}", ".pagination>li>a{border:0;border-radius:24px!important;transition:.3s;padding:0 9px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>span{border:0;border-radius:24px!important;transition:.3s;padding:0 8px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>a:focus,.pagination>li>a:hover,.pagination>li>span:focus,.pagination>li>span:hover{z-index:3;color:#23527c;background-color:#eee;border-color:#ddd}.pagination>.active>a,.pagination>.active>a:focus,.pagination>.active>a:hover,.pagination>.active>span,.pagination>.active>span:focus,.pagination>.active>span:hover{background-color:#c82c37;border-color:#c82c37;color:#fff;box-shadow:0 4px 5px 0 rgba(156,39,176,.14),0 1px 10px 0 rgba(156,39,176,.12),0 2px 4px -1px rgba(156,39,176,.2)}.pagination.pagination-info>.active>a,.pagination.pagination-info>.active>a:focus,.pagination.pagination-info>.active>a:hover,.pagination.pagination-info>.active>span,.pagination.pagination-info>.active>span:focus,.pagination.pagination-info>.active>span:hover{background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 4px 5px 0 rgba(0,188,212,.14),0 1px 10px 0 rgba(0,188,212,.12),0 2px 4px -1px rgba(0,188,212,.2)}.pagination.pagination-success>.active>a,.pagination.pagination-success>.active>a:focus,.pagination.pagination-success>.active>a:hover,.pagination.pagination-success>.active>span,.pagination.pagination-success>.active>span:focus,.pagination.pagination-success>.active>span:hover{background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.pagination.pagination-warning>.active>a,.pagination.pagination-warning>.active>a:focus,.pagination.pagination-warning>.active>a:hover,.pagination.pagination-warning>.active>span,.pagination.pagination-warning>.active>span:focus,.pagination.pagination-warning>.active>span:hover{background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.pagination.pagination-danger>.active>a,.pagination.pagination-danger>.active>a:focus,.pagination.pagination-danger>.active>a:hover,.pagination.pagination-danger>.active>span,.pagination.pagination-danger>.active>span:focus,.pagination.pagination-danger>.active>span:hover{background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", "select.form-control-xs:not([size]):not([multiple]){height:28px}", ".c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}", "@charset \"UTF-8\";.table.c-table.table-bordered,.table.c-table.table-bordered td,.table.c-table.table-bordered th{border:1px solid #dee2e6!important}.table.c-table.table-bordered td.c-sticky-spliter,.table.c-table.table-bordered th.c-sticky-spliter{background-color:#dee2e6!important;border:none!important}.table.c-table.table-bordered td.c-sticky-left,.table.c-table.table-bordered th.c-sticky-left{border-right:0!important;border-left:0!important}.table.c-table.table-bordered td.c-sticky-all,.table.c-table.table-bordered th.c-sticky-all{border:0!important}.table.c-table.table-bordered td.c-empty,.table.c-table.table-bordered th.c-empty{text-align:center;background-color:#fff;border-bottom:none!important}.table.c-table.table-bordered td.c-empty img,.table.c-table.table-bordered th.c-empty img{margin-top:20px;margin-bottom:20px;opacity:.2}.table.c-table thead.thead-light th{color:#495057;background-color:#eceff1;font-size:14px!important;min-width:0;min-height:50px;height:50px;border-top:none!important}.table.c-table thead.thead-light th.c-cell{padding:3px 5px!important}.table.c-table tbody td{font-size:13px!important;min-width:0;min-height:25px}.table.c-table tbody td.c-cell{padding:3px 5px!important}.table.table-striped tbody tr:not(.c-no-hover):hover,.table.table-striped tbody tr:not(.c-no-hover):hover td.c-sticky-left{background-color:#e3f2fd!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd){background-color:#fafafa}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left{background-color:#fafafa!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left.c-sticky-spliter{background-color:#dee2e6!important;border:none!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left.c-selected{background-color:#00bcd4!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(odd) .c-sticky-left.c-error{background-color:#f44336!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even){background-color:#fff}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left{background-color:#fff!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left.c-sticky-spliter{background-color:#dee2e6!important;border:none!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left.c-selected{background-color:#00bcd4!important}.table.table-striped tbody tr:not(.c-no-hover):nth-of-type(even) .c-sticky-left.c-error{background-color:#f44336!important}.grid-header{overflow-x:hidden;overflow-y:hidden}.c-cell-padding{padding:3px 5px!important}.c-header-title{text-transform:uppercase;font-weight:500}span.c-header-title{white-space:nowrap;overflow:hidden!important;text-overflow:ellipsis;display:block;padding:0 .3rem}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:center;text-transform:uppercase}.status.c-desktop-status{width:100%}.status.c-align-left{text-align:left!important}.status-success{color:#43a047}.status-danger{color:#f44336}.page-item{cursor:pointer}.sumarize{padding:8px 12px;text-transform:uppercase;font-size:12px;color:#fff;display:inline-block;white-space:normal;font-weight:500;line-height:1;text-align:center;border-radius:10rem;background-color:#00bcd4}.cursor-pointer{cursor:pointer}label.custom-control.custom-checkbox{margin:0}.c-overflow-x-hidden{overflow-x:hidden}.c-overflow-y-hidden{overflow-y:hidden}.c-grid-header{overflow-x:hidden;overflow-y:hidden}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px!important;height:28px!important}.c-sticky-top{z-index:20;top:0!important}.c-sticky-left{z-index:20;left:0}.c-sticky-all{z-index:30;top:0!important;left:0}.c-sticky-spliter{z-index:40!important;background-color:#dee2e6!important;border:none!important;width:1px!important;min-width:1px!important}.c-badge:not(.c-children){display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:12px;max-width:80%;margin:0 auto}.c-badge.c-children{padding:5px!important;font-weight:500;font-size:14px}.blinker{-webkit-animation:.5s linear infinite blinker;animation:.5s linear infinite blinker;color:#1c87c9;font-weight:500}@-webkit-keyframes blinker{50%{opacity:0}}@keyframes blinker{50%{opacity:0}}.c-loading{opacity:.4}.c-loading-icon{position:-webkit-sticky;position:sticky;top:calc(50% - 2.5rem);left:calc(50% - 2.5rem)}.c-loading-margin{margin-top:-5rem}fieldset.c-fieldset-mobile{border-radius:5px;border:1px solid #e0e0e0;padding:3px 5px}legend.c-legend-mobile{width:auto;padding:0 5px;margin:0 10px;border-bottom:none;font-size:16px;font-weight:500}@media (min-width:481px) and (max-width:767px){.c-mobile-hidden{display:none!important}}@media (min-width:320px) and (max-width:480px){.c-mobile-hidden{display:none!important}}.c-mobile-box{border-top:none!important;box-shadow:0 0 3px 0 rgba(0,0,0,.3)}.c-mobile-body{margin-top:5px;margin-bottom:5px;overflow-x:auto}.c-mobile-item{border:1px solid #fff;border-radius:5px;margin:8px 0;padding:5px;box-shadow:0 0 3px 0 rgba(0,0,0,.3)}.c-mobile-item.c-mobile-item-selected{border:2px solid #00bcd4}.c-mobile-item:nth-of-type(odd){background-color:#fafafa}.c-mobile-item:nth-of-type(even){background-color:#fff}.c-mobile-row{margin-top:0;margin-bottom:3px}.c-desktop-title{font-size:13px;margin-right:3px;font-weight:700;color:#212529;line-height:1.7}.c-mobile-title{font-size:14px;margin-right:3px;font-weight:700;color:#212529}.c-children,.c-mobile-value{font-size:14px;overflow-wrap:break-word;color:#212529}.c-mobile-badge{padding:5px!important;font-weight:500;font-size:14px}.c-mobile-command{padding:5px 3px 0;border-top:1px solid #f4f4f4;display:flex;align-items:center;justify-content:space-between}.c-mobile-action{font-size:18px!important}.c-mobile-checkable{margin:5px 0 5px -5px!important}.c-m-3{margin:3px!important}.c-m-5{margin:5px!important}fieldset.c-fieldset{border-radius:5px;border:1px solid #919191}legend.c-legend{width:auto;padding:0 5px;margin:0 10px;border-bottom:none;font-size:20px}"]
    })
], GridControlComponent);

let ModalControl = 
// tslint:disable-next-line: component-class-suffix
class ModalControl {
    // private modalIndex = 700;
    constructor(dialog, bottomSheet, deviceService) {
        this.dialog = dialog;
        this.bottomSheet = bottomSheet;
        this.height = 'auto';
        this.modalWidth = 'auto';
        this.isOpened = false;
        this.isMobileOrTablet = false;
        this.open = () => {
            this.isOpened = true;
            if (this.isMobileOrTablet) {
                this.bottomSheet.open(this.templateRef);
            }
            else {
                this.dialog.open(this.templateRef);
            }
        };
        this.close = () => {
            if (this.isMobileOrTablet) {
                this.bottomSheet.dismiss();
            }
            else {
                this.dialog.closeAll();
            }
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
        this.type = this.type || 'primary';
        this.width = this.width || 'lg';
        if (!this.isMobileOrTablet) {
            switch (this.width) {
                case 'lg':
                    this.modalWidth = '80%';
                    break;
                case 'md':
                    this.modalWidth = '60%';
                    break;
                case 'sm':
                    this.modalWidth = '40%';
                    break;
                default: this.modalWidth = this.width;
            }
        }
    }
    ngAfterViewInit() {
        // $('body').append(this.modal.nativeElement);
    }
    ngOnDestroy() {
        // $(this.modal.nativeElement).remove();
    }
};
ModalControl.index = 0;
ModalControl.ctorParameters = () => [
    { type: MatDialog },
    { type: MatBottomSheet },
    { type: DeviceDetectorService }
];
__decorate([
    ViewChild('templateRef')
], ModalControl.prototype, "templateRef", void 0);
__decorate([
    Input()
], ModalControl.prototype, "title", void 0);
__decorate([
    Input()
], ModalControl.prototype, "type", void 0);
__decorate([
    Input()
], ModalControl.prototype, "width", void 0);
__decorate([
    Input()
], ModalControl.prototype, "height", void 0);
__decorate([
    ViewChild('modal')
], ModalControl.prototype, "modal", void 0);
ModalControl = __decorate([
    Component({
        selector: 'sd-modal-control',
        template: "<ng-template #templateRef>\r\n  <ng-container *ngIf=\"isOpened\">\r\n    <sd-modal-header *ngIf=\"title\">\r\n      {{title}}\r\n      <button *ngIf=\"!isMobileOrTablet\" class=\"float-right\" type=\"button\" (click)=\"close()\" mat-icon-button>\r\n        <mat-icon>close</mat-icon>\r\n      </button>\r\n    </sd-modal-header>\r\n    <ng-content></ng-content>\r\n  </ng-container>\r\n</ng-template>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".c-modal-dialog{max-height:calc(100vh - 80px)!important;overflow-y:auto}.c-modal-dialog.c-mobile-dialog{width:auto!important;height:auto!important}"]
    })
    // tslint:disable-next-line: component-class-suffix
], ModalControl);

let SelectControlComponent = class SelectControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.initialized = false;
        this.pItems = [];
        this.flag = false;
        this.name = v4();
        this.multiple = false;
        this.cItems = [];
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.onChanges = () => {
            var _a;
            this.cItems = this.pItems;
            this.value = this.pModel;
            if (this.flag || (!this.valueField && !this.displayField)) {
                this.cItems = this.pItems.map(e => ({
                    code: e
                }));
                this.flag = true;
                this.valueField = 'code';
                this.displayField = 'code';
            }
            else {
                this.cItems = this.pItems;
            }
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
            if (!this.value && !this.multiple && this.required && this.cItems.length > 0) {
                setTimeout(() => {
                    this.onChange(this.cItems[0][this.valueField]);
                });
            }
        };
        this.onSelectionChange = (change) => {
            var _a;
            const value = ((_a = change) === null || _a === void 0 ? void 0 : _a.value) || '';
            if (this.multiple) {
                this.onChange(value || []);
            }
            else {
                this.onChange(value);
            }
        };
        this.reValidate = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.onChange = (value) => {
            this.value = value;
            this.modelChange.emit(this.value);
            this.change.emit(this.value);
            this.sdChange.emit(this.value);
        };
    }
    set items(items) {
        if (!Array.isArray(items)) {
            items = [];
        }
        this.pItems = items.filter(item => !!item);
        if (this.initialized) {
            this.onChanges();
        }
    }
    set model(value) {
        this.pModel = value || '';
        if (this.initialized) {
            this.onChanges();
        }
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges();
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
};
SelectControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], SelectControlComponent.prototype, "multiple", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "items", null);
__decorate([
    Input()
], SelectControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "model", null);
__decorate([
    Output()
], SelectControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], SelectControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], SelectControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], SelectControlComponent.prototype, "validator", void 0);
__decorate([
    ViewChild('formModel')
], SelectControlComponent.prototype, "formModel", void 0);
SelectControlComponent = __decorate([
    Component({
        selector: 'sd-select-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <mat-select class=\"sd-select\" #formModel=\"ngModel\" [ngModel]=\"value\" [name]=\"name\" placeholder=\"{{label}}\"\r\n    [required]=\"required\" [disabled]=\"disabled\" [sdCustomValidator]=\"validator\" [multiple]=\"multiple\"\r\n    (selectionChange)=\"onSelectionChange($event)\">\r\n    <mat-option *ngIf=\"!required && !multiple\" value=\"\">{{'Please select' | sdTranslate}}</mat-option>\r\n    <mat-option *ngFor=\"let item of cItems\" [value]=\"item[valueField]\">\r\n      {{item[displayField]}}\r\n    </mat-option>\r\n  </mat-select>\r\n  <mat-error *ngIf=\"formModel.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.customValidator\">\r\n    {{formModel?.errors?.customValidator}}\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}"]
    })
], SelectControlComponent);

// Document: https://xdsoft.net/jqplugins/datetimepicker/
let DatePickerControlComponent = class DatePickerControlComponent {
    constructor(ref, deviceService) {
        this.ref = ref;
        this.isMobileOrTablet = false;
        this.initialized = false;
        this.pMinDate = null;
        this.pMaxDate = null;
        this.name = v4();
        this.type = 'datetime';
        this.disabled = false;
        this.required = false;
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.modelChange = new EventEmitter();
        this.onFocus = () => {
            if (this.isMobileOrTablet) {
                $$1(this.control.nativeElement).trigger('blur');
            }
        };
        this.onChanges = () => {
            this.date = this.pDate;
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    set minDate(date) {
        if (!Date.isDate(date)) {
            this.pMinDate = null;
        }
        else {
            this.pMinDate = Date.toFormat(date, 'yyyy/MM/dd HH:mm');
        }
        this.setOption();
    }
    set maxDate(date) {
        if (!Date.isDate(date)) {
            this.pMaxDate = null;
        }
        else {
            this.pMaxDate = Date.toFormat(date, 'yyyy/MM/dd HH:mm'); // this.datePipe.transform(date, 'yyyy/MM/dd HH:mm');
        }
        this.setOption();
    }
    set model(val) {
        if (!Date.isDate(val)) {
            this.pDate = null;
        }
        else {
            if (this.type === 'datetime') {
                this.pDate = Date.toFormat(val, 'dd/MM/yyyy HH:mm');
            }
            else if (this.type === 'date') {
                this.pDate = Date.toFormat(val, 'dd/MM/yyyy');
            }
            else {
                this.pDate = Date.toFormat(val, 'HH:mm');
            }
        }
        if (this.initialized) {
            this.onChanges();
        }
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges();
        this.initialized = true;
        this.setOption();
        this.ref.detectChanges();
    }
    setOption() {
        if (this.initialized) {
            $$1(this.control.nativeElement).datetimepicker({
                datepicker: this.type === 'datetime' || this.type === 'date',
                timepicker: this.type === 'datetime' || this.type === 'time',
                format: this.type === 'datetime' ? 'd/m/Y H:i' : (this.type === 'date' ? 'd/m/Y' : 'H:i'),
                step: 15,
                minDate: this.pMinDate || undefined,
                maxDate: this.pMaxDate || undefined,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false,
                onChangeDateTime: (date) => {
                    if (!date && !this.date) {
                        return;
                    }
                    if (this.type === 'datetime') {
                        date = Date.toFormat(date, 'dd/MM/yyyy HH:mm');
                    }
                    else if (this.type === 'time') {
                        date = Date.toFormat(date, 'HH:mm');
                    }
                    else {
                        date = Date.toFormat(date, 'dd/MM/yyyy');
                    }
                    if (!this.equal(date, this.date)) {
                        this.model = this.parse(date);
                        this.modelChange.emit(this.parse(date));
                        this.change.emit(this.parse(date));
                        this.sdChange.emit(this.parse(date));
                    }
                    this.ref.detectChanges();
                }
            });
        }
    }
    parse(date) {
        if (this.type === 'date') {
            return Date.parseFrom(date, 'dd/MM/yyyy');
        }
        else if (this.type === 'time') {
            return Date.parseFrom(date, 'HH:mm');
        }
        return Date.parseFrom(date, 'dd/MM/yyyy HH:mm');
    }
    equal(date1, date2) {
        return Date.equal(this.parse(date1), this.parse(date2));
    }
};
DatePickerControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService }
];
__decorate([
    Input()
], DatePickerControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "minDate", null);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "maxDate", null);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "validator", void 0);
__decorate([
    Output()
], DatePickerControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], DatePickerControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], DatePickerControlComponent.prototype, "model", null);
__decorate([
    Output()
], DatePickerControlComponent.prototype, "modelChange", void 0);
__decorate([
    ViewChild('control')
], DatePickerControlComponent.prototype, "control", void 0);
__decorate([
    ViewChild('formModel')
], DatePickerControlComponent.prototype, "formModel", void 0);
DatePickerControlComponent = __decorate([
    Component({
        selector: 'sd-date-picker-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input class=\"sd-input\" #formModel=\"ngModel\" [name]=\"name\" autocomplete=\"false\" #control matInput\r\n    placeholder=\"{{label}}\" [ngModel]=\"date\" (focus)=\"onFocus()\" [required]=\"required\" [disabled]=\"disabled\"\r\n    [sdMinDate]=\"pMinDate\" [sdMaxDate]=\"pMaxDate\" [sdCustomValidator]=\"validator\" autocomplete=\"off\">\r\n  <mat-icon *ngIf=\"type !== 'time'\" matSuffix>date_range</mat-icon>\r\n  <mat-icon *ngIf=\"type === 'time'\" matSuffix>schedule</mat-icon>\r\n  <!-- <i matSuffix class=\"fa\" [ngClass]=\"{'fa-clock-o':type === 'time', 'fa-calendar':type !== 'time'}\"></i> -->\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.minDate\">\r\n    {{'Min date' | sdTranslate}}: <strong>{{pMinDate | date:'dd/MM/yyyy HH:mm'}}</strong>\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.maxDate\">\r\n    {{'Max date' | sdTranslate}}: <strong>{{pMaxDate | date:'dd/MM/yyyy HH:mm'}}</strong>\r\n  </mat-error>\r\n  <mat-error *ngIf=\"formModel?.errors?.customValidator\">\r\n    <strong>{{formModel?.errors?.customValidator}}</strong>\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}"]
    })
], DatePickerControlComponent);

let ModalHeaderComponent = class ModalHeaderComponent {
    constructor(deviceService) {
        this.isMobileOrTablet = false;
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
};
ModalHeaderComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
ModalHeaderComponent = __decorate([
    Component({
        selector: 'sd-modal-header',
        template: "<h3 mat-dialog-title *ngIf=\"!isMobileOrTablet\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</h3>\r\n<sd-bottom-sheet-header *ngIf=\"isMobileOrTablet\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</sd-bottom-sheet-header>\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>",
        styles: [""]
    })
], ModalHeaderComponent);

let ModalBodyComponent = class ModalBodyComponent {
    constructor(deviceService) {
        this.height = 'auto';
        this.width = 'auto';
        this.isMobileOrTablet = false;
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
};
ModalBodyComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
__decorate([
    Input()
], ModalBodyComponent.prototype, "height", void 0);
__decorate([
    Input()
], ModalBodyComponent.prototype, "width", void 0);
ModalBodyComponent = __decorate([
    Component({
        selector: 'sd-modal-body',
        template: "<!-- <div class=\"c-body\" [ngStyle]=\"{'height': height}\">\r\n  <ng-content></ng-content>\r\n</div> -->\r\n<mat-dialog-content *ngIf=\"!isMobileOrTablet\" class=\"c-body\" [ngStyle]=\"{'height': height, 'width': width}\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</mat-dialog-content>\r\n<sd-bottom-sheet-body *ngIf=\"isMobileOrTablet\" [height]=\"height\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</sd-bottom-sheet-body>\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".c-body{display:block;margin:0 -24px;padding:0 24px;max-height:65vh;overflow:auto}"]
    })
], ModalBodyComponent);

let ModalFooterComponent = class ModalFooterComponent {
    constructor(deviceService) {
        this.isMobileOrTablet = false;
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
    }
};
ModalFooterComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
ModalFooterComponent = __decorate([
    Component({
        selector: 'sd-modal-footer',
        template: "<!-- <div class=\"modal-footer\" style=\"padding:5px\"><ng-content></ng-content></div> -->\r\n<mat-dialog-actions *ngIf=\"!isMobileOrTablet\">\r\n  <div class=\"c-footer\">\r\n    <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n  </div>\r\n</mat-dialog-actions>\r\n<sd-bottom-sheet-footer *ngIf=\"isMobileOrTablet\">\r\n  <ng-container *ngTemplateOutlet=\"content\"></ng-container>\r\n</sd-bottom-sheet-footer>\r\n<ng-template #content>\r\n  <ng-content></ng-content>\r\n</ng-template>",
        styles: [".c-footer{flex:auto;display:flex}"]
    })
], ModalFooterComponent);

let UploadExcelControlComponent = class UploadExcelControlComponent {
    constructor(ref, excelService, translateService, notifyService, utilityService, loadingService) {
        this.ref = ref;
        this.excelService = excelService;
        this.translateService = translateService;
        this.notifyService = notifyService;
        this.utilityService = utilityService;
        this.loadingService = loadingService;
        this.items = [];
        this.hasDescription = false;
        // Paginate
        this.pages = [1];
        this.pageSize = 50;
        this.currentPage = 1;
        this.pageCount = 5;
        this.totalPage = 1;
        this.showing = 'ALL';
        this.filteredItems = [];
        this.viewItems = [];
        this.numberOfSuccess = 0;
        this.numberOfError = 0;
        this.numberOfWarning = 0;
        this.upload = () => __awaiter(this, void 0, void 0, function* () {
            var _a, _b;
            try {
                const { translate } = this.translateService;
                const { items, file } = yield this.excelService.import();
                if (this.option.columns.some(e => !!e.description)) {
                    this.hasDescription = true;
                }
                else {
                    this.hasDescription = false;
                }
                const offset = this.hasDescription ? 2 : 1;
                items.splice(0, offset);
                if (items.length === 0) {
                    this.notifyService.notify.warning(`${translate(`No data to import`)}`);
                    return;
                }
                if (items.length > this.option.limit) {
                    this.notifyService.notify.warning(`${translate(`Limit rows`)}: ${this.option.limit}`);
                    return;
                }
                this.items = ((_b = (_a = this.option).mappingItems) === null || _b === void 0 ? void 0 : _b.call(_a, items)) || items;
                this.filteredItems = this.items;
                this.showing = 'ALL';
                this.file = file;
                this.currentPage = 1;
                this.generatePaginate();
                for (const [idx, item] of this.items.entries()) {
                    item.lineId = v4();
                    item.excelIndex = idx + (this.hasDescription ? 4 : 3);
                    yield this.validate(item);
                }
                // Nếu không có error thì tiếp tục validate từ option validate truyền vào
                if (!this.items.some(item => !!item.validation.error) && this.option.errorValidation) {
                    this.loadingService.start();
                    const results = yield this.option.errorValidation(this.items);
                    results.forEach(result => this.items[result.idx].validation.error = result.message);
                    this.loadingService.stop();
                }
                // Nếu không có warning thì tiếp tục validate từ option validate truyền vào
                if (!this.items.some(item => !!item.validation.warning) && this.option.warningValidation) {
                    this.loadingService.start();
                    const results = yield this.option.warningValidation(this.items);
                    results.forEach(result => this.items[result.idx].validation.warning = result.message);
                    this.loadingService.stop();
                }
                this.reload();
                this.ref.detectChanges();
            }
            catch (err) {
                this.utilityService.handle.error(err);
            }
        });
        this.setValidation = (validates) => {
            if (Array.isArray(validates)) {
                validates.forEach(validate => this.items[validate.idx].validation.error = validate.message);
            }
            this.reload();
            this.ref.detectChanges();
        };
        this.view = (showing = 'ALL') => {
            this.showing = showing;
            this.currentPage = 1;
            this.reload();
            this.generatePaginate();
        };
    }
    ngOnInit() {
        this.uploadExcelConfig.setOption({
            key: this.option.key,
            columns: this.option.columns
        });
    }
    loadConfig(configResult) {
        return __awaiter(this, void 0, void 0, function* () {
            this.configResult = configResult;
            this.option.columns = configResult.columns;
        });
    }
    open() {
        this.items = [];
        this.numberOfSuccess = 0;
        this.numberOfError = 0;
        this.numberOfWarning = 0;
        this.modal.open();
    }
    close() {
        this.modal.close();
    }
    reload() {
        this.currentPage = this.currentPage || 1;
        this.filteredItems = this.items.filter((item) => {
            if (this.showing === 'SUCCESS') {
                return !item.validation.error && !item.validation.warning;
            }
            else if (this.showing === 'WARNING') {
                return !!item.validation.warning && !item.validation.error;
            }
            else if (this.showing === 'ERROR') {
                return !!item.validation.error;
            }
            return true;
        });
        this.viewItems = this.filteredItems
            .filter((item, index) => index >= (this.currentPage - 1) * this.pageSize && index < this.currentPage * this.pageSize);
        this.numberOfSuccess = this.items.filter(item => !item.validation.error && !item.validation.warning).length;
        this.numberOfError = this.items.filter(item => item.validation.error).length;
        this.numberOfWarning = this.items.filter(item => item.validation.warning && !item.validation.error).length;
    }
    validate(item) {
        var _a, _b, _c;
        return __awaiter(this, void 0, void 0, function* () {
            const validation = {
                error: '',
                warning: '',
                data: {}
            };
            const { translate } = this.translateService;
            for (const column of this.option.columns) {
                validation.data[column.field] = {};
                try {
                    if (column.defaultValue !== undefined) {
                        item[column.field] = (_a = item[column.field], (_a !== null && _a !== void 0 ? _a : column.defaultValue));
                    }
                    else if (column.required && !item[column.field] && item[column.field] !== 0) {
                        validation.data[column.field].error = `${translate('required')}`;
                        validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                        continue;
                    }
                    if (column.type === 'string') {
                        const value = (item[column.field] || '').toString();
                        if (column.minLength !== undefined && value.length < column.minLength) {
                            validation.data[column.field].error = `${translate('Min length')}: ${column.minLength}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.maxLength !== undefined && value.length > column.maxLength) {
                            validation.data[column.field].error = `${translate('Max length')}: ${column.maxLength}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'number') {
                        if (item[column.field]) {
                            const value = +item[column.field];
                            if (Number.isNaN(value)) {
                                validation.data[column.field].error = `${item[column.field]} ${translate('is not a number')}`;
                                validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                                continue;
                            }
                            item[column.field] = value;
                        }
                        if (!item[column.field] && item[column.field] !== 0) {
                            item[column.field] = undefined;
                        }
                        if (column.minValue !== undefined && item[column.field] < column.minValue) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Min value')}: ${column.minValue}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.maxValue !== undefined && item[column.field] > column.maxValue) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Max value')}: ${column.maxValue}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'bool') {
                        if (item[column.field] === 0 || item[column.field] === false) {
                            item[column.field] = '0';
                        }
                        if (item[column.field] === 1 || item[column.field] === true) {
                            item[column.field] = '1';
                        }
                        if (item[column.field]) {
                            const value = +item[column.field];
                            if (Number.isNaN(value) || (value !== 0 && value !== 1)) {
                                validation.data[column.field].error = `${translate('Value shoud be 0 or 1')}`;
                                validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            }
                        }
                    }
                    else if (column.type === 'values') {
                        if (typeof (item[column.field]) !== 'number' && typeof (item[column.field]) !== 'string') {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Invalid data type')}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.checkValueInArray && item[column.field] && !column.values.some(e => e.toString() === item[column.field].toString())) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Value not in')} [${column.values.join()}]`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'radio') {
                        if (typeof (item[column.field]) !== 'number' && typeof (item[column.field]) !== 'string') {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Invalid data type')}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                        if (column.checkValueInArray && item[column.field] && !column.values.some(e => e.toString() === item[column.field].toString())) {
                            validation.data[column.field].error = `${item[column.field]} ${translate('Value not in')} [${column.values.join()}]`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    else if (column.type === 'date') {
                        if (column.format && item[column.field]) {
                            if (!Date.isDate(Date.parseFrom(item[column.field], column.format))) {
                                validation.data[column.field].error = `${translate('Invalid format')} ${column.format}: ${item[column.field]}`;
                                validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            }
                        }
                        if (item[column.field] && !Date.isDate(item[column.field])) {
                            validation.data[column.field].error = `${translate('Invalid date')}: ${item[column.field]}`;
                            validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                            continue;
                        }
                    }
                    if (!validation.data[column.field].error && column.errorValidation) {
                        const error = yield column.errorValidation(item, item[column.field]);
                        if (error) {
                            validation.data[column.field].error = `${error}`;
                            validation.error += `[${column.field}] ${error}\n`;
                        }
                    }
                    if (!validation.data[column.field].warning && column.warningValidation) {
                        const warning = yield column.warningValidation(item, item[column.field]);
                        if (warning) {
                            validation.data[column.field].warning = `${warning}`;
                            validation.warning += `[${column.field}] ${warning}\n`;
                        }
                    }
                }
                catch (ex) {
                    validation.data[column.field].error = `${((_b = ex) === null || _b === void 0 ? void 0 : _b.message) || ((_c = ex) === null || _c === void 0 ? void 0 : _c.error) || ex || 'Có lỗi xảy ra'}`;
                    validation.error += `[${column.field}] ${validation.data[column.field].error}\n`;
                }
            }
            item.validation = validation;
        });
    }
    generatePaginate() {
        this.pages = [];
        this.totalPage = Math.trunc(this.filteredItems.length / this.pageSize) + (this.filteredItems.length % this.pageSize === 0 ? 0 : 1);
        if (this.currentPage > this.totalPage) {
            this.currentPage = this.totalPage;
        }
        if (this.totalPage <= this.pageCount) {
            for (let i = 1; i <= this.totalPage; i++) {
                this.pages.push(i);
            }
        }
        else {
            if (this.currentPage < 3) {
                this.pages = [1, 2, 3, 4, 5];
            }
            else if (this.currentPage > this.totalPage - 2) {
                this.pages = [this.totalPage - 4, this.totalPage - 3, this.totalPage - 2, this.totalPage - 1, this.totalPage];
            }
            else {
                this.pages = [this.currentPage - 2, this.currentPage - 1, this.currentPage, this.currentPage + 1, this.currentPage + 2];
            }
        }
    }
    selectPage(selectedPage) {
        const page = +selectedPage;
        if (this.currentPage !== page && page > 0 && page <= this.totalPage) {
            this.currentPage = page;
        }
        this.reload();
        this.generatePaginate();
    }
    accept() {
        var _a;
        const successItems = this.items.filter(item => !item.validation.error && !item.validation.warning);
        const errorItems = this.items.filter(item => item.validation.error);
        const warningItems = this.items.filter(item => !item.validation.error && item.validation.warning);
        (_a = this.option) === null || _a === void 0 ? void 0 : _a.onAccept(this.items, successItems, errorItems, warningItems, this.file);
    }
    downloadTemplate() {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            const excelTemplate = {
                fileName: this.option.fileName || 'Template.xlsx',
                columns: this.option.columns.map(column => {
                    return {
                        field: column.field,
                        title: column.title,
                        width: column.width,
                        required: column.required,
                        description: column.description
                    };
                })
            };
            const result = yield this.excelService.generateExcelTemplate(excelTemplate);
            if ((_a = result) === null || _a === void 0 ? void 0 : _a.filePath) {
                yield this.excelService.downloadTemplate(result.filePath, excelTemplate.fileName || 'Template.xlsx');
            }
        });
    }
};
UploadExcelControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: ExcelService },
    { type: TranslateService },
    { type: NotifyService },
    { type: UtilityService },
    { type: LoadingService }
];
__decorate([
    Input()
], UploadExcelControlComponent.prototype, "option", void 0);
__decorate([
    ViewChild('modal')
], UploadExcelControlComponent.prototype, "modal", void 0);
__decorate([
    ViewChild('uploadExcelConfig', { static: true })
], UploadExcelControlComponent.prototype, "uploadExcelConfig", void 0);
UploadExcelControlComponent = __decorate([
    Component({
        selector: 'sd-upload-excel-control',
        template: "<sd-modal-control [title]=\"'Import Excel' | sdTranslate\" #modal>\r\n  <sd-modal-body background=\"#F0F8FF\">\r\n    <div class=\"row mx-0 mb-2\">\r\n      <sd-button *ngIf=\"items?.length\" class=\"mr-1\" (action)=\"view('ALL')\" icon=\"cached\"\r\n        [title]=\"'View all' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"numberOfSuccess\" class=\"mr-1\" (action)=\"view('SUCCESS')\" icon=\"done\" [title]=\"numberOfSuccess\"\r\n        [tooltip]=\"'Number of success rows' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"numberOfWarning\" class=\"mr-1\" (action)=\"view('WARNING')\" icon=\"warning\"\r\n        [title]=\"numberOfWarning\" [tooltip]=\"'Number of warning rows' | sdTranslate\"></sd-button>\r\n      <sd-button *ngIf=\"numberOfError\" class=\"mr-1\" (action)=\"view('ERROR')\" icon=\"error\" [title]=\"numberOfError\"\r\n        color=\"accent\" [tooltip]=\"'Number of error rows' | sdTranslate\"></sd-button>\r\n    </div>\r\n    <div class=\"sd-box sd-box-primary\">\r\n      <div class=\"sd-box-body p-0\">\r\n        <div class=\"table-responsive\" style=\"position: relative; height:50vh\">\r\n          <table class=\"table table-striped table-sm table-hover table-bordered\">\r\n            <thead class=\"thead-light\">\r\n              <tr>\r\n                <th class=\"text-center position-sticky c-sticky-left\" style=\"width: 50px\">#</th>\r\n                <th *ngFor=\"let column of option.columns\"\r\n                  [ngStyle]=\"{'min-width':column.width ? column.width : '300px'}\">\r\n                  <span class=\"c-ellipsis\"\r\n                    [ngStyle]=\"{'min-width':column.width ? column.width : '300px', 'max-width':column.width ? column.width : '300px'}\">{{column.title}}</span>\r\n                </th>\r\n              </tr>\r\n            </thead>\r\n            <tbody *ngIf=\"items.length\">\r\n              <tr *ngFor=\"let item of viewItems\">\r\n                <td class=\"text-center position-sticky c-sticky-left\" style=\"width: 50px\">\r\n                  <span class=\"badge\"\r\n                    [ngClass]=\"{'badge-success':!item.validation?.warning && !item.validation?.error, 'badge-warning':item.validation?.warning && !item.validation?.error, 'badge-danger':item.validation?.error}\"\r\n                    [matTooltip]=\"item.validation?.error || item.validation?.warning\" matTooltipPosition=\"right\"\r\n                    style=\"width: 100%\" matTooltipClass=\"white-space-pre-line\">{{item.excelIndex}}</span>\r\n                </td>\r\n                <td *ngFor=\"let column of option.columns\" class=\"align-middle\"\r\n                  [ngClass]=\"{'table-warning':item.validation?.data[column.field]?.warning && !item.validation?.data[column.field]?.error, 'table-danger':item.validation?.data[column.field]?.error}\"\r\n                  [matTooltip]=\"item.validation?.data[column.field]?.error || item.validation?.data[column.field]?.warning\"\r\n                  matTooltipPosition=\"above\">\r\n                  <span class=\"c-ellipsis\"\r\n                    [ngStyle]=\"{'min-width':column.width ? column.width : '300px', 'max-width':column.width ? column.width : '300px'}\">\r\n                    <ng-container *ngIf=\"column.type === 'date'\">\r\n                      {{item.validation?.data[column.field]?.error ?  item[column.field] : (item[column.field] | date:'dd/MM/yyyy HH:mm')}}\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"column.type === 'number'\">\r\n                      {{item.validation?.data[column.field]?.error ?  item[column.field] : (item[column.field] | number : '1.0-2')}}\r\n                    </ng-container>\r\n                    <ng-container *ngIf=\"column.type !== 'date' && column.type !== 'number'\">{{item[column.field]}}\r\n                    </ng-container>\r\n                  </span>\r\n                </td>\r\n              </tr>\r\n            </tbody>\r\n          </table>\r\n        </div>\r\n      </div>\r\n      <div class=\"sd-box-footer clearfix\">\r\n        <div class=\"row mr-0 ml-0 text-right pull-right\">\r\n          <ul class=\"pagination pagination-primary m-0\">\r\n            <li class=\"page-item cursor-pointer\" *ngIf=\"currentPage > 1\" placement=\"top\" ngbTooltip=\"Previous\"\r\n              (click)=\"selectPage(currentPage-1)\">\r\n              <a class=\"page-link\">\r\n                {{'Previous' | sdTranslate | uppercase}}\r\n              </a>\r\n            </li>\r\n            <li class=\"page-item cursor-pointer\" [ngClass]=\"{'active':page === currentPage}\" *ngFor=\"let page of pages\"\r\n              (click)=\"selectPage(page)\">\r\n              <a class=\"page-link\">{{page}}</a>\r\n            </li>\r\n            <li class=\"page-item cursor-pointer\" *ngIf=\"currentPage < totalPage\" placement=\"top\" ngbTooltip=\"Next\"\r\n              (click)=\"selectPage(currentPage+1)\">\r\n              <a class=\"page-link\">\r\n                {{'Next' | sdTranslate | uppercase}}\r\n              </a>\r\n            </li>\r\n          </ul>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer *sdDesktop>\r\n    <div class=\"mr-auto\">\r\n      <sd-button class=\"mr-1\" (action)=\"upload()\" icon=\"publish\" [title]=\"'Upload' | sdTranslate\"></sd-button>\r\n      <sd-button class=\"mr-1\" (action)=\"downloadTemplate()\" icon=\"get_app\" [title]=\"'Download' | sdTranslate\">\r\n      </sd-button>\r\n    </div>\r\n    <sd-button (action)=\"accept()\" icon=\"check\" [title]=\"'Accept' | sdTranslate\"\r\n      [disabled]=\"numberOfSuccess === 0 || numberOfError > 0\" color=\"primary\"></sd-button>\r\n  </sd-modal-footer>\r\n  <sd-modal-footer *sdMobileTablet>\r\n    <sd-button style=\"flex: 1; padding-right: 5px;\" (action)=\"upload()\" icon=\"publish\" [title]=\"'Upload' | sdTranslate\"\r\n      width=\"100%\"></sd-button>\r\n    <sd-button style=\"flex: 1; padding-left: 5px;\" (action)=\"accept()\" icon=\"check\" [title]=\"'Accept' | sdTranslate\"\r\n      color=\"primary\" width=\"100%\"></sd-button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>\r\n<sd-upload-excel-config (change)=\"loadConfig($event)\" #uploadExcelConfig></sd-upload-excel-config>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".pagination>li>a{border:0;border-radius:24px!important;transition:.3s;padding:0 9px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>span{border:0;border-radius:24px!important;transition:.3s;padding:0 8px;margin:0 3px;min-width:16px;height:25px;line-height:25px;color:#919191;font-weight:400;font-size:11px;text-transform:uppercase;background:0 0}.pagination>li>a:focus,.pagination>li>a:hover,.pagination>li>span:focus,.pagination>li>span:hover{z-index:3;color:#23527c;background-color:#eee;border-color:#ddd}.pagination>.active>a,.pagination>.active>a:focus,.pagination>.active>a:hover,.pagination>.active>span,.pagination>.active>span:focus,.pagination>.active>span:hover{background-color:#c82c37;border-color:#c82c37;color:#fff;box-shadow:0 4px 5px 0 rgba(156,39,176,.14),0 1px 10px 0 rgba(156,39,176,.12),0 2px 4px -1px rgba(156,39,176,.2)}.pagination.pagination-info>.active>a,.pagination.pagination-info>.active>a:focus,.pagination.pagination-info>.active>a:hover,.pagination.pagination-info>.active>span,.pagination.pagination-info>.active>span:focus,.pagination.pagination-info>.active>span:hover{background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 4px 5px 0 rgba(0,188,212,.14),0 1px 10px 0 rgba(0,188,212,.12),0 2px 4px -1px rgba(0,188,212,.2)}.pagination.pagination-success>.active>a,.pagination.pagination-success>.active>a:focus,.pagination.pagination-success>.active>a:hover,.pagination.pagination-success>.active>span,.pagination.pagination-success>.active>span:focus,.pagination.pagination-success>.active>span:hover{background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.pagination.pagination-warning>.active>a,.pagination.pagination-warning>.active>a:focus,.pagination.pagination-warning>.active>a:hover,.pagination.pagination-warning>.active>span,.pagination.pagination-warning>.active>span:focus,.pagination.pagination-warning>.active>span:hover{background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.pagination.pagination-danger>.active>a,.pagination.pagination-danger>.active>a:focus,.pagination.pagination-danger>.active>a:hover,.pagination.pagination-danger>.active>span,.pagination.pagination-danger>.active>span:focus,.pagination.pagination-danger>.active>span:hover{background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".table thead td,.table thead th{padding-top:5px;padding-bottom:5px}.table-striped tbody tr:nth-of-type(even) .c-sticky-left{background-color:#fff}.table-striped tbody tr:nth-of-type(odd) .c-sticky-left{background-color:#f2f2f2}.c-sticky-left{z-index:20;left:0!important;border-left:none!important;border-right:none!important}.c-ellipsis{white-space:nowrap;overflow:hidden!important;text-overflow:ellipsis;display:block;padding:.1rem}"]
    })
], UploadExcelControlComponent);

let TextareaControlComponent = class TextareaControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.name = v4();
        this.modelChange = new EventEmitter();
    }
    set model(value) {
        this.ref.detectChanges();
        // setTimeout(() => {
        //     this._model = value;
        // }, 0);
        this._model = value;
    }
    ngAfterViewInit() {
        if (this.form && this.formModel) {
            this.form.addControl(this.formModel);
        }
    }
    ngOnDestroy() {
        if (this.form && this.formModel) {
            this.form.removeControl(this.formModel);
        }
    }
    onChange(value) {
        this._model = value;
        this.modelChange.emit(this._model);
    }
};
TextareaControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], TextareaControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "model", null);
__decorate([
    Output()
], TextareaControlComponent.prototype, "modelChange", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "maxlength", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "pattern", void 0);
__decorate([
    Input()
], TextareaControlComponent.prototype, "disabled", void 0);
__decorate([
    ViewChild('formModel')
], TextareaControlComponent.prototype, "formModel", void 0);
TextareaControlComponent = __decorate([
    Component({
        selector: 'sd-textarea-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <textarea class=\"sd-input\" #formModel=\"ngModel\" [name]=\"name\" matInput placeholder=\"{{label}}\" [ngModel]=\"_model\" (ngModelChange)=\"onChange($event)\" [required]=\"required\" [disabled]=\"disabled\" autocomplete=\"off\"></textarea>\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}"]
    })
], TextareaControlComponent);

let AutocompleteControlComponent = class AutocompleteControlComponent {
    constructor(ref, utilityService) {
        this.ref = ref;
        this.utilityService = utilityService;
        this.initialized = false;
        this.pItems = [];
        this.flag = false;
        this.previousResults = [];
        this.delay = 500; // Sau khoảng thời gian delay nếu không có thay đổi thì thì mới bắt đầu thực hiện gọi hàm
        this.isServerFilter = false;
        this.name = v4();
        this.loading = false;
        // tslint:disable-next-line: variable-name
        this.cItems = [];
        this.limit = 100;
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.onChanges = (searchText) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            this.cModel = this.pModel;
            let items = [];
            if (typeof (this.pItems) === 'function') {
                items = yield this.loadItems(searchText, this.pItems);
            }
            else {
                items = this.pItems;
            }
            if (this.flag || (!this.valueField && !this.displayField)) {
                this.cItems = items.map(e => ({
                    code: e
                }));
                this.flag = true;
                this.valueField = 'code';
                this.displayField = 'code';
            }
            else {
                this.cItems = items;
            }
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
            this.ref.detectChanges();
        });
        this.loadItems = (searchText, items) => __awaiter(this, void 0, void 0, function* () {
            this.previous = new Date();
            yield new Promise(resolve => setTimeout(resolve, this.delay));
            const now = new Date();
            const dif = now.getTime() - this.previous.getTime();
            if (dif < this.delay) {
                return this.previousResults;
            }
            this.loading = true;
            this.previousResults = yield items(searchText).finally(() => this.loading = false);
            return this.previousResults;
        });
        this.onChange = (item) => {
            if (typeof item !== 'string') {
                this.cModel = item ? item[this.valueField] : undefined;
                this.modelChange.emit(this.cModel);
                this.change.emit(item);
                this.sdChange.emit(item);
            }
            else {
                if (!item) {
                    this.clear();
                }
                this.onChanges(item);
            }
        };
        this.filter = (value) => {
            const items = this.cItems;
            if (!this.name || this.isServerFilter) {
                return this.cItems.filter((item, index) => index < this.limit);
            }
            return this.cItems
                .filter(item => {
                return this.utilityService.changeAliasLowerCase(item[this.displayField])
                    .indexOf(this.utilityService.changeAliasLowerCase(value)) !== -1;
            }).filter((item, index) => index < this.limit);
        };
        this.displayFn = (value) => {
            if (typeof value === 'string') {
                if (!this.cItems) {
                    return value;
                }
                const selectedItem = this.cItems.find(item => item[this.valueField] === value);
                if (selectedItem) {
                    return selectedItem[this.displayField];
                }
                return value;
            }
            else {
                return value ? value[this.displayField] : undefined;
            }
        };
        this.clear = ($event) => {
            var _a, _b;
            (_a = $event) === null || _a === void 0 ? void 0 : _a.stopPropagation();
            this.cModel = undefined;
            this.modelChange.emit(this.cModel);
            this.change.emit(this.cModel);
            this.sdChange.emit(this.cModel);
            this.formModel.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
            if ($event) {
                (_b = this.autocompleteTrigger) === null || _b === void 0 ? void 0 : _b.openPanel();
            }
        };
        this.reValidate = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
    }
    set items(items) {
        this.pItems = items || [];
        this.isServerFilter = !Array.isArray(this.pItems);
        if (this.initialized) {
            this.onChanges().then(() => { var _a, _b; return (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue((_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.value); });
        }
    }
    set model(value) {
        this.pModel = value;
        if (this.initialized) {
            this.onChanges(value).then(() => { var _a; return (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue(value); });
        }
    }
    ngOnInit() {
        this.filteredItems = this.formModel.valueChanges.pipe(startWith(''), map(item => typeof item === 'string' ? item : (item ? item[this.displayField] : '')), map(this.filter));
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges(this.pModel).then(() => { var _a; return (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue(this.pModel); });
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
};
AutocompleteControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: UtilityService }
];
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "items", null);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "limit", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "model", null);
__decorate([
    Output()
], AutocompleteControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], AutocompleteControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], AutocompleteControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], AutocompleteControlComponent.prototype, "disabled", void 0);
__decorate([
    ViewChild('formModel', { static: true })
], AutocompleteControlComponent.prototype, "formModel", void 0);
__decorate([
    ViewChild(MatAutocompleteTrigger, { read: MatAutocompleteTrigger })
], AutocompleteControlComponent.prototype, "autocompleteTrigger", void 0);
AutocompleteControlComponent = __decorate([
    Component({
        selector: 'sd-autocomplete-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input class=\"sd-input\" #autocompleteTrigger #formModel=\"ngModel\" [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\" [name]=\"name\" placeholder=\"{{label}}\" [matAutocomplete]=\"auto\" [required]=\"required\" [disabled]=\"disabled\" matInput autocomplete=\"off\">\r\n  <!-- <mat-icon *ngIf=\"type !== 'time'\" matSuffix>date_range</mat-icon>\r\n  <mat-icon *ngIf=\"type === 'time'\" matSuffix>schedule</mat-icon> -->\r\n  \r\n  <!-- <i *ngIf=\"!loading && !cModel && !disabled\" matSuffix class=\"fa fa-search fa-fw\"></i> -->\r\n  <!-- <i *ngIf=\"!loading && cModel && !disabled\" matSuffix class=\"fa fa-times fa-fw text-danger\" (click)=\"clear($event)\" style=\"cursor: pointer;\"></i> -->\r\n  <mat-icon *ngIf=\"!loading && !cModel && !disabled\" matSuffix>search</mat-icon>\r\n  <mat-icon *ngIf=\"!loading && cModel && !disabled\" class=\"cursor-pointer\" (click)=\"clear($event)\" matSuffix>close</mat-icon>\r\n  <mat-spinner *ngIf=\"loading\" matSuffix></mat-spinner>\r\n  <!-- <i *ngIf=\"loading\" matSuffix class=\"fa fa-spinner fa-spin\"></i> -->\r\n  <mat-autocomplete #auto=\"matAutocomplete\" [displayWith]=\"displayFn\">\r\n    <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\">\r\n      {{item[displayField]}}\r\n    </mat-option>\r\n  </mat-autocomplete>\r\n  <mat-error *ngIf=\"formModel?.errors?.required\">\r\n    {{'This field is required' | sdTranslate}}\r\n  </mat-error>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}"]
    })
], AutocompleteControlComponent);

const MobileMaxWidth = 767;
const IsMobile = window.innerWidth < MobileMaxWidth;

// Document: https://xdsoft.net/jqplugins/datetimepicker/
let GridDatePickerControlComponent = class GridDatePickerControlComponent {
    constructor(ref, datePipe) {
        this.ref = ref;
        this.datePipe = datePipe;
        this.isMobile = window.innerWidth < MobileMaxWidth;
        this.initialized = false;
        this.type = 'datetime';
        this.sdChange = new EventEmitter();
        this.modelChange = new EventEmitter();
        this.onFocus = () => {
            if (this.isMobile) {
                // tslint:disable-next-line: deprecation
                $$1(this.control.nativeElement).blur();
            }
        };
        this.onChanges = () => {
            this.date = this.pDate;
        };
    }
    set model(val) {
        if (!Date.isDate(val)) {
            this.pDate = null;
        }
        else {
            if (this.type === 'datetime') {
                this.pDate = this.datePipe.transform(val, 'dd/MM/yyyy HH:mm');
            }
            else if (this.type === 'date') {
                this.pDate = this.datePipe.transform(val, 'dd/MM/yyyy');
            }
            else {
                this.pDate = this.datePipe.transform(val, 'HH:mm');
            }
        }
        if (this.initialized) {
            this.onChanges();
        }
        this.ref.detectChanges();
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        this.onChanges();
        this.initialized = true;
        this.setOption();
    }
    setOption() {
        if (this.initialized) {
            $$1(this.control.nativeElement).datetimepicker({
                datepicker: this.type === 'datetime' || this.type === 'date',
                timepicker: this.type === 'datetime' || this.type === 'time',
                format: this.type === 'datetime' ? 'd/m/Y H:i' : (this.type === 'date' ? 'd/m/Y' : 'H:i'),
                step: 15,
                scrollMonth: false,
                scrollTime: false,
                scrollInput: false,
                onChangeDateTime: (date) => {
                    if (!date && !this.date) {
                        return;
                    }
                    date = Date.toFormat(date, 'dd/MM/yyyy HH:mm');
                    if (!this.equal(date, this.date)) {
                        this.model = this.parse(date);
                        this.modelChange.emit(this.parse(date));
                        this.sdChange.emit(this.parse(date));
                        this.ref.detectChanges();
                    }
                }
            });
        }
    }
    parse(date) {
        if (this.type === 'date') {
            return Date.parseFrom(date, 'dd/MM/yyyy');
        }
        else if (this.type === 'time') {
            return Date.parseFrom(date, 'HH:mm');
        }
        return Date.parseFrom(date, 'dd/MM/yyyy HH:mm');
    }
    equal(date1, date2) {
        return Date.equal(this.parse(date1), this.parse(date2));
    }
};
GridDatePickerControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DatePipe }
];
__decorate([
    Input()
], GridDatePickerControlComponent.prototype, "type", void 0);
__decorate([
    Output()
], GridDatePickerControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], GridDatePickerControlComponent.prototype, "model", null);
__decorate([
    Output()
], GridDatePickerControlComponent.prototype, "modelChange", void 0);
__decorate([
    ViewChild('control')
], GridDatePickerControlComponent.prototype, "control", void 0);
GridDatePickerControlComponent = __decorate([
    Component({
        selector: 'sd-grid-date-picker-control',
        template: "<div class=\"w-100 c-container\">\r\n  <input #control class=\"form-control c-input-xs\" [ngModel]=\"date\" (focus)=\"onFocus()\">\r\n  <i class=\"fa c-icon\" [ngClass]=\"{'fa-clock-o':type === 'time', 'fa-calendar':type !== 'time'}\"></i>\r\n</div>",
        styles: [".c-container{position:relative}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}.c-icon{position:absolute;top:7px;right:7px;font-size:13px!important}"]
    })
], GridDatePickerControlComponent);

let Login01Component = class Login01Component {
    constructor() {
        this.loginForm = new FormGroup({
            username: new FormControl('', [Validators.required]),
            password: new FormControl('', [Validators.required]),
            rememberme: new FormControl(true)
        });
        this.textSignIn = 'SIGN IN';
        this.textUsername = 'Username';
        this.textPassword = 'Password';
        this.textRememberMe = 'Remember me';
        this.textLoginButton = 'Login';
        this.textForgotPassword = 'Forgot Password?';
        this.textCreateAccount = 'Create Account';
        this.textCopyRight = '2018 © SuperDev Angular Core';
        this.onLogin = new EventEmitter();
        this.onForgotPassword = new EventEmitter();
        this.onCreateAccount = new EventEmitter();
    }
    ngOnInit() {
    }
    login() {
        this.onLogin.emit({
            username: this.loginForm.value.username,
            password: this.loginForm.value.password,
            rememberme: this.loginForm.value.rememberme
        });
    }
    forgotPassword() {
        this.onForgotPassword.emit();
    }
    createAccount() {
        this.onCreateAccount.emit();
    }
};
__decorate([
    Input()
], Login01Component.prototype, "logoUrl", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textSignIn", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textUsername", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textPassword", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textRememberMe", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textLoginButton", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textForgotPassword", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textCreateAccount", void 0);
__decorate([
    Input()
], Login01Component.prototype, "textCopyRight", void 0);
__decorate([
    Output()
], Login01Component.prototype, "onLogin", void 0);
__decorate([
    Output()
], Login01Component.prototype, "onForgotPassword", void 0);
__decorate([
    Output()
], Login01Component.prototype, "onCreateAccount", void 0);
Login01Component = __decorate([
    Component({
        selector: 'sd-login01',
        template: "<div style=\"height:100vh; width: 100vw; position:fixed\" class=\"sd-login\">\r\n  <div class=\"menu-toggler sidebar-toggler\"></div>\r\n  <!-- END SIDEBAR TOGGLER BUTTON -->\r\n  <!-- BEGIN LOGO -->\r\n  <div *ngIf=\"logoUrl\" class=\"sd-logo\">\r\n    <a href=\"javascript:;\"> <img [src]=\"logoUrl\" alt=\"SuperDev\" /> </a>\r\n  </div>\r\n  <!-- END LOGO -->\r\n  <!-- BEGIN LOGIN -->\r\n  <div class=\"content\">\r\n    <!-- BEGIN LOGIN FORM -->\r\n    <form class=\"sd-login-form\" [formGroup]=\"loginForm\" (ngSubmit)=\"login()\">\r\n      <h3 class=\"sd-form-title font-green\">{{textSignIn}}</h3>\r\n      <div class=\"form-group\">\r\n        <input class=\"form-control form-control-solid placeholder-no-fix\" type=\"text\" placeholder=\"{{textUsername}}\"\r\n          formControlName=\"username\" /></div>\r\n      <div class=\"form-group\">\r\n        <input class=\"form-control form-control-solid placeholder-no-fix\" type=\"password\" placeholder=\"{{textPassword}}\"\r\n          formControlName=\"password\" /> </div>\r\n      <div class=\"custom-control custom-checkbox\">\r\n        <input type=\"checkbox\" class=\"custom-control-input\" formControlName=\"rememberme\">\r\n        <label class=\"custom-control-label\">{{textRememberMe}}</label>\r\n      </div>\r\n      <div class=\"form-actions\">\r\n        <button type=\"submit\" class=\"btn green uppercase\" [disabled]=\"loginForm.invalid\">{{textLoginButton}}</button>\r\n        <a *ngIf=\"onForgotPassword.observers.length\" (click)=\"forgotPassword()\" href=\"javascript:;\" class=\"forget-password\">{{textForgotPassword}}</a>\r\n      </div>\r\n      <div *ngIf=\"onCreateAccount.observers.length\" class=\"create-account\">\r\n        <p>\r\n          <a (click)=\"createAccount()\" href=\"javascript:;\" class=\"uppercase\">Create Account</a>\r\n        </p>\r\n      </div>\r\n    </form>\r\n    <!-- END LOGIN FORM -->\r\n  </div>\r\n  <div class=\"copyright\"> {{textCopyRight}} </div>\r\n</div>",
        styles: [".sd-login{background-color:#dcdee0!important}.sd-login .sd-logo{margin:60px auto 0;padding:15px;text-align:center}.sd-login .content{background-color:#eceef1;border-radius:7px;width:400px;margin:40px auto 10px;padding:10px 30px 30px;overflow:hidden;position:relative}.sd-login .content h3{margin-top:20px;color:#4db3a5;text-align:center;font-size:28px;font-weight:400!important}.sd-login .content .form-control{border:1px solid #dde3ec;background-color:#dde3ec;height:43px;color:#8290a3}.login .content .form-control:active,.sd-login .content .form-control:focus{border:1px solid #c3ccda}.sd-login .content .form-control::-moz-placeholder{color:#8290a3;opacity:1}.sd-login .content .form-control:-ms-input-placeholder{color:#8290a3}.sd-login .content .form-control::-webkit-input-placeholder{color:#8290a3}.sd-login .content .sd-form-title{text-transform:uppercase;font-weight:300;margin-bottom:25px}.sd-login .content .form-actions{clear:both;border:0;border-bottom:1px solid #eee;padding:25px 30px;margin-left:-30px;margin-right:-30px}.sd-login .content .form-actions .btn{margin-top:1px;font-weight:600;padding:10px 20px!important}.sd-login .content .forget-password{margin-top:10px;font-size:14px;float:right}.sd-login .content .create-account{margin:0 -40px -30px;padding:15px 0 17px;text-align:center;background-color:#6c7a8d;border-radius:0 0 7px 7px}.sd-login .content .create-account>p{margin:0}.sd-login .content .create-account p a{font-weight:600;font-size:14px;color:#c3cedd}.sd-login .content .create-account a{display:inline-block;margin-top:5px}.sd-login .copyright{text-align:center;margin:0 auto 30px 0;padding:10px;color:#7a8ca5;font-size:13px}@media (max-width:440px){.sd-login .sd-logo{margin-top:10px}.sd-login .content{width:280px;margin-top:10px}.sd-login .content h3{font-size:22px}.sd-login .checkbox{font-size:13px}}.uppercase{text-transform:uppercase!important}a{text-shadow:none;color:#337ab7}.btn{outline:0!important;font-size:12px;transition:box-shadow .28s cubic-bezier(.4,0,.2,1);box-shadow:0 1px 3px rgba(0,0,0,.1),0 1px 2px rgba(0,0,0,.18);border-radius:2px;border-width:0!important;overflow:hidden;position:relative;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;padding:9px 14px 8px}.btn:disabled{opacity:.65;cursor:not-allowed}.btn.green{color:#fff;background-color:#32c5d2;border-color:#32c5d2}.btn.green:active,.btn.green:focus,.btn.green:hover{color:#fff;background-color:#26a1ab;border-color:#26a1ab}"]
    })
], Login01Component);

let CheckboxControlComponent = class CheckboxControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.color = 'primary';
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.modelChange = new EventEmitter();
    }
    set model(value) {
        this.ref.detectChanges();
        this._model = value;
    }
    onChange() {
        this.modelChange.emit(this._model);
        this.change.emit(this._model);
        this.sdChange.emit(this._model);
    }
};
CheckboxControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], CheckboxControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], CheckboxControlComponent.prototype, "color", void 0);
__decorate([
    Input()
], CheckboxControlComponent.prototype, "disabled", void 0);
__decorate([
    Output()
], CheckboxControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], CheckboxControlComponent.prototype, "sdChange", void 0);
__decorate([
    Input()
], CheckboxControlComponent.prototype, "model", null);
__decorate([
    Output()
], CheckboxControlComponent.prototype, "modelChange", void 0);
CheckboxControlComponent = __decorate([
    Component({
        selector: 'sd-checkbox-control',
        template: "<mat-checkbox [(ngModel)]=\"_model\" (change)=\"onChange()\" [disabled]=\"disabled\" [color]=\"color\"><span class=\"sd-label\">{{label}}</span></mat-checkbox>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}"]
    })
], CheckboxControlComponent);

let SwitchControlComponent = class SwitchControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.color = 'primary';
        this.modelChange = new EventEmitter();
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
    }
    set model(value) {
        this.ref.detectChanges();
        this.cModel = value;
    }
    ngOnInit() {
    }
    onChange(value) {
        this.cModel = value;
        this.modelChange.emit(this.cModel);
        this.change.emit(this.cModel);
        this.sdChange.emit(this.cModel);
    }
};
SwitchControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], SwitchControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], SwitchControlComponent.prototype, "color", void 0);
__decorate([
    Input()
], SwitchControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], SwitchControlComponent.prototype, "model", null);
__decorate([
    Output()
], SwitchControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], SwitchControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], SwitchControlComponent.prototype, "sdChange", void 0);
SwitchControlComponent = __decorate([
    Component({
        selector: 'sd-switch-control',
        template: "<mat-slide-toggle [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\" [disabled]=\"disabled\" [color]=\"color\"><span class=\"sd-label\">{{label}}</span></mat-slide-toggle>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}"]
    })
], SwitchControlComponent);

let RadioControlComponent = class RadioControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.initialized = false;
        this.pItems = [];
        this.name = v4();
        this.valueField = 'value';
        this.displayField = 'display';
        this.display = 'row';
        // tslint:disable-next-line: variable-name
        this._items = [];
        // Optional
        this.required = false;
        this.disabled = false;
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.onChanges = () => {
            this._items = this.pItems;
            this._model = this.pModel;
            if (!this._model && this.required && this._items.length > 0) {
                setTimeout(() => {
                    this.onChange(this._items[0][this.valueField]);
                });
            }
        };
    }
    get items() {
        return this._items;
    }
    set items(items) {
        if (!Array.isArray(items)) {
            items = [];
        }
        this.pItems = items;
        if (this.initialized) {
            this.onChanges();
        }
    }
    set model(value) {
        this.pModel = value || '';
        if (this.initialized) {
            this.onChanges();
        }
    }
    // @ViewChild('formModel') formModel: NgModel;
    ngAfterViewInit() {
        this.onChanges();
        this.initialized = true;
        this.ref.detectChanges();
    }
    onChange(value) {
        this._model = value;
        this.modelChange.emit(this._model);
        this.change.emit(this._model);
    }
};
RadioControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], RadioControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "display", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "items", null);
__decorate([
    Input()
], RadioControlComponent.prototype, "model", null);
__decorate([
    Input()
], RadioControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], RadioControlComponent.prototype, "disabled", void 0);
__decorate([
    Output()
], RadioControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], RadioControlComponent.prototype, "change", void 0);
RadioControlComponent = __decorate([
    Component({
        selector: 'sd-radio-control',
        template: "<section [ngClass]=\"{'c-section': display == 'row'}\">\r\n  <label *ngIf=\"label\" class=\"sd-label d-block mr-2\">{{label}} </label>\r\n  <mat-radio-group [disabled]=\"disabled\" [ngClass]=\"{'c-radio-group-column': display == 'column', 'c-radio-group-row': display == 'row'}\" [ngModel]=\"_model\" (ngModelChange)=\"onChange($event)\" [name]=\"name\">\r\n    <mat-radio-button *ngIf=\"!required\" color=\"warn\" [ngClass]=\"{'m-0': display == 'column', 'mr-4': display == 'row'}\" value=\"\">\r\n      {{'All' | sdTranslate}}\r\n    </mat-radio-button>\r\n    <mat-radio-button color=\"primary\" [ngClass]=\"{'m-0': display == 'column', 'mr-4': display == 'row'}\" *ngFor=\"let item of _items\" [value]=\"item[valueField]\">\r\n      {{item[displayField]}}\r\n    </mat-radio-button>\r\n  </mat-radio-group>\r\n</section>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", ".c-section{align-content:center;align-items:center}.c-radio-group-column{display:flex;flex-direction:column}.c-radio-group-row{display:flex;flex-direction:row}"]
    })
], RadioControlComponent);

let SettingService = class SettingService {
    constructor(configurationService) {
        this.configurationService = configurationService;
        this.cache = {};
        this.getKey = (key) => {
            var _a;
            if (!key) {
                throw new Error(`[Setting Service] key is required`);
            }
            const hashedKey = typeof (key) === 'string' ? key : hash__default(key);
            if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.convertKey) {
                return this.configuration.convertKey(hashedKey);
            }
            return hashedKey;
        };
    }
    init() {
        this.configuration = this.configurationService.getSettingConfiguration();
    }
    hasKey(key) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            try {
                const hashKey = this.getKey(key);
                if (this.cache[hashKey] === undefined) {
                    let result = localStorage.getItem(hashKey);
                    if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.get) {
                        result = yield this.configuration.get(hashKey);
                    }
                    if (!result) {
                        this.cache[hashKey] = null;
                    }
                    else {
                        this.cache[hashKey] = JSON.parse(result);
                    }
                }
                return !!this.cache[hashKey];
            }
            catch (err) {
                console.error(`[SETTING HASKEY] ${err}`);
                return null;
            }
        });
    }
    set(key, value, args) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            const hashKey = this.getKey(key);
            if (hashKey) {
                localStorage.setItem(hashKey, JSON.stringify(value));
                if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.set) {
                    yield this.configuration.set(hashKey, value, args);
                }
                this.cache[hashKey] = value;
            }
        });
    }
    get(key, args) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            try {
                const hashKey = this.getKey(key);
                if (this.cache[hashKey] === undefined) {
                    let result = localStorage.getItem(hashKey);
                    if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.get) {
                        result = yield this.configuration.get(hashKey, args);
                    }
                    if (!result) {
                        this.cache[hashKey] = null;
                    }
                    else {
                        this.cache[hashKey] = JSON.parse(result);
                    }
                }
                return this.cache[hashKey];
            }
            catch (err) {
                console.error(`[SETTING GET] ${err}`);
                return null;
            }
        });
    }
    remove(key, args) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.init();
            const hashKey = typeof (key) === 'string' ? key : hash__default(key);
            if (hashKey) {
                localStorage.removeItem(hashKey);
                if ((_a = this.configuration) === null || _a === void 0 ? void 0 : _a.remove) {
                    yield this.configuration.remove(hashKey, args);
                }
                this.cache[hashKey] = null;
            }
        });
    }
};
SettingService.ctorParameters = () => [
    { type: ConfigurationService }
];
SettingService = __decorate([
    Injectable()
], SettingService);

let GridConfigComponent = class GridConfigComponent {
    constructor(ref, notifyService, settingService, translateService) {
        this.ref = ref;
        this.notifyService = notifyService;
        this.settingService = settingService;
        this.translateService = translateService;
        this.isMobile = window.innerWidth < MobileMaxWidth;
        this.sdChange = new EventEmitter();
    }
    ngOnInit() {
    }
    setOption(option) {
        return __awaiter(this, void 0, void 0, function* () {
            this.ref.detectChanges();
            this.option = option;
            yield this.init();
            this.emitOnChange();
        });
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.option.key) {
                const storage = yield this.settingService.get(this.option.key).catch(() => undefined);
                try {
                    if (!storage) {
                        this.settingService.remove(this.option.key).catch(console.error);
                        this.initDefault();
                        return;
                    }
                    this.storage = storage;
                    // Loại bỏ những column đã bị xóa khỏi originColumns
                    this.storage.columnConfigs = this.storage.columnConfigs
                        .filter(column => this.option.columns.some(e => e.field === column.originColumn.field));
                    // Thêm những column mới vào storage nếu có
                    this.option.columns.forEach(column => {
                        if (!this.storage.columnConfigs.some(e => e.originColumn.field === column.field)) {
                            this.storage.columnConfigs.push({
                                originColumn: {
                                    field: column.field,
                                    title: column.title,
                                    width: column.width,
                                    fixed: column.fixed
                                },
                                hidden: false,
                                fixed: column.fixed
                            });
                        }
                    });
                    // Cập nhật originColumn
                    this.storage.columnConfigs.forEach(column => {
                        const originColumn = this.option.columns.find(e => e.field === column.originColumn.field);
                        if (originColumn) {
                            Object.assign(column.originColumn, {
                                title: originColumn.title,
                                width: originColumn.width,
                                fixed: originColumn.fixed
                            });
                        }
                    });
                }
                catch (ex) {
                    this.settingService.remove(this.option.key).catch(console.error);
                    this.initDefault();
                }
            }
            else {
                this.initDefault();
            }
        });
    }
    initDefault() {
        this.storage = {};
        this.storage.pageSize = this.option.pageSize;
        this.storage.columnConfigs = [];
        this.option.columns.forEach(column => {
            this.storage.columnConfigs.push({
                originColumn: {
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    fixed: column.fixed
                },
                hidden: false,
                fixed: column.fixed
            });
        });
    }
    open() {
        this.modal.open();
    }
    save() {
        if (!Number.isSafeInteger(+this.storage.pageSize)) {
            this.notifyService.notify.warning(this.translateService.translate('Page size must be an integer'));
            return;
        }
        if (this.storage.pageSize > 200) {
            this.notifyService.notify.warning(this.translateService.translate('Page size is too large'));
            return;
        }
        this.settingService.set(this.option.key, this.storage);
        this.emitOnChange();
        this.modal.close();
        this.ref.detectChanges();
    }
    reset() {
        this.settingService.remove(this.option.key);
        this.initDefault();
        // this.reload();
        this.emitOnChange();
        this.modal.close();
        this.ref.detectChanges();
    }
    moveColumnUp(index) {
        const temp = this.storage.columnConfigs[index];
        this.storage.columnConfigs[index] = this.storage.columnConfigs[index - 1];
        this.storage.columnConfigs[index - 1] = temp;
    }
    moveColumnDown(index) {
        const temp = this.storage.columnConfigs[index];
        this.storage.columnConfigs[index] = this.storage.columnConfigs[index + 1];
        this.storage.columnConfigs[index + 1] = temp;
    }
    emitOnChange() {
        const pageSize = +this.storage.pageSize || this.option.pageSize;
        const columns = this.option.columns.filter(column => {
            // Hidden column theo config
            // Lấy các thuộc tính Title, Width, Fixed từ config
            const columnConfig = this.storage.columnConfigs.find(e => e.originColumn.field === column.field);
            if (columnConfig) {
                column.title = columnConfig.title || column.title;
                column.width = columnConfig.width || column.width;
                column.fixed = columnConfig.fixed;
                return !columnConfig.hidden;
            }
            return true;
        }).sort((current, next) => {
            // Sắp xếp theo config
            const currentIndex = this.storage.columnConfigs.findIndex(e => e.originColumn.field === current.field);
            const nextIndex = this.storage.columnConfigs.findIndex(e => e.originColumn.field === next.field);
            return currentIndex - nextIndex;
        }).filter(column => {
            // Hidden column theo option truyền vào
            if (column.hidden === undefined) {
                return true;
            }
            if (typeof (column.hidden) === 'boolean') {
                return !column.hidden;
            }
            if (typeof (column.hidden) === 'function') {
                return !column.hidden();
            }
            return false;
        });
        const result = {
            pageSize,
            columns,
            fixedColumns: columns.filter(e => e.fixed),
            normalColumns: columns.filter(e => !e.fixed)
        };
        this.sdChange.emit(result);
    }
};
GridConfigComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NotifyService },
    { type: SettingService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridConfigComponent.prototype, "modal", void 0);
__decorate([
    Output()
], GridConfigComponent.prototype, "sdChange", void 0);
GridConfigComponent = __decorate([
    Component({
        selector: 'sd-grid-config',
        template: "<sd-modal-control [title]=\"'Configuration' | sdTranslate\" #modal>\r\n  <sd-modal-body *ngIf=\"storage\">\r\n    <div class=\"row\">\r\n      <div class=\"col-6\">\r\n        <sd-input-control [label]=\"'Page size' | sdTranslate\" [(model)]=\"storage.pageSize\" type=\"number\" step=\"1\">\r\n        </sd-input-control>\r\n      </div>\r\n    </div>\r\n    <div class=\"sd-box sd-box-primary\">\r\n      <div class=\"sd-box-body p-0\">\r\n        <div class=\"table-responsive\">\r\n          <table class=\"table table-striped table-sm table-hover table-bordered mb-1\">\r\n            <thead class=\"thead-light\">\r\n              <tr>\r\n                <th class=\"text-center\" style=\"width: 50px\">#</th>\r\n                <th *ngIf=\"!isMobile\" class=\"text-center\" style=\"width: 80px\"></th>\r\n                <!-- <th class=\"text-uppercase\" style=\"width: 120px\">Field </th> -->\r\n                <th class=\"text-uppercase\">{{'Title' | sdTranslate}}</th>\r\n                <th *ngIf=\"!isMobile\" class=\"text-uppercase\" style=\"width: 80px\">{{'Width' | sdTranslate}}</th>\r\n                <th class=\"text-uppercase\" style=\"width: 80px\">{{'Hidden' | sdTranslate}}</th>\r\n                <th *ngIf=\"!isMobile\" class=\"text-uppercase\" style=\"width: 80px\">{{'Freeze' | sdTranslate}}</th>\r\n              </tr>\r\n            </thead>\r\n            <tbody>\r\n              <tr *ngFor=\"let column of storage.columnConfigs; let idx = index\">\r\n                <td class=\"align-middle text-center\">\r\n                  {{idx+1}}\r\n                </td>\r\n                <td *ngIf=\"!isMobile\" class=\"align-middle text-center\">\r\n                  <button type=\"button\" [disabled]=\"idx==0\" type=\"button\" class=\"c-btn-icon\" placement=\"top\"\r\n                    matTooltip=\"Up\" (click)=\"moveColumnUp(idx)\">\r\n                    <i class=\"fa fa-arrow-up text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                  <button type=\"button\" [disabled]=\"idx==storage.columnConfigs.length-1\" type=\"button\"\r\n                    class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Down\" (click)=\"moveColumnDown(idx)\">\r\n                    <i class=\"fa fa-arrow-down text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                </td>\r\n                <!-- <td class=\"align-middle\">{{column.originColumn.field}}</td> -->\r\n                <td class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.title}}\" [(ngModel)]=\"column.title\"\r\n                    class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td *ngIf=\"!isMobile\" class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.width}}\" [(ngModel)]=\"column.width\"\r\n                    class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td class=\"align-middle text-center\">\r\n                  <mat-slide-toggle [(ngModel)]=\"column.hidden\" color=\"primary\"></mat-slide-toggle>\r\n                </td>\r\n                <td *ngIf=\"!isMobile\" class=\"align-middle text-center\">\r\n                  <mat-slide-toggle [(ngModel)]=\"column.fixed\" color=\"primary\"></mat-slide-toggle>\r\n                </td>\r\n              </tr>\r\n          </table>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer *sdDesktop>\r\n    <sd-button class=\"mr-auto\" (action)=\"reset()\" icon=\"refresh\" [title]=\"'Reset' | sdTranslate\"></sd-button>\r\n    <sd-button (action)=\"save()\" icon=\"save\" [title]=\"'Save' | sdTranslate\" color=\"primary\"></sd-button>\r\n  </sd-modal-footer>\r\n  <sd-modal-footer *sdMobileTablet>\r\n    <sd-button style=\"flex: 1; padding-right: 5px;\" (action)=\"reset()\" icon=\"refresh\" [title]=\"'Reset' | sdTranslate\"\r\n      width=\"100%\"></sd-button>\r\n    <sd-button style=\"flex: 1; padding-left: 5px;\" (action)=\"save()\" icon=\"save\" [title]=\"'Save' | sdTranslate\" color=\"primary\" width=\"100%\"></sd-button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".c-btn-icon{background:0 0!important;border:none;opacity:.8}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.table td,.table th{padding:.2rem!important}"]
    })
], GridConfigComponent);

let CkeditorControlComponent = class CkeditorControlComponent {
    constructor(ref) {
        this.ref = ref;
        this.disabled = false;
        this.required = false;
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.config = {
            entities_latin: false
        };
    }
    set model(value) {
        this.cModel = value;
        this.ref.detectChanges();
    }
    onChange(value) {
        this.model = value;
        this.modelChange.emit(value);
        this.change.emit(value);
        this.sdChange.emit(value);
    }
};
CkeditorControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], CkeditorControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], CkeditorControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], CkeditorControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], CkeditorControlComponent.prototype, "model", null);
__decorate([
    Output()
], CkeditorControlComponent.prototype, "modelChange", void 0);
__decorate([
    Output()
], CkeditorControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], CkeditorControlComponent.prototype, "sdChange", void 0);
CkeditorControlComponent = __decorate([
    Component({
        selector: 'sd-ckeditor-control',
        template: "\r\n<label *ngIf=\"label\" class=\"sd-label d-block\">{{label}} <span *ngIf=\"required\" class=\"text-danger\">*</span></label>\r\n<ckeditor [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\" [config]=\"config\" [readOnly]=\"disabled\"></ckeditor>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", ":host ::ng-deep .ck-editor__editable{min-height:500px}"]
    })
], CkeditorControlComponent);

let TranslatePipe = class TranslatePipe {
    constructor(translateService) {
        this.translateService = translateService;
    }
    transform(value) {
        return this.translateService.translate(value);
    }
};
TranslatePipe.ctorParameters = () => [
    { type: TranslateService }
];
TranslatePipe = __decorate([
    Pipe({
        name: 'sdTranslate'
    })
], TranslatePipe);

let CacheService = class CacheService {
    constructor() {
        this.cache = {};
    }
    set(key, data, group = null) {
        let objHash = null;
        let objGroup = null;
        if (typeof (key) === 'object') {
            objHash = Object.assign({}, key);
            key = hash__default(key);
        }
        if (typeof (group) === 'object') {
            objGroup = Object.assign({}, group);
            group = hash__default(group);
        }
        if (this.has(key) && typeof (this.cache[key].data) === 'object' && typeof (data) === 'object') {
            Object.assign(this.cache[key].data, data);
        }
        else {
            this.cache[key] = {
                objHash,
                objGroup,
                group,
                data
            };
        }
    }
    get(key) {
        if (typeof (key) === 'object') {
            key = hash__default(key);
        }
        if (!this.has(key)) {
            return null;
        }
        return this.cache[key].data;
    }
    has(key) {
        if (typeof (key) === 'object') {
            key = hash__default(key);
        }
        return !!this.cache[key];
    }
    clear() {
        this.cache = {};
    }
    allByGroup(group) {
        if (typeof (group) === 'object') {
            group = hash__default(group);
        }
        const results = [];
        Object.keys(this.cache)
            .filter(key => this.cache[key] && this.cache[key].group === group)
            .forEach(key => results.push(this.cache[key].data));
        return results;
    }
    clearByGroup(group) {
        if (typeof (group) === 'object') {
            group = hash__default(group);
        }
        Object.keys(this.cache).forEach(key => {
            if (this.cache[key].group === group) {
                this.cache[key] = undefined;
            }
        });
    }
};
CacheService = __decorate([
    Injectable()
], CacheService);

let UploadExcelConfigComponent = class UploadExcelConfigComponent {
    constructor(settingService, translateService) {
        this.settingService = settingService;
        this.translateService = translateService;
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
    }
    ngOnInit() {
    }
    setOption(option) {
        return __awaiter(this, void 0, void 0, function* () {
            this.option = option;
            yield this.init();
            this.emitOnChange();
        });
    }
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.option.key && this.settingService.get(this.option.key)) {
                try {
                    this.storage = yield this.settingService.get(this.option.key);
                    if (!this.storage) {
                        // Xóa setting
                        this.settingService.remove(this.option.key);
                        // Lấy setting mặc định
                        this.initDefault();
                        return;
                    }
                    // Loại bỏ những column đã bị xóa khỏi originColumns
                    this.storage.columns = this.storage.columns.filter(column => this.option.columns.some(e => e.field === column.originColumn.field));
                    // Thêm những column mới vào storage nếu có
                    this.option.columns.forEach(column => {
                        if (!this.storage.columns.some(e => e.originColumn.field === column.field)) {
                            this.storage.columns.push({
                                originColumn: {
                                    field: column.field,
                                    title: column.title,
                                    width: column.width,
                                    required: column.required
                                },
                                hidden: false
                            });
                        }
                    });
                    // Cập nhật originColumn
                    this.storage.columns.forEach(column => {
                        const originColumn = this.option.columns.find(e => e.field === column.originColumn.field);
                        if (originColumn) {
                            Object.assign(column.originColumn, {
                                title: originColumn.title,
                                width: originColumn.width
                            });
                        }
                    });
                }
                catch (err) {
                    // Xóa setting
                    this.settingService.remove(this.option.key);
                    // Lấy setting mặc định
                    this.initDefault();
                }
            }
            else {
                this.initDefault(); // Lấy setting mặc định
            }
        });
    }
    initDefault() {
        this.storage = {};
        this.storage.formatDate = '';
        this.storage.columns = [];
        this.option.columns.forEach(column => {
            this.storage.columns.push({
                originColumn: {
                    field: column.field,
                    title: column.title,
                    width: column.width,
                    required: column.required
                },
                hidden: false
            });
        });
    }
    open() {
        this.modal.open();
    }
    save() {
        this.settingService.set(this.option.key, this.storage);
        this.emitOnChange();
        this.modal.close();
    }
    reset() {
        this.settingService.remove(this.option.key);
        this.initDefault();
        // this.reload();
        this.emitOnChange();
        this.modal.close();
    }
    moveColumnUp(index) {
        const temp = this.storage.columns[index];
        this.storage.columns[index] = this.storage.columns[index - 1];
        this.storage.columns[index - 1] = temp;
    }
    moveColumnDown(index) {
        const temp = this.storage.columns[index];
        this.storage.columns[index] = this.storage.columns[index + 1];
        this.storage.columns[index + 1] = temp;
    }
    emitOnChange() {
        const formatDate = this.storage.formatDate || '';
        const columns = this.option.columns.filter(column => {
            // Hidden column theo config
            // Lấy các thuộc tính Title, Width từ config
            const columnConfig = this.storage.columns.find(e => e.originColumn.field === column.field);
            if (columnConfig) {
                column.title = columnConfig.title || this.translateService.translate(columnConfig.originColumn.title);
                column.width = columnConfig.width || columnConfig.originColumn.width;
                return !columnConfig.hidden;
            }
            else {
                return true;
            }
        }).sort((current, next) => {
            // Sắp xếp theo config
            const currentIndex = this.storage.columns.findIndex(e => e.originColumn.field === current.field);
            const nextIndex = this.storage.columns.findIndex(e => e.originColumn.field === next.field);
            return currentIndex - nextIndex;
        });
        const result = {
            formatDate: '',
            // pageSize: pageSize,
            columns
        };
        this.change.emit(result);
    }
};
UploadExcelConfigComponent.ctorParameters = () => [
    { type: SettingService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], UploadExcelConfigComponent.prototype, "modal", void 0);
__decorate([
    Output()
], UploadExcelConfigComponent.prototype, "change", void 0);
UploadExcelConfigComponent = __decorate([
    Component({
        selector: 'sd-upload-excel-config',
        template: "<sd-modal-control width=\"sm\" title=\"Configure Upload Excel\" #modal>\r\n  <sd-modal-body *ngIf=\"storage\">\r\n    <div class=\"row\">\r\n      <div class=\"col-md-12 mt-2\">\r\n        <sd-input-control [(model)]=\"storage.formatDate\"></sd-input-control>\r\n      </div>\r\n    </div>\r\n    <div class=\"sd-box sd-box-primary\">\r\n      <div class=\"sd-box-body p-0\">\r\n        <div class=\"table-responsive\" style=\"height: calc(100vh - 20rem)\">\r\n          <table class=\"table table-striped table-sm table-hover table-bordered\">\r\n            <thead class=\"thead-light\">\r\n              <tr>\r\n                <th class=\"text-center\" style=\"width: 50px\">#</th>\r\n                <th class=\"text-center\" style=\"width: 80px\"></th>\r\n                <th class=\"text-uppercase\" style=\"width: 120px\" translate>Field </th>\r\n                <th class=\"text-uppercase\" translate>Title </th>\r\n                <th class=\"text-uppercase\" style=\"width: 80px\" translate>Width </th>\r\n                <th class=\"text-uppercase\" style=\"width: 80px\" translate>Hidden </th>\r\n              </tr>\r\n            </thead>\r\n            <tbody>\r\n              <tr *ngFor=\"let column of storage.columns; let idx = index\">\r\n                <td class=\"align-middle text-center\">\r\n                  {{idx+1}}\r\n                </td>\r\n                <td class=\"align-middle text-center\">\r\n                  <button type=\"button\" [disabled]=\"idx==0\" type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Up\" (click)=\"moveColumnUp(idx)\">\r\n                    <i class=\"fa fa-arrow-up text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                  <button type=\"button\" [disabled]=\"idx==storage.columns.length-1\" type=\"button\" class=\"c-btn-icon\" placement=\"top\" matTooltip=\"Down\" (click)=\"moveColumnDown(idx)\">\r\n                    <i class=\"fa fa-arrow-down text-primary\" aria-hidden=\"true\"></i>\r\n                  </button>\r\n                </td>\r\n                <td class=\"align-middle\">{{column.originColumn.field}}</td>\r\n                <td class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.title}}\" [(ngModel)]=\"column.title\" class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td class=\"align-middle\">\r\n                  <input type=\"text\" placeholder=\"{{column.originColumn.width}}\" [(ngModel)]=\"column.width\" class=\"form-control form-control-sm\">\r\n                </td>\r\n                <td class=\"align-middle text-center\">\r\n                  <mat-slide-toggle [(ngModel)]=\"column.hidden\" color=\"primary\" [disabled]=\"column.originColumn.required\"></mat-slide-toggle>\r\n                </td>\r\n              </tr>\r\n          </table>\r\n        </div>\r\n      </div>\r\n    </div>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <button type=\"button\" class=\"btn btn-info btn-sm mr-auto\" (click)=\"reset()\">\r\n      <i class=\"fa fa-refresh mr-1\"></i> <span translate>Reset</span></button>\r\n    <button type=\"button\" class=\"btn btn-primary btn-sm\" (click)=\"save()\">\r\n      <i class=\"fa fa-floppy-o mr-1\"></i> <span translate>Save</span></button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".sd-box{position:relative;border-radius:3px;background:#fff;border-top:3px solid #919191;width:100%;box-shadow:0 1px 1px rgba(0,0,0,.1)}.sd-box.sd-box-primary{border-top-color:#c82c37!important}.sd-box.sd-box-success{border-top-color:#4caf50!important}.sd-box.sd-box-info{border-top-color:#00bcd4!important}.sd-box.sd-box-warning{border-top-color:#ff9800!important}.sd-box.sd-box-danger{border-top-color:#f44336!important}.sd-box-header{color:#444;display:block;padding:.5rem;position:relative;border-bottom:1px solid #f4f4f4}.sd-box-header .sd-box-title{display:inline-block;font-size:1.2rem;margin:0;line-height:1}.sd-box-body{padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}.sd-box-footer{border-top:1px solid #f4f4f4;padding:.5rem;background-color:#fff;border-radius:0 0 3px 3px}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", ".c-btn-icon{background:0 0!important;border:none;opacity:.8}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.table td,.table th{padding:.2rem!important}.btn{color:#fff;background-color:#999;border-color:#999;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:hover{color:#fff;background-color:#919191;border-color:#7a7a7a}.btn.btn-sm{font-size:.6875rem}.btn.btn-primary{color:#fff;background-color:#9c27b0;border-color:#9c27b0;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,188,212,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}"]
    })
], UploadExcelConfigComponent);

let GridAutocompleteControl = 
// tslint:disable-next-line: component-class-suffix
class GridAutocompleteControl {
    constructor(ref, utilityService) {
        this.ref = ref;
        this.utilityService = utilityService;
        this.initialized = false;
        this.pItems = [];
        this.flag = false;
        this.name = v4();
        this.cItems = [];
        this.limit = 30;
        this.loading = false;
        this.modelChange = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.search = new EventEmitter();
        this.subcription = new Subscription();
        this.visibility = true;
        this.onChanges = () => {
            this.cModel = this.pModel;
            if (this.flag || (!this.valueField && !this.displayField)) {
                this.cItems = this.pItems.map(e => ({
                    code: e
                }));
                this.flag = true;
                this.valueField = 'code';
                this.displayField = 'code';
            }
            else {
                this.cItems = this.pItems;
            }
            // this.formModel?.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.reload = () => {
            var _a;
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.filter = (value) => {
            let results = this.cItems;
            if (value) {
                results = this.cItems.filter(item => {
                    return this.utilityService.changeAliasLowerCase(item[this.displayField])
                        .indexOf(this.utilityService.changeAliasLowerCase(value)) !== -1;
                });
            }
            return results.filter((item, index) => index < this.limit);
        };
        this.displayFn = (value) => {
            if (typeof value === 'string') {
                if (!this.cItems) {
                    return value;
                }
                const selectedItem = this.cItems.find(item => item[this.valueField] === value);
                if (selectedItem) {
                    return selectedItem[this.displayField];
                }
                return value;
            }
            else {
                return value ? value[this.displayField] : undefined;
            }
        };
        this.clear = ($event) => {
            var _a, _b;
            (_a = $event) === null || _a === void 0 ? void 0 : _a.stopPropagation();
            (_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.setValue(undefined);
        };
    }
    set items(items) {
        var _a, _b, _c, _d;
        if (!items) {
            items = [];
        }
        if (Array.isArray(items)) {
            this.pItems = items || [];
            if (this.initialized) {
                this.onChanges();
                (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue((_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.value);
                this.reload();
            }
        }
        else if ((_c = items) === null || _c === void 0 ? void 0 : _c.pipe) {
            this.subcription.add((_d = items) === null || _d === void 0 ? void 0 : _d.subscribe(values => {
                var _a, _b;
                this.pItems = values || [];
                if (this.initialized) {
                    this.onChanges();
                    (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.setValue((_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.value);
                    this.reload();
                }
            }));
        }
    }
    set model(value) {
        this.pModel = value;
        if (this.initialized) {
            this.onChanges();
            this.reload();
        }
    }
    ngOnInit() {
        this.filteredItems = this.formModel.valueChanges.pipe(startWith(''), map(item => typeof item === 'string' ? item : (item ? item[this.displayField] : '')), map(this.filter));
    }
    ngAfterViewInit() {
        this.onChanges();
        this.reload();
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.subcription) === null || _a === void 0 ? void 0 : _a.unsubscribe();
    }
    onChange(value) {
        var _a;
        if (typeof value !== 'string') {
            this.cModel = value ? value[this.valueField] : undefined;
            this.modelChange.emit(this.cModel);
            this.sdChange.emit(value);
        }
        else {
            if (!value) {
                this.cModel = undefined;
                this.modelChange.emit(this.cModel);
                this.sdChange.emit(this.cModel);
                this.reload();
                (_a = this.autocompleteTrigger) === null || _a === void 0 ? void 0 : _a.openPanel();
                // this.clear();
            }
            this.search.emit(value);
        }
    }
};
GridAutocompleteControl.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: UtilityService }
];
__decorate([
    Input()
], GridAutocompleteControl.prototype, "loading", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "valueField", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "displayField", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "items", null);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "model", null);
__decorate([
    Output()
], GridAutocompleteControl.prototype, "modelChange", void 0);
__decorate([
    Output()
], GridAutocompleteControl.prototype, "sdChange", void 0);
__decorate([
    Output()
], GridAutocompleteControl.prototype, "search", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "required", void 0);
__decorate([
    Input()
], GridAutocompleteControl.prototype, "disabled", void 0);
__decorate([
    ViewChild('formModel', { static: true })
], GridAutocompleteControl.prototype, "formModel", void 0);
__decorate([
    ViewChild(MatAutocompleteTrigger, { read: MatAutocompleteTrigger })
], GridAutocompleteControl.prototype, "autocompleteTrigger", void 0);
GridAutocompleteControl = __decorate([
    Component({
        selector: 'sd-grid-autocomplete-control',
        template: "<div class=\"w-100 c-container\">\r\n  <input #autocompleteTrigger class=\"form-control c-input-xs\" #formModel=\"ngModel\" [ngModel]=\"cModel\" (ngModelChange)=\"onChange($event)\"\r\n    [name]=\"name\" [matAutocomplete]=\"auto\" [required]=\"required\" [disabled]=\"disabled\" autocomplete=\"false\">\r\n  <i *ngIf=\"!cModel; else clearIcon\" class=\"fa fa-search c-icon\"></i>\r\n  <ng-template #clearIcon>\r\n    <i class=\"fa fa-times text-danger c-icon\" (click)=\"clear($event)\" style=\"cursor: pointer;\"></i>\r\n  </ng-template>\r\n</div>\r\n<mat-autocomplete #auto=\"matAutocomplete\" [displayWith]=\"displayFn\" autoActiveFirstOption>\r\n  <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\">\r\n    {{item[displayField]}}\r\n  </mat-option>\r\n</mat-autocomplete>",
        styles: [".c-container{position:relative}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}.c-icon{position:absolute;top:7px;right:7px;font-size:13px!important}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}"]
    })
    // tslint:disable-next-line: component-class-suffix
], GridAutocompleteControl);

let GridPopupEditorComponent = class GridPopupEditorComponent {
    constructor(settingService) {
        this.settingService = settingService;
        this.save = new EventEmitter();
        this.columns = [];
    }
    ngOnInit() {
    }
    setGridOption(gridOption) {
        this.gridOption = gridOption;
    }
    open(item) {
        this.item = item;
        this.columns = this.gridOption.columns.filter(column => item.editorHandler[column.field].visible);
    }
    onCancel() {
        this.modal.close();
    }
    onSave() {
        this.modal.close();
        this.save.emit(this.item);
    }
};
GridPopupEditorComponent.ctorParameters = () => [
    { type: SettingService }
];
__decorate([
    ViewChild('modal')
], GridPopupEditorComponent.prototype, "modal", void 0);
__decorate([
    Output()
], GridPopupEditorComponent.prototype, "save", void 0);
GridPopupEditorComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-editor',
        template: "<sd-modal-control title=\"Configuration\" #modal>\r\n  <sd-modal-body *ngIf=\"item && gridOption?.columns\">\r\n    <form #formEditor=\"ngForm\">\r\n      <ng-template ngFor let-column [ngForOf]=\"columns\">\r\n        <div class=\"row\">\r\n          <div class=\"col-md-4\"></div>\r\n          <div class=\"col-md-8\">\r\n            <sd-input-control *ngIf=\"column.type === 'string'\" [(model)]=\"item[column.field]\"></sd-input-control>\r\n            <sd-input-control *ngIf=\"column.type === 'number'\" [(model)]=\"item[column.field]\" type=\"number\">\r\n            </sd-input-control>\r\n            <sd-select-control *ngIf=\"column.type === 'values'\" [(model)]=\"item[column.field]\" [items]=\"column.values\">\r\n            </sd-select-control>\r\n            <sd-switch-control *ngIf=\"column.type === 'boolean'\" [(model)]=\"item[column.field]\">\r\n            </sd-switch-control>\r\n            <sd-radio-control *ngIf=\"column.type === 'radio'\" [(model)]=\"item[column.field]\" [items]=\"column.values\">\r\n            </sd-radio-control>\r\n          </div>\r\n        </div>\r\n      </ng-template>\r\n    </form>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <button type=\"button\" class=\"btn btn-info btn-sm mr-auto\" (click)=\"onCancel()\">\r\n      <i class=\"fa fa-refresh\"></i> {{'Cancel' | sdTranslate }}</button>\r\n    <button type=\"button\" class=\"btn btn-primary btn-sm\" (click)=\"onSave()\">\r\n      <i class=\"fa fa-floppy-o\"></i> {{'Save' | sdTranslate }}</button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}"]
    })
], GridPopupEditorComponent);

let FilterMobilePipe = class FilterMobilePipe {
    transform(columns, item) {
        // Những giá trị undefined, null và rỗng sẽ bỏ qua khi hiển thị trên mobile
        return columns.filter(column => {
            var _a;
            return (item[column.field] !== undefined
                && item[column.field] !== null
                && item[column.field] !== '')
                || column.htmlTemplate
                || column.type === 'children'
                || (column.type === 'string' && ((_a = column.commands) === null || _a === void 0 ? void 0 : _a.length) > 0);
        });
    }
};
FilterMobilePipe = __decorate([
    Pipe({
        name: 'filterMobile',
        pure: false
    })
], FilterMobilePipe);

let GridPopupFilterComponent = class GridPopupFilterComponent {
    constructor(ref, deviceService, settingService, notifyService, translateService) {
        this.ref = ref;
        this.settingService = settingService;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.keyPrefix = 'PopupFilter';
        this.displayKey = 'SDCUSTOM';
        this.isMobileOrTablet = false;
        this.filterType = 'inline';
        this.key = '';
        this.accept = new EventEmitter();
        this.clear = new EventEmitter();
        this.loadInlineFilter = new EventEmitter();
        this.filter = {};
        this.externalFilter = {};
        this.columns = [];
        this.externalFilters = [];
        this.quickFilters = [];
        this.showInlineFilter = true;
        this.numberOfQuickFiltes = 0;
        this.maxQuickFilters = 5;
        this.select = (quickFilter) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (quickFilter.code === this.selectedCode) {
                delete this.selectedCode;
            }
            else {
                const f1 = JSON.stringify(quickFilter.filter);
                const f2 = JSON.stringify(quickFilter.externalFilter);
                this.selectedCode = (_a = quickFilter) === null || _a === void 0 ? void 0 : _a.code;
                this.filter = JSON.parse(f1);
                this.externalFilter = JSON.parse(f2);
            }
            yield this.updateConfiguration();
        });
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    ngOnInit() {
        this.loadConfiguration().then(() => {
            var _a;
            this.loadInlineFilter.emit({
                showInlineFilter: (_a = this.showInlineFilter, (_a !== null && _a !== void 0 ? _a : true)),
                quickFilters: this.quickFilters || [],
                selectedQuickFilter: this.selectedCode || ''
            });
        });
    }
    ngAfterViewInit() {
    }
    open(fixedColums, normalColumns, filter, externalFilter, externalFilters) {
        this.columns = [...fixedColums, ...normalColumns].filter(e => !e.preventFilter);
        this.columns.forEach(column => {
            if (column.type === 'children') {
                column.children = column.children.filter(e => !e.preventFilter);
            }
        });
        if (externalFilters) {
            this.externalFilters = externalFilters;
            for (const item of this.externalFilters) {
                if (item.type === 'daterange' || item.type === 'numberrange') {
                    this.externalFilter[item.field] = this.externalFilter[item.field] || { from: '', to: '' };
                }
            }
        }
        else {
            this.externalFilters = [];
        }
        this.filter = filter;
        this.externalFilter = externalFilter;
        this.modal.open();
    }
    onAccept() {
        this.accept.emit({
            filter: this.filter,
            externalFilter: this.externalFilter
        });
        this.modal.close();
    }
    onClear() {
        delete this.selectedCode;
        this.clear.emit();
    }
    createQuickFilter() {
        return __awaiter(this, void 0, void 0, function* () {
            this.notifyService.confirmWithInput(this.translateService.translate('Enter quick filter name')).then((code) => __awaiter(this, void 0, void 0, function* () {
                if (code) {
                    if (code.length > 100) {
                        this.notifyService.notify.warning(this.translateService.translate('Code too long'));
                        return;
                    }
                    yield this.add(code);
                    this.notifyService.notify.success();
                }
                else {
                    this.notifyService.notify.warning(this.translateService.translate('Code can not be empty'));
                }
            }));
        });
    }
    updateQuickFilter() {
        return __awaiter(this, void 0, void 0, function* () {
            if (this.selectedCode) {
                yield this.update(this.selectedCode);
                this.notifyService.notify.success();
                this.selectedCode = null;
            }
        });
    }
    add(code) {
        return __awaiter(this, void 0, void 0, function* () {
            const f1 = JSON.stringify(this.filter);
            const f2 = JSON.stringify(this.externalFilter);
            const quickFilter = {
                code,
                filter: JSON.parse(f1),
                externalFilter: JSON.parse(f2),
            };
            const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
            if (idx !== -1) {
                this.notifyService.notify.warning(`${this.translateService.translate('Code is existed')}: ${quickFilter.code}`);
                return;
            }
            this.quickFilters.push(quickFilter);
            yield this.updateConfiguration();
        });
    }
    update(code) {
        return __awaiter(this, void 0, void 0, function* () {
            const f1 = JSON.stringify(this.filter);
            const f2 = JSON.stringify(this.externalFilter);
            const quickFilter = {
                code,
                filter: JSON.parse(f1),
                externalFilter: JSON.parse(f2)
            };
            const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
            if (idx === -1) {
                this.notifyService.notify.warning(`Code ${quickFilter.code} is not existed`);
                return;
            }
            this.quickFilters[idx] = quickFilter;
            yield this.updateConfiguration();
        });
    }
    remove(quickFilter) {
        this.notifyService.confirm(this.translateService.translate('Remove filter')).then(() => __awaiter(this, void 0, void 0, function* () {
            if (quickFilter.code === this.selectedCode) {
                delete this.selectedCode;
            }
            const idx = this.quickFilters.findIndex(e => e.code === quickFilter.code);
            this.quickFilters.splice(idx, 1);
            yield this.updateConfiguration();
        }));
    }
    loadConfiguration() {
        var _a, _b, _c, _d, _e;
        return __awaiter(this, void 0, void 0, function* () {
            this.quickFilters = [];
            this.showInlineFilter = true;
            if (!this.key) {
                return;
            }
            if (!(yield this.settingService.hasKey(this.keyPrefix + this.key))) {
                return;
            }
            const configuration = yield this.settingService.get(this.keyPrefix + this.key);
            if (Array.isArray((_a = configuration) === null || _a === void 0 ? void 0 : _a.quickFilters)) {
                this.quickFilters = configuration.quickFilters;
            }
            this.numberOfQuickFiltes = ((_b = this.quickFilters) === null || _b === void 0 ? void 0 : _b.length) || 0;
            this.showInlineFilter = (_d = (_c = configuration) === null || _c === void 0 ? void 0 : _c.showInlineFilter, (_d !== null && _d !== void 0 ? _d : true));
            this.selectedCode = ((_e = configuration) === null || _e === void 0 ? void 0 : _e.selectedQuickFilter) || '';
        });
    }
    updateConfiguration(selectedQuickFilterCode) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            if (!this.key) {
                return;
            }
            if (selectedQuickFilterCode !== undefined) {
                this.selectedCode = selectedQuickFilterCode;
            }
            yield this.settingService.set(this.keyPrefix + this.key, {
                quickFilters: this.quickFilters,
                showInlineFilter: this.showInlineFilter,
                selectedQuickFilter: this.selectedCode
            });
            this.loadInlineFilter.emit({
                showInlineFilter: (_a = this.showInlineFilter, (_a !== null && _a !== void 0 ? _a : true)),
                quickFilters: this.quickFilters || [],
                selectedQuickFilter: this.selectedCode || ''
            });
            this.numberOfQuickFiltes = ((_b = this.quickFilters) === null || _b === void 0 ? void 0 : _b.length) || 0;
            this.ref.detectChanges();
        });
    }
};
GridPopupFilterComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: SettingService },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    ViewChild('modal')
], GridPopupFilterComponent.prototype, "modal", void 0);
__decorate([
    Input()
], GridPopupFilterComponent.prototype, "filterType", void 0);
__decorate([
    Input()
], GridPopupFilterComponent.prototype, "key", void 0);
__decorate([
    Output()
], GridPopupFilterComponent.prototype, "accept", void 0);
__decorate([
    Output()
], GridPopupFilterComponent.prototype, "clear", void 0);
__decorate([
    Output()
], GridPopupFilterComponent.prototype, "loadInlineFilter", void 0);
GridPopupFilterComponent = __decorate([
    Component({
        selector: 'sd-grid-popup-filter',
        template: "<sd-modal-control width=\"sm\" [title]=\"'Filter' | sdTranslate\" #modal>\r\n  <sd-modal-body>\r\n    <fieldset *ngIf=\"key && quickFilters?.length\" class=\"c-fieldset\">\r\n      <legend class=\"c-legend\">{{'Quick filters' | sdTranslate}}</legend>\r\n      <div class=\"col-sm-12\">\r\n        <div *ngFor=\"let quickFilter of quickFilters\" class=\"c-quick-filter\"\r\n          [ngClass]=\"{'c-selected': quickFilter.code === selectedCode}\" (click)=\"select(quickFilter)\">\r\n          <span>{{quickFilter.code}}</span>\r\n          <i class=\"fa fa-times text-danger\" (click)=\"remove(quickFilter)\"></i>\r\n        </div>\r\n      </div>\r\n    </fieldset>\r\n    <div *ngFor=\"let item of externalFilters\" class=\"col-sm-12\">\r\n      <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\"\r\n        [(model)]=\"externalFilter[item.field]\">\r\n      </sd-input-control>\r\n      <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n        [(model)]=\"externalFilter[item.field]\">\r\n      </sd-input-control>\r\n      <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\" [{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n        [(model)]=\"externalFilter[item.field]\">\r\n      </sd-select-control>\r\n      <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n        [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n      </sd-radio-control>\r\n      <ng-container *ngIf=\"item.type === 'values'\">\r\n        <sd-select-control *ngIf=\"item.selection === 'MULTIPLE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          multiple=\"true\">\r\n        </sd-select-control>\r\n        <sd-autocomplete-control *ngIf=\"item.selection === 'AUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n        </sd-autocomplete-control>\r\n        <sd-chip-control *ngIf=\"item.selection === 'MULTIPLEAUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n        </sd-chip-control>\r\n        <sd-select-control *ngIf=\"!item.selection\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\">\r\n        </sd-select-control>\r\n      </ng-container>\r\n      <sd-input-control *ngIf=\"item.type === 'custom'\" [label]=\"item.title\" \r\n        [(model)]=\"externalFilter[displayKey + item.field]\"\r\n        (sdClick)=\"item?.onClick(externalFilter, item.field, displayKey + item.field)\">\r\n      </sd-input-control>\r\n      <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.field]\"\r\n        type=\"date\">\r\n      </sd-date-picker-control>\r\n      <sd-date-range-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='daterangefull'\"\r\n        [(fromDate)]=\"externalFilter[item.field].from\" [(toDate)]=\"externalFilter[item.field].to\"\r\n        [minDate]=\"item.minDate\" [maxDate]=\"item.maxDate\" type=\"date\">\r\n      </sd-date-range-picker-control>\r\n      <ng-container *ngIf=\"item.type ==='daterange'\">\r\n        <div class=\"row\">\r\n          <div class=\"col-6\">\r\n            <sd-date-picker-control [label]=\"item.fromTitle\" [(model)]=\"externalFilter[item.field].from\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate\"\r\n              [maxDate]=\"externalFilter[item.field].to || item.maxDate\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n          <div class=\"col-6\">\r\n            <sd-date-picker-control [label]=\"item.toTitle\" [(model)]=\"externalFilter[item.field].to\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate || externalFilter[item.field].from\"\r\n              [maxDate]=\"item.maxDate\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n        </div>\r\n      </ng-container>\r\n      <div class=\"row\" *ngIf=\"item.type ==='numberrange'\">\r\n        <div class=\"col-6\">\r\n          <sd-input-control [label]=\"item.fromTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].from\">\r\n          </sd-input-control>\r\n        </div>\r\n        <div class=\"col-6\">\r\n          <sd-input-control [label]=\"item.toTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].to\">\r\n          </sd-input-control>\r\n        </div>\r\n      </div>\r\n    </div>\r\n    <ng-container *ngFor=\"let column of columns\">\r\n      <div class=\"col-sm-12\">\r\n        <sd-input-control *ngIf=\"column.type === 'string'\" [label]=\"column.title\" type=\"text\"\r\n          [(model)]=\"filter[column.field]\">\r\n        </sd-input-control>\r\n        <sd-input-control *ngIf=\"column.type === 'number'\" [label]=\"column.title\" type=\" number\"\r\n          [(model)]=\"filter[column.field]\">\r\n        </sd-input-control>\r\n        <sd-radio-control *ngIf=\"column.type === 'bool'\" [label]=\"column.title\" [items]=\"[{value:'1',display:column.trueValue || 'True' },\r\n          {value:'0',display:column.falseValue || 'False' }]\" [(model)]=\"filter[column.field]\">\r\n        </sd-radio-control>\r\n        <sd-radio-control *ngIf=\"column.type === 'radio'\" [label]=\"column.title\" [items]=\"column.values\"\r\n          [valueField]=\"column.valueField\" [displayField]=\"column.displayField\" [(model)]=\"filter[column.field]\">\r\n        </sd-radio-control>\r\n        <sd-autocomplete-control *ngIf=\"column.type === 'values'\" [label]=\"column.title\" [items]=\"column.values\"\r\n          valueField=\"value\" displayField=\"text\" [(model)]=\"filter[column.field]\">\r\n        </sd-autocomplete-control>\r\n        <sd-date-picker-control *ngIf=\"column.type ==='date' || column.type==='datetime' ||\r\n          column.type==='time'\" [label]=\"column.title\" [(model)]=\" filter[column.field]\" type=\"date\">\r\n        </sd-date-picker-control>\r\n      </div>\r\n      <div *ngIf=\"column.type === 'children' && column.children?.length\" class=\"col-sm-12\">\r\n        <ng-template ngFor let-childColumn [ngForOf]=\"column.children\">\r\n          <sd-input-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'string'\" type=\"text\"\r\n            [(model)]=\"filter[childColumn.field]\">\r\n          </sd-input-control>\r\n          <sd-input-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'number'\" type=\" number\"\r\n            [(model)]=\"filter[childColumn.field]\">\r\n          </sd-input-control>\r\n          <sd-radio-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'bool'\" [items]=\"[{value:'1',display:column.trueValue || 'True' },\r\n          {value:'0',display:childColumn.falseValue || 'False' }]\" [(model)]=\"filter[childColumn.field]\">\r\n          </sd-radio-control>\r\n          <sd-radio-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'radio'\"\r\n            [items]=\"childColumn.values\" [valueField]=\"childColumn.valueField\" [displayField]=\"childColumn.displayField\"\r\n            [(model)]=\"filter[childColumn.field]\">\r\n          </sd-radio-control>\r\n          <sd-autocomplete-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type === 'values'\"\r\n            [items]=\"childColumn.values\" valueField=\"value\" displayField=\"text\" [(model)]=\"filter[childColumn.field]\">\r\n          </sd-autocomplete-control>\r\n          <sd-date-picker-control [label]=\"childColumn.title\" *ngIf=\"childColumn.type ==='date' || childColumn.type==='datetime' ||\r\n          childColumn.type==='time'\" [(model)]=\" filter[childColumn.field]\" type=\"date\">\r\n          </sd-date-picker-control>\r\n        </ng-template>\r\n      </div>\r\n    </ng-container>\r\n  </sd-modal-body>\r\n  <sd-modal-footer>\r\n    <div class=\"mr-auto\">\r\n      <button type=\"button\" class=\"btn btn-warning btn-sm mr-2\" (click)=\"onClear()\">\r\n        <i class=\"fa fa-times fa-fw mr-1\"></i>{{'Clear filter' | sdTranslate}}</button>\r\n      <button *ngIf=\"key && !selectedCode && numberOfQuickFiltes < maxQuickFilters\" type=\"button\"\r\n        class=\"btn btn-success btn-sm mr-auto\" (click)=\"createQuickFilter()\">\r\n        <i class=\"fa fa-plus fa-fw mr-1\"></i>\r\n        <span>{{'Create quick filter' | sdTranslate}}</span>\r\n      </button>\r\n      <button *ngIf=\"key && selectedCode\" type=\"button\" class=\"btn btn-info btn-sm mr-auto\"\r\n        (click)=\"updateQuickFilter()\">\r\n        <i class=\"fa fa-floppy-o fa-fw mr-1\"></i>\r\n        <span>{{'Update quick filter' | sdTranslate}}</span>\r\n      </button>\r\n      <sd-checkbox-control *ngIf=\"key && !isMobileOrTablet\" class=\"ml-2\" [label]=\"'Show inline filter' | sdTranslate\"\r\n        [(model)]=\"showInlineFilter\" (sdChange)=\"updateConfiguration()\"></sd-checkbox-control>\r\n    </div>\r\n    <button type=\"button\" class=\"btn btn-primary btn-sm\" (click)=\"onAccept()\">\r\n      <i class=\"fa fa-check fa-fw mr-1\"></i>{{'Accept' | sdTranslate }}</button>\r\n  </sd-modal-footer>\r\n</sd-modal-control>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", "fieldset.c-fieldset{border-radius:5px;border:1px solid #919191}legend.c-legend{width:auto;padding:0 5px;margin:0 10px;border-bottom:none;font-size:20px}.c-quick-filter{display:inline-block;margin-right:5px;margin-bottom:10px;border:1px solid #919191;border-radius:20px;padding:2px 10px;cursor:pointer}.c-quick-filter.c-selected{border:1px solid #00bcd4;background-color:#00bcd4;color:#fff}.c-quick-filter span{font-size:16px}.c-quick-filter i{font-size:16px;margin-left:12px;cursor:pointer;opacity:.7}.c-quick-filter i:hover{opacity:1}"]
    })
], GridPopupFilterComponent);

let ChartControlComponent = class ChartControlComponent {
    constructor(ref, datePipe) {
        this.ref = ref;
        this.datePipe = datePipe;
        this.initialized = false;
        this.visible = true;
        this.height = '300px';
    }
    set chartOption(chartOption) {
        this.pChartOption = chartOption;
        if (this.initialized) {
            this.renderChart();
        }
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        this.renderChart(true);
        this.initialized = true;
        this.ref.detectChanges();
    }
    renderChart(firstRender) {
        var _a;
        return __awaiter(this, void 0, void 0, function* () {
            this.height = ((_a = this.pChartOption) === null || _a === void 0 ? void 0 : _a.height) || '300px';
            if (!firstRender) {
                this.visible = false;
                yield new Promise(resolve => setTimeout(resolve, 500));
                this.visible = true;
            }
            setTimeout(() => {
                const canvas = this.chartRef.nativeElement;
                this.ctx = canvas.getContext('2d');
                switch (this.pChartOption.type) {
                    case 'pie':
                        this.renderPieChart(this.pChartOption);
                        break;
                    case 'bar':
                        this.renderBarChart(this.pChartOption);
                        break;
                    case 'line':
                        this.renderLineChart(this.pChartOption);
                        break;
                    case 'barline':
                        this.renderBarLineChart(this.pChartOption);
                        break;
                    default: break;
                }
            }, 500);
        });
    }
    renderPieChart(option) {
    }
    renderBarChart(option) {
        var _a, _b;
        const labelWidth = (_a = option.labelWidth, (_a !== null && _a !== void 0 ? _a : 50));
        if (option.datasets.length) {
            const newwidth = Math.max(option.labels.length * option.datasets.length * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
            $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
        }
        const configuration = {
            options: {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    display: !option.hideLegend
                },
                scales: {
                    xAxes: [{
                            display: true,
                            scaleLabel: {
                                display: !!option.xTitle,
                                labelString: option.xTitle || ''
                            }
                        }],
                    yAxes: [{
                            display: true,
                            ticks: {
                                beginAtZero: (_b = option.beginAtZero, (_b !== null && _b !== void 0 ? _b : true)),
                            },
                            scaleLabel: {
                                display: !!option.yTitle,
                                labelString: option.yTitle || ''
                            }
                        }]
                }
            },
            type: 'bar',
            data: {
                labels: option.labels,
                datasets: option.datasets.map(e => {
                    const result = {
                        label: e.label,
                        fill: e.backgroundColor,
                        backgroundColor: e.backgroundColor,
                        data: e.data
                    };
                    return result;
                })
            }
        };
        this.chart = new Chart(this.ctx, configuration);
    }
    renderLineChart(option) {
        var _a, _b;
        const labelWidth = (_a = option.labelWidth, (_a !== null && _a !== void 0 ? _a : 50));
        if (option.datasets.length) {
            const newwidth = Math.max(option.labels.length * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
            $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
        }
        const configuration = {
            options: {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    display: !option.hideLegend
                },
                scales: {
                    xAxes: [{
                            display: true,
                            scaleLabel: {
                                display: !!option.xTitle,
                                labelString: option.xTitle || ''
                            }
                        }],
                    yAxes: [{
                            display: true,
                            ticks: {
                                beginAtZero: (_b = option.beginAtZero, (_b !== null && _b !== void 0 ? _b : true))
                            },
                            scaleLabel: {
                                display: !!option.yTitle,
                                labelString: option.yTitle || ''
                            }
                        }]
                }
            },
            type: 'line',
            data: {
                labels: option.labels,
                datasets: option.datasets.map(e => {
                    const result = {
                        label: e.label,
                        fill: e.backgroundColor,
                        backgroundColor: e.backgroundColor,
                        borderColor: e.borderColor,
                        data: e.data
                    };
                    return result;
                })
            }
        };
        this.chart = new Chart(this.ctx, configuration);
    }
    renderBarLineChart(option) {
        var _a, _b, _c;
        const labelWidth = (_a = option.labelWidth, (_a !== null && _a !== void 0 ? _a : 50));
        if (option.datasets.length) {
            const numberOfBars = option.datasets.filter(e => e.type === 'bar').length;
            if (numberOfBars <= 1) {
                const newwidth = Math.max(option.labels.length * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
                $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
            }
            else {
                const newwidth = Math.max(option.labels.length * numberOfBars * labelWidth, $$1(this.chartWrapperRef.nativeElement).width());
                $$1(this.chartAreaWrapperExtendRef.nativeElement).width(newwidth);
            }
        }
        const leftId = `I${v4()}`;
        const rightId = `I${v4()}`;
        const yAxes = [{
                type: 'linear',
                display: true,
                position: 'left',
                id: leftId,
                ticks: {
                    beginAtZero: (_b = option.beginAtZero, (_b !== null && _b !== void 0 ? _b : true)),
                    suggestedMin: 0
                },
                scaleLabel: {
                    display: !!option.yTitle,
                    labelString: option.yTitle || ''
                }
            }];
        if (option.datasets.some(e => e.yAlign === 'right')) {
            yAxes.push({
                type: 'linear',
                display: true,
                position: 'right',
                id: rightId,
                ticks: {
                    beginAtZero: (_c = option.beginAtZero, (_c !== null && _c !== void 0 ? _c : true)),
                    suggestedMin: 0
                },
                scaleLabel: {
                    display: !!option.yRightTitle,
                    labelString: option.yRightTitle || ''
                }
            });
        }
        const configuration = {
            options: {
                responsive: true,
                maintainAspectRatio: false,
                legend: {
                    display: !option.hideLegend
                },
                title: {
                    display: true,
                    text: option.title
                },
                scales: {
                    xAxes: [{
                            display: true,
                            scaleLabel: {
                                display: !!option.xTitle,
                                labelString: option.xTitle || ''
                            }
                        }],
                    yAxes
                }
            },
            data: {
                labels: option.labels,
                datasets: option.datasets.map(e => {
                    const result = {
                        type: e.type,
                        label: e.label,
                        fill: e.backgroundColor,
                        backgroundColor: e.backgroundColor,
                        borderColor: e.borderColor,
                        data: e.data,
                        yAxisID: e.yAlign === 'right' ? rightId : leftId
                    };
                    return result;
                })
            }
        };
        this.chart = new Chart(this.ctx, configuration);
    }
};
ChartControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DatePipe }
];
__decorate([
    Input()
], ChartControlComponent.prototype, "chartOption", null);
__decorate([
    ViewChild('chart')
], ChartControlComponent.prototype, "chartRef", void 0);
__decorate([
    ViewChild('chartWrapper')
], ChartControlComponent.prototype, "chartWrapperRef", void 0);
__decorate([
    ViewChild('chartAxis')
], ChartControlComponent.prototype, "chartAxisRef", void 0);
__decorate([
    ViewChild('chartAreaWrapperExtend')
], ChartControlComponent.prototype, "chartAreaWrapperExtendRef", void 0);
ChartControlComponent = __decorate([
    Component({
        selector: 'sd-chart-control',
        template: "<div *ngIf=\"visible\" class=\"c-chart-wrapper mt-2\" >\r\n  <div class=\"c-chart-area-wrapper\" #chartWrapper>\r\n    <div class=\"c-chart-area-wrapper-extend\" [ngStyle]=\"{'height':height}\" #chartAreaWrapperExtend>\r\n      <canvas #chart></canvas>\r\n    </div>\r\n  </div>\r\n</div>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".c-container{background:#f5f6f7;border-radius:5px}.c-flex{display:flex;margin:15px;border-radius:8px}.c-chart-container{box-shadow:0 0 13px 0 rgba(82,63,105,.1);border-radius:8px;margin:15px;padding:15px;background:#fff}.c-btn-dashboard{height:60%;align-self:center;vertical-align:middle}.c-chart-wrapper{position:relative}.c-chart-wrapper>canvas{position:absolute;left:0;top:0;pointer-events:none}.c-chart-area-wrapper{overflow-x:scroll;position:relative;width:100%}.c-chart-area-wrapper-extend{position:relative}"]
    })
], ChartControlComponent);

let ChipControlComponent = class ChipControlComponent {
    constructor(ref, utilityService, translateService) {
        this.ref = ref;
        this.utilityService = utilityService;
        this.translateService = translateService;
        this.initialized = false;
        this.pModel = [];
        this.pItems = [];
        this.name = v4();
        this.separatorKeysCodes = [ENTER, COMMA];
        this.selectable = true;
        this.removable = true;
        // tslint:disable-next-line: variable-name
        this._items = [];
        this.limit = 50;
        this.selectedItems = [];
        // model
        // tslint:disable-next-line: variable-name
        this._model = [];
        this.modelChange = new EventEmitter();
        // tslint:disable-next-line: variable-name
        this._minItem = 0;
        // tslint:disable-next-line: no-output-native
        this.change = new EventEmitter();
        this.sdChange = new EventEmitter();
        this.chipSelected = new EventEmitter();
        this.onChanges = () => {
            var _a;
            this._model = this.pModel;
            this._items = this.pItems;
            this.selectedItems = this._items.filter(item => this._model.findIndex(value => { var _a; return value === ((_a = item) === null || _a === void 0 ? void 0 : _a[this.valueField]); }) !== -1);
            (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        };
        this.displayFn = (value) => {
            if (typeof value === 'string') {
                if (!this.items) {
                    return undefined;
                }
                const selectedItem = this.items.find(item => item[this.valueField] === value);
                if (selectedItem) {
                    return selectedItem[this.displayField];
                }
                if (this.items.some(item => item[this.displayField].toLowerCase().indexOf(value.toLowerCase()) !== -1)) {
                    return value;
                }
                else {
                    return undefined;
                }
            }
            else {
                return value ? value[this.displayField] : undefined;
            }
        };
        this.validateMinItem = () => {
            if (!this.chipList) {
                return null;
            }
            if (this.selectedItems.length < this._minItem) {
                this.chipList.errorState = true;
                return `${this.translateService.translate('Please select at least')} ${this._minItem}`;
            }
            this.chipList.errorState = false;
            return null;
        };
        this.clear = ($event) => {
            var _a, _b;
            (_a = $event) === null || _a === void 0 ? void 0 : _a.stopPropagation();
            this.input.nativeElement.value = '';
            this.ipt = '';
            this.formModel.control.setValue(null);
            (_b = this.autocompleteTrigger) === null || _b === void 0 ? void 0 : _b.openPanel();
            this.ref.detectChanges();
        };
    }
    get items() {
        return this._items;
    }
    set items(items) {
        if (!Array.isArray(items)) {
            items = [];
        }
        this.pItems = items;
        if (this.initialized) {
            this.onChanges();
        }
    }
    set model(values) {
        if (!Array.isArray(values)) {
            values = [];
        }
        this.pModel = values;
        if (this.initialized) {
            this.onChanges();
        }
    }
    set minItem(minItem) {
        var _a;
        minItem = +minItem || 0;
        this._minItem = minItem;
        (_a = this.formModel) === null || _a === void 0 ? void 0 : _a.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        this.ref.detectChanges();
    }
    ngOnInit() {
        this.filteredItems = this.formModel.valueChanges.pipe(startWith(''), map(item => { var _a, _b; return typeof item === 'string' ? item : (_b = (_a = item) === null || _a === void 0 ? void 0 : _a[this.displayField], (_b !== null && _b !== void 0 ? _b : '')); }), map(name => this.filter(name)));
    }
    ngAfterViewInit() {
        var _a, _b;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        (_b = this.formModel) === null || _b === void 0 ? void 0 : _b.control.updateValueAndValidity({ onlySelf: false, emitEvent: true });
        this.onChanges();
        this.initialized = true;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    filter(value) {
        return this.items
            .filter(item => {
            if (this.selectedItems.some(e => e[this.valueField] === item[this.valueField])) {
                return false;
            }
            return !value || this.utilityService.changeAliasLowerCase(item[this.displayField])
                .indexOf(this.utilityService.changeAliasLowerCase(value)) !== -1;
        }).filter((item, index) => index < this.limit);
    }
    add(event) {
        // Add item only when MatAutocomplete is not open
        // To make sure this does not conflict with OptionSelected Event
        if (!this.matAutocomplete.isOpen) {
            const input = event.input;
            const value = event.value;
            // Add our item
            if ((value || '').trim()) {
                const item = this.items.find(e => e[this.displayField]
                    && e[this.displayField].toString().toLowerCase() === value.toString().toLowerCase().trim());
                if (item) {
                    this.selectedItems.push(item);
                    this.updateModel();
                }
            }
            // Reset the input value
            if (input) {
                input.value = '';
            }
            this.formModel.control.setValue(null);
        }
    }
    remove(item) {
        const index = this.selectedItems.indexOf(item);
        if (index >= 0) {
            this.selectedItems.splice(index, 1);
            this.updateModel();
            this.formModel.reset();
        }
    }
    select(item) {
        this.chipSelected.emit(item);
    }
    selected(event) {
        const value = event.option.viewValue;
        // Add our fruit
        if ((value || '').trim()) {
            const item = this.items.find(e => e[this.displayField]
                && e[this.displayField].toString().toLowerCase() === value.toString().toLowerCase().trim());
            this.selectedItems.push(item);
            this.input.nativeElement.value = '';
            this.formModel.control.setValue(null);
            this.updateModel();
            setTimeout(() => {
                var _a;
                (_a = this.autocompleteTrigger) === null || _a === void 0 ? void 0 : _a.openPanel();
            });
        }
    }
    updateModel() {
        this._model = this.selectedItems.map(e => e[this.valueField]);
        this.modelChange.emit(this._model);
        this.change.emit(this.selectedItems);
        this.sdChange.emit(this.selectedItems);
        setTimeout(() => {
            var _a, _b;
            (_b = (_a = this.form) === null || _a === void 0 ? void 0 : _a.form) === null || _b === void 0 ? void 0 : _b.markAsDirty();
        }, 0);
    }
};
ChipControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: UtilityService },
    { type: TranslateService }
];
__decorate([
    Input()
], ChipControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "valueField", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "displayField", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "displayChipField", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "items", null);
__decorate([
    Input()
], ChipControlComponent.prototype, "limit", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "model", null);
__decorate([
    Output()
], ChipControlComponent.prototype, "modelChange", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], ChipControlComponent.prototype, "minItem", null);
__decorate([
    Output()
], ChipControlComponent.prototype, "change", void 0);
__decorate([
    Output()
], ChipControlComponent.prototype, "sdChange", void 0);
__decorate([
    Output()
], ChipControlComponent.prototype, "chipSelected", void 0);
__decorate([
    ViewChild('formModel', { static: true })
], ChipControlComponent.prototype, "formModel", void 0);
__decorate([
    ViewChild('input')
], ChipControlComponent.prototype, "input", void 0);
__decorate([
    ViewChild('auto')
], ChipControlComponent.prototype, "matAutocomplete", void 0);
__decorate([
    ViewChild('chipList', { static: true })
], ChipControlComponent.prototype, "chipList", void 0);
__decorate([
    ViewChild(MatAutocompleteTrigger, { read: MatAutocompleteTrigger })
], ChipControlComponent.prototype, "autocompleteTrigger", void 0);
ChipControlComponent = __decorate([
    Component({
        selector: 'sd-chip-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <mat-chip-list #chipList>\r\n    <ng-container *ngFor=\"let item of selectedItems\">\r\n      <mat-chip *ngIf=\"item\" [selectable]=\"selectable\" [removable]=\"removable\" (removed)=\"remove(item)\" [selected]=\"item.isSelected\"\r\n        (selectionChange)=\"select(item)\" [disabled]=\"disabled\" (click)=\"item.isSelected = !item.isSelected\">\r\n        {{item[displayChipField] || item[displayField]}}\r\n        <mat-icon matChipRemove *ngIf=\"removable\"><i class=\"fa fa-times text-danger c-chip-remove\"></i></mat-icon>\r\n      </mat-chip>\r\n    </ng-container>\r\n    <input #autocompleteTrigger #formModel=\"ngModel\" [(ngModel)]=\"ipt\" [name]=\"name\" [placeholder]=\"label\"\r\n      [disabled]=\"disabled\" [matAutocomplete]=\"auto\" [matChipInputFor]=\"chipList\"\r\n      [matChipInputSeparatorKeyCodes]=\"separatorKeysCodes\" (matChipInputTokenEnd)=\"add($event)\"\r\n      [sdChipMinItem]=\"validateMinItem\" autocomplete=\"false\" matInput #input>\r\n    <i *ngIf=\"!ipt\" matSuffix class=\"fa fa-search fa-fw\"></i>\r\n    <i *ngIf=\"ipt\" matSuffix class=\"fa fa-times fa-fw text-danger\" (click)=\"clear($event)\" style=\"cursor: pointer;\"></i>\r\n  </mat-chip-list>\r\n  <mat-error *ngIf=\"formModel?.errors?.minItem\">\r\n    {{formModel?.errors?.minItem}}\r\n  </mat-error>\r\n  <mat-autocomplete #auto=\"matAutocomplete\" [displayWith]=\"displayFn\" (optionSelected)=\"selected($event)\">\r\n    <mat-option *ngFor=\"let item of filteredItems | async\" [value]=\"item\">\r\n      {{item[displayField]}}\r\n    </mat-option>\r\n  </mat-autocomplete>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}", "sd-chip-control .c-chip-remove:hover{color:#f44336!important}"]
    })
], ChipControlComponent);

let GridSubInformationComponent = class GridSubInformationComponent {
    constructor(ref, settingService, notifyService) {
        this.ref = ref;
        this.settingService = settingService;
        this.notifyService = notifyService;
        this.height = 'auto';
        this.columns = [];
        this.commands = [];
        this.subItems = [];
        this.isMobile = window.innerWidth < MobileMaxWidth;
        this.filter = {};
        this.onEditorChange = (column, item, value) => {
            var _a;
            if (column.type !== 'children') {
                (_a = column.editor) === null || _a === void 0 ? void 0 : _a.change(item, value);
                this.ref.detectChanges();
            }
        };
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
    }
    updateFilter() {
    }
    trackById(index, item) {
        return item.id;
    }
};
GridSubInformationComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: SettingService },
    { type: NotifyService }
];
__decorate([
    Input()
], GridSubInformationComponent.prototype, "height", void 0);
__decorate([
    Input()
], GridSubInformationComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GridSubInformationComponent.prototype, "commands", void 0);
__decorate([
    Input()
], GridSubInformationComponent.prototype, "subItems", void 0);
GridSubInformationComponent = __decorate([
    Component({
        selector: 'sd-grid-sub-information',
        template: "<div class=\"clearfix\"></div>\r\n<div *ngIf=\"!isMobile\" class=\"sd-box sd-box-primary\">\r\n  <div class=\"sd-box-body p-0\">\r\n    <div class=\"row mx-0\">\r\n      <div class=\"table-responsive\" style=\"position: relative;\" [ngStyle]=\"{'height': height}\">\r\n        <table class=\"table table-hover table-striped table-bordered\">\r\n          <thead class=\"thead-light\">\r\n            <tr>\r\n              <th class=\"position-sticky c-sticky-all align-middle p-0\" style=\"width:1px\">\r\n                <div class=\"d-flex h-100\">\r\n                  <div style=\"width:4px; min-width: 4px;\"></div>\r\n                  <div *ngIf=\"commands?.length\" class=\"align-middle text-center\"\r\n                    [ngStyle]=\"{'width':commands.length*35 + 'px', 'min-width': commands.length*35 + 'px'}\">\r\n                  </div>\r\n                  <div *ngIf=\"commands?.length\" class=\"c-sticky-spliter\"></div>\r\n                </div>\r\n              </th>\r\n              <th *ngFor=\"let column of columns\" class=\"position-sticky c-sticky-top\"\r\n                [ngStyle]=\"{'width':column.width ? column.width : '','min-width':column.width ? column.width : '300px'}\">\r\n                <span [title]=\"column.title\" class=\"c-header-title cursor-pointer\"\r\n                  [ngStyle]=\"{'width':column.width ? column.width : ''}\">\r\n                  {{column.title}}\r\n                </span>\r\n              </th>\r\n            </tr>\r\n          </thead>\r\n          <tbody>\r\n            <ng-container *ngFor=\"let item of subItems; trackBy: trackById\">\r\n              <tr>\r\n                <td class=\"position-sticky c-sticky-left p-0\" style=\"width:1px\">\r\n                  <div class=\"d-inline-flex align-middle h-100\">\r\n                    <div class=\"h-100\" style=\"width:4px;min-width: 4px;left:0\" matTooltipPosition=\"after\">\r\n                    </div>\r\n                  </div>\r\n                  <div *ngIf=\"commands?.length\" class=\"d-inline-flex align-middle\">\r\n                    <div class=\"d-flex align-middle text-center justify-content-center\"\r\n                      [ngStyle]=\"{'width':commands.length*35 + 'px', 'min-width': commands.length*35 + 'px'}\">\r\n                      <ng-container *ngIf=\"item.viewCommands?.length\">\r\n                        <section *ngFor=\"let command of item.viewCommands\">\r\n                          <button (click)=\"command.click(item)\" type=\"button\" class=\"c-btn-icon\"\r\n                            [matTooltip]=\"command.title\" [disabled]=\"command.disabled\">\r\n                            <i class=\"{{command.icon}}\" aria-hidden=\"true\"></i>\r\n                          </button>\r\n                        </section>\r\n                      </ng-container>\r\n                    </div>\r\n                  </div>\r\n                  <div *ngIf=\"commands?.length\" class=\"d-inline-flex align-middle h-100\">\r\n                    <div class=\"c-sticky-spliter h-100\"></div>\r\n                  </div>\r\n                </td>\r\n                <td *ngFor=\"let column of columns\" class=\"align-middle\"\r\n                  [ngClass]=\"{'text-center': column.type !== 'string' && column.type !== 'number', 'text-right': column.type === 'number'}\"\r\n                  [ngStyle]=\"{'width':column.width ? column.width : '', 'min-width':column.width ? column.width : '300px'}\">\r\n                  <ng-container *ngIf=\"!column.children?.length\">\r\n                    <ng-container *ngIf=\"item[column.field] | editorSubInformationHandler:item:columns\">\r\n                      <ng-container *ngIf=\"item.editorHandler[column.field].visible;else elseDisableEditor\">\r\n                        <div *ngIf=\"column.type === 'string'\">\r\n                          <input class=\"form-control c-input-xs\"\r\n                            [ngClass]=\"{'border-right-0':column.editor && column.editor.click}\"\r\n                            [(ngModel)]=\"item[column.field]\"\r\n                            (keyup.enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n                            (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'number'\">\r\n                          <input class=\"form-control c-input-xs\" type=\"number\"\r\n                            [ngClass]=\"{'border-right-0':column.editor && column.editor.click}\"\r\n                            [(ngModel)]=\"item[column.field]\"\r\n                            (keyup.enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n                            (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'bool'\">\r\n                          <div class=\"align-middle\">\r\n                            <mat-slide-toggle [(ngModel)]=\"item[column.field]\"\r\n                              (change)=\"onEditorChange(column,item,item[column.field])\" color=\"primary\">\r\n                            </mat-slide-toggle>\r\n                          </div>\r\n                        </div>\r\n                      </ng-container>\r\n                      <ng-template #elseDisableEditor>\r\n                        <div *ngIf=\"column.type === 'string'\">\r\n                          <div class=\"c-ellipsis\">\r\n                            <span [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-badge':item.badge && item.badge[column.field], \r\n                            'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n                            'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n                            'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n                            'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n                            'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n                            'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n                            'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n                            'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n                            'blinker': item.blinker && item.blinker[column.field]}\">{{item[column.field]}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'color'\">\r\n                          <input [disabled]=\"true\" type=\"color\" class=\"form-control c-input-xs\"\r\n                            [(ngModel)]=\"item[column.field]\">\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'number'\">\r\n                          <div class=\"pull-right\">\r\n                            <span\r\n                              [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-badge':item.badge && item.badge[column.field], \r\n                              'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n                              'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n                              'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n                              'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n                              'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n                              'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n                              'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n                              'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n                              'blinker': item.blinker && item.blinker[column.field]}\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'date'\">\r\n                          {{item[column.field] | date:'dd/MM/yyyy'}}\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'datetime'\">\r\n                          {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'time'\">\r\n                          {{item[column.field] | date:'HH:mm'}}\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'bool'\">\r\n                          <div class=\"align-middle\">\r\n                            <span *ngIf=\"item[column.field]\"\r\n                              class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n                            <span *ngIf=\"!item[column.field]\"\r\n                              class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'values'\">\r\n                          <div class=\"status c-ellipsis\"\r\n                            [ngStyle]=\"{'color':column?.dictionary[item[column.field]]?.color}\">\r\n                            {{!!column?.dictionary[item[column.field]] ? column?.dictionary[item[column.field]]?.text : item[column.field]}}\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'radio'\">\r\n                          <div class=\"c-ellipsis\">\r\n                            <span>{{item[column.field]}}</span>\r\n                          </div>\r\n                        </div>\r\n                        <div *ngIf=\"column.type === 'image'\">\r\n                          <div class=\"align-middle\">\r\n                            <img [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n                              [height]=\"column.display?.height\" style=\"margin: 5px 0\">\r\n                          </div>\r\n                        </div>\r\n                      </ng-template>\r\n                    </ng-container>\r\n                  </ng-container>\r\n                  <div *ngIf=\"column.children?.length\" class=\"row mx-0\">\r\n                    <div *ngFor=\"let childColumn of column.children | filterMobile:item\"\r\n                      [ngClass]=\"{'col-sm-6': childColumn?.colSpan === 1, 'col-sm-12': !childColumn?.colSpan || childColumn?.colSpan === 2}\">\r\n                      <span class=\"c-mobile-title\">\u2022 {{childColumn.title}}:</span>\r\n                      <span *ngIf=\"childColumn.type === 'string'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n                        'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n                        'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n                        'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n                        'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n                        'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n                        'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n                        'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n                        'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n                        'blinker': item.blinker && item.blinker[childColumn.field]}\">{{item[childColumn.field]}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'number'\" class=\"c-mobile-value\"\r\n                        [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n                        'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n                        'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n                        'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n                        'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n                        'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n                        'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n                        'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n                        'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n                        'blinker': item.blinker && item.blinker[childColumn.field]}\">{{(item[childColumn.field] | valueTransform:item:childColumn) | number : '1.0-2'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'datetime'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'date'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'time'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field] | date:'HH:mm'}}</span>\r\n                      <span *ngIf=\"childColumn.type === 'bool'\" class=\"c-mobile-value\">\r\n                        <span *ngIf=\"item[childColumn.field]\"\r\n                          class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n                        <span *ngIf=\"!item[childColumn.field]\"\r\n                          class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n                      </span>\r\n                      <span *ngIf=\"childColumn.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\"\r\n                          type=\"color\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[childColumn.field]\"></span>\r\n                      <span *ngIf=\"childColumn.type === 'values'\" class=\"status c-mobile-value\"\r\n                        [ngStyle]=\"{'color':childColumn?.dictionary[item[childColumn.field]]?.color}\">\r\n                        {{!!childColumn?.dictionary[item[childColumn.field]] ? childColumn?.dictionary[item[childColumn.field]]?.text : item[childColumn.field]}}\r\n                      </span>\r\n                      <span *ngIf=\"childColumn.type === 'radio'\"\r\n                        class=\"c-mobile-value\">{{item[childColumn.field]}}</span>\r\n                      <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n                        [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\"\r\n                        style=\"margin: 5px 0\">\r\n                    </div>\r\n                  </div>\r\n                </td>\r\n              </tr>\r\n            </ng-container>\r\n          </tbody>\r\n        </table>\r\n      </div>\r\n    </div>\r\n  </div>\r\n</div>\r\n<div *ngIf=\"isMobile\" class=\"sd-box c-mobile-box\">\r\n  <div class=\"sd-box-body c-mobile-body\" [ngStyle]=\"{'height': height}\">\r\n    <ng-container *ngFor=\"let item of subItems\">\r\n      <div class=\"c-mobile-item\">\r\n        <ng-container *ngFor=\"let column of columns | filterMobile:item\">\r\n          <div *ngIf=\"item[column.field]\" class=\"c-mobile-row\">\r\n            <span class=\"c-mobile-title\">\u2022 {{column.title}}:</span>\r\n            <span *ngIf=\"column.type === 'string'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-mobile-badge':item.badge && item.badge[column.field], \r\n            'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[column.field]}\">{{item[column.field]}}</span>\r\n            <span *ngIf=\"column.type === 'number'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[column.field], 'c-mobile-badge':item.badge && item.badge[column.field], \r\n            'badge-primary':item.badge && item.badge[column.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[column.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[column.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[column.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[column.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[column.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[column.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[column.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[column.field]}\">{{item[column.field] | number : '1.0-2'}}</span>\r\n            <span *ngIf=\"column.type === 'datetime'\"\r\n              class=\"c-mobile-value\">{{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</span>\r\n            <span *ngIf=\"column.type === 'date'\"\r\n              class=\"c-mobile-value\">{{item[column.field] | date:'dd/MM/yyyy'}}</span>\r\n            <span *ngIf=\"column.type === 'time'\" class=\"c-mobile-value\">{{item[column.field] | date:'HH:mm'}}</span>\r\n            <span *ngIf=\"column.type === 'bool'\" class=\"c-mobile-value\">\r\n              <span *ngIf=\"item[column.field]\" class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n              <span *ngIf=\"!item[column.field]\" class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"></span>\r\n            <span *ngIf=\"column.type === 'values'\" class=\"status c-mobile-value\"\r\n              [ngStyle]=\"{'color':column?.dictionary[item[column.field]]?.color}\">\r\n              {{!!column?.dictionary[item[column.field]] ? column?.dictionary[item[column.field]]?.text : item[column.field]}}\r\n            </span>\r\n            <span *ngIf=\"column.type === 'radio'\" class=\"c-mobile-value\">{{item[column.field]}}</span>\r\n            <img *ngIf=\"column.type === 'image'\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n              [height]=\"column.display?.height\" style=\"margin: 5px 0\">\r\n          </div>\r\n          <ng-container *ngIf=\"column.children?.length\">\r\n            <div class=\"c-mobile-row\" *ngFor=\"let childColumn of column.children | filterMobile:item\">\r\n              <span class=\"c-mobile-title\">\u2022 {{childColumn.title}}:</span>\r\n              <span *ngIf=\"childColumn.type === 'string'\" class=\"c-mobile-value\" [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n            'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[childColumn.field]}\">{{item[childColumn.field]}}</span>\r\n              <span *ngIf=\"childColumn.type === 'number'\" class=\"c-mobile-value\"\r\n                [ngClass]=\"{'badge': item.badge && item.badge[childColumn.field], 'c-mobile-badge':item.badge && item.badge[childColumn.field], \r\n            'badge-primary':item.badge && item.badge[childColumn.field] === 'PRIMARY', \r\n            'badge-secondary':item.badge && item.badge[childColumn.field] === 'SECONDARY', \r\n            'badge-info':item.badge && item.badge[childColumn.field] === 'INFO', \r\n            'badge-success':item.badge && item.badge[childColumn.field] === 'SUCCESS', \r\n            'badge-warning':item.badge && item.badge[childColumn.field] === 'WARNING', \r\n            'badge-danger':item.badge && item.badge[childColumn.field] === 'DANGER',\r\n            'badge-light':item.badge && item.badge[childColumn.field] === 'LIGHT',\r\n            'badge-dark':item.badge && item.badge[childColumn.field] === 'DARK',\r\n            'blinker': item.blinker && item.blinker[childColumn.field]}\">{{item[childColumn.field] | number : '1.0-2'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'datetime'\"\r\n                class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'date'\"\r\n                class=\"c-mobile-value\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'time'\"\r\n                class=\"c-mobile-value\">{{item[childColumn.field] | date:'HH:mm'}}</span>\r\n              <span *ngIf=\"childColumn.type === 'bool'\" class=\"c-mobile-value\">\r\n                <span *ngIf=\"item[childColumn.field]\"\r\n                  class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n                <span *ngIf=\"!item[childColumn.field]\"\r\n                  class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n              </span>\r\n              <span *ngIf=\"childColumn.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                  class=\"form-control c-input-xs\" [(ngModel)]=\"item[childColumn.field]\"></span>\r\n              <span *ngIf=\"childColumn.type === 'values'\" class=\"status c-mobile-value\"\r\n                [ngStyle]=\"{'color':childColumn?.dictionary[item[childColumn.field]]?.color}\">\r\n                {{!!childColumn?.dictionary[item[childColumn.field]] ? childColumn?.dictionary[item[childColumn.field]]?.text : item[childColumn.field]}}\r\n              </span>\r\n              <span *ngIf=\"childColumn.type === 'radio'\" class=\"c-mobile-value\">{{item[childColumn.field]}}</span>\r\n              <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n                [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\" style=\"margin: 5px 0\">\r\n            </div>\r\n          </ng-container>\r\n        </ng-container>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</div>",
        styles: [".btn{color:#fff;background-color:#919191;border-color:#919191;box-shadow:0 2px 2px 0 rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn:active,.btn:hover{box-shadow:0 14px 26px -12px rgba(153,153,153,.14),0 3px 1px -2px rgba(153,153,153,.2),0 1px 5px 0 rgba(153,153,153,.12)}.btn.btn-sm{padding:.2rem .5rem;font-size:11px}.btn.btn-xs{padding:.1rem .3rem;font-size:9px}.btn.btn-round{border-radius:30px}.btn.btn-primary{color:#fff;background-color:#c82c37;border-color:#c82c37;box-shadow:0 2px 2px 0 rgba(156,39,176,.14),0 3px 1px -2px rgba(156,39,176,.2),0 1px 5px 0 rgba(156,39,176,.12)}.btn.btn-primary:active,.btn.btn-primary:hover{box-shadow:0 14px 26px -12px rgba(156,39,176,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(156,39,176,.2)}.btn.btn-info{color:#fff;background-color:#00bcd4;border-color:#00bcd4;box-shadow:0 2px 2px 0 rgba(0,188,212,.14),0 3px 1px -2px rgba(0,0,0,.2),0 1px 5px 0 rgba(0,188,212,.12)}.btn.btn-info:active,.btn.btn-info:hover{box-shadow:0 14px 26px -12px rgba(0,188,212,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(0,188,212,.2)}.btn.btn-success{color:#fff;background-color:#4caf50;border-color:#4caf50;box-shadow:0 2px 2px 0 rgba(76,175,80,.14),0 3px 1px -2px rgba(76,175,80,.2),0 1px 5px 0 rgba(76,175,80,.12)}.btn.btn-success:active,.btn.btn-success:hover{box-shadow:0 14px 26px -12px rgba(76,175,80,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(76,175,80,.2)}.btn.btn-warning{color:#fff;background-color:#ff9800;border-color:#ff9800;box-shadow:0 2px 2px 0 rgba(255,152,0,.14),0 3px 1px -2px rgba(255,152,0,.2),0 1px 5px 0 rgba(255,152,0,.12)}.btn.btn-warning:active,.btn.btn-warning:hover{box-shadow:0 14px 26px -12px rgba(255,152,0,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(255,152,0,.2)}.btn.btn-danger{color:#fff;background-color:#f44336;border-color:#f44336;box-shadow:0 2px 2px 0 rgba(244,67,54,.14),0 3px 1px -2px rgba(244,67,54,.2),0 1px 5px 0 rgba(244,67,54,.12)}.btn.btn-danger:active,.btn.btn-danger:hover{box-shadow:0 14px 26px -12px rgba(244,67,54,.42),0 4px 23px 0 rgba(0,0,0,.12),0 8px 10px -5px rgba(244,67,54,.2)}", ".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", "::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", "select.form-control-xs:not([size]):not([multiple]){height:28px}", "@charset \"UTF-8\";.grid-header{overflow-x:hidden;overflow-y:hidden}td,th{padding:3px 5px;font-size:13px;min-width:0}.c-cell-padding{padding:3px 5px!important}.c-header-title{text-transform:uppercase;font-weight:500}span.c-header-title{white-space:nowrap;overflow:hidden!important;text-overflow:ellipsis;display:block;padding:0 .3rem}thead th{min-height:50px;height:50px;border-top:none}tbody td{min-height:25px;height:25px}.status{font-weight:500;padding:2px 5px;border-radius:1.5rem;color:#16759b;display:inline-block;text-align:center;text-transform:uppercase}.status-success{color:#43a047}.status-danger{color:#f44336}.sumarize{padding:8px 12px;text-transform:uppercase;font-size:12px;color:#fff;display:inline-block;white-space:normal;font-weight:500;line-height:1;text-align:center;border-radius:10rem;background-color:#00bcd4}.cursor-pointer{cursor:pointer}label.custom-control.custom-checkbox{margin:0}.c-overflow-x-hidden{overflow-x:hidden}.c-overflow-y-hidden{overflow-y:hidden}.c-grid-header{overflow-x:hidden;overflow-y:hidden}.c-th-xs{line-height:1.15;padding:.1rem!important;font-size:.8rem;min-width:0;min-height:49px;height:49px}.c-td-xs{line-height:1.15;padding:.1rem!important;font-size:.8rem;min-width:0;min-height:1.5rem;height:1.5rem}.c-input-xs{font-size:13px!important;line-height:1.5!important;padding:3px!important;height:28px!important}.c-sticky-top{z-index:20;top:0!important}.c-sticky-left{z-index:20;left:0!important;border-left:none!important;border-right:none!important}.c-sticky-all{z-index:30;top:0!important;left:0!important;border-left:none!important;border-right:none!important}.c-sticky-spliter{z-index:40;background-color:#dee2e6;border:none;width:1px;min-width:1px}.table-striped tbody tr:nth-of-type(even) .c-sticky-left{background-color:#fff}.table-striped tbody tr:nth-of-type(odd) .c-sticky-left{background-color:#f2f2f2}.table-responsive>.table-bordered{border:1px solid #dee2e6!important}.c-badge{display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:.8rem}"]
    })
], GridSubInformationComponent);

var SdMinDateValidator_1;
let SdMinDateValidator = SdMinDateValidator_1 = class SdMinDateValidator {
    validate(c) {
        const date = c.value || null;
        const minDate = this.minDate || null;
        if (!date) {
            return null;
        }
        if (!minDate) {
            return null;
        }
        if (new Date(Date.parseFrom(date, 'dd/MM/yyyy HH:mm')).getTime() < new Date(minDate).getTime()) {
            return {
                minDate: true
            };
        }
        return null;
    }
};
__decorate([
    Input('sdMinDate')
], SdMinDateValidator.prototype, "minDate", void 0);
SdMinDateValidator = SdMinDateValidator_1 = __decorate([
    Directive({
        selector: '[sdMinDate]',
        providers: [{ provide: NG_VALIDATORS, useExisting: SdMinDateValidator_1, multi: true }]
    })
], SdMinDateValidator);

var SdMaxDateValidator_1;
let SdMaxDateValidator = SdMaxDateValidator_1 = class SdMaxDateValidator {
    validate(c) {
        const date = c.value || null;
        const maxDate = this.maxDate || null;
        if (!date) {
            return null;
        }
        if (!maxDate) {
            return null;
        }
        if (new Date(Date.parseFrom(date, 'dd/MM/yyyy HH:mm')).getTime() > new Date(maxDate).getTime()) {
            return {
                maxDate: true
            };
        }
        return null;
    }
};
__decorate([
    Input('sdMaxDate')
], SdMaxDateValidator.prototype, "maxDate", void 0);
SdMaxDateValidator = SdMaxDateValidator_1 = __decorate([
    Directive({
        selector: '[sdMaxDate]',
        providers: [{ provide: NG_VALIDATORS, useExisting: SdMaxDateValidator_1, multi: true }]
    })
], SdMaxDateValidator);

var SdCustomValidator_1;
let SdCustomValidator = SdCustomValidator_1 = class SdCustomValidator {
    validate(c) {
        return __awaiter(this, void 0, void 0, function* () {
            const value = c.value || null;
            if (this.func && typeof (this.func) === 'function') {
                const result = this.func(value);
                if (result instanceof Promise) {
                    const message = yield result;
                    if (message) {
                        return {
                            customValidator: message
                        };
                    }
                    return null;
                }
                if (result) {
                    return {
                        customValidator: result
                    };
                }
                return null;
            }
            return null;
        });
    }
};
__decorate([
    Input('sdCustomValidator')
], SdCustomValidator.prototype, "func", void 0);
SdCustomValidator = SdCustomValidator_1 = __decorate([
    Directive({
        selector: '[sdCustomValidator]',
        providers: [{ provide: NG_ASYNC_VALIDATORS, useExisting: SdCustomValidator_1, multi: true }]
    })
], SdCustomValidator);

let CommandIconPipe = class CommandIconPipe {
    transform(icon, item) {
        if (!icon) {
            return '';
        }
        if (typeof (icon) === 'string') {
            return icon;
        }
        return icon(item);
    }
};
CommandIconPipe = __decorate([
    Pipe({
        name: 'commandIcon'
    })
], CommandIconPipe);

let CommandTitlePipe = class CommandTitlePipe {
    transform(title, item) {
        if (!title) {
            return '';
        }
        if (typeof (title) === 'string') {
            return title;
        }
        return title(item);
    }
};
CommandTitlePipe = __decorate([
    Pipe({
        name: 'commandTitle'
    })
], CommandTitlePipe);

let CommandDisabledPipe = class CommandDisabledPipe {
    transform(disabled, item) {
        if (!disabled) {
            return false;
        }
        if (typeof (disabled) === 'boolean') {
            return disabled;
        }
        return disabled(item);
    }
};
CommandDisabledPipe = __decorate([
    Pipe({
        name: 'commandDisabled'
    })
], CommandDisabledPipe);

let CommandHiddenByItemPipe = class CommandHiddenByItemPipe {
    transform(item, hiddenByItem) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!hiddenByItem) {
                return false;
            }
            return hiddenByItem(item);
        });
    }
};
CommandHiddenByItemPipe = __decorate([
    Pipe({
        name: 'commandHiddenByItem'
    })
], CommandHiddenByItemPipe);

let MobileCommandFilterPipe = class MobileCommandFilterPipe {
    transform(commands, item) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            if (!commands) {
                return results;
            }
            for (const command of commands) {
                if ('children' in command) {
                    let flag = true;
                    const { hiddenByItem } = command;
                    if (hiddenByItem) {
                        const hidden = hiddenByItem(item);
                        if (hidden instanceof Promise) {
                            if (yield hidden) {
                                flag = false;
                            }
                        }
                        else {
                            if (hidden) {
                                flag = false;
                            }
                        }
                    }
                    if (flag) {
                        for (const childCommand of command.children) {
                            if (!childCommand.hiddenByItem) {
                                results.push(childCommand);
                            }
                            else {
                                const hidden = childCommand.hiddenByItem(item);
                                if (hidden instanceof Promise) {
                                    if (!(yield hidden)) {
                                        results.push(childCommand);
                                    }
                                }
                                else {
                                    if (!hidden) {
                                        results.push(childCommand);
                                    }
                                }
                            }
                        }
                    }
                }
                else {
                    const { hiddenByItem } = command;
                    if (!hiddenByItem) {
                        results.push(command);
                    }
                    else {
                        const hidden = hiddenByItem(item);
                        if (hidden instanceof Promise) {
                            if (!(yield hidden)) {
                                results.push(command);
                            }
                        }
                        else {
                            if (!hidden) {
                                results.push(command);
                            }
                        }
                    }
                }
            }
            return results;
        });
    }
};
MobileCommandFilterPipe = __decorate([
    Pipe({
        name: 'mobileCommandFilter'
    })
], MobileCommandFilterPipe);

let ColumnTitlePipe = class ColumnTitlePipe {
    transform(item, title, dynamicTitle) {
        return __awaiter(this, void 0, void 0, function* () {
            if (!title) {
                return '';
            }
            if (dynamicTitle) {
                const result = dynamicTitle(item);
                if (result instanceof Promise) {
                    return yield result;
                }
                return result;
            }
            return title;
        });
    }
};
ColumnTitlePipe = __decorate([
    Pipe({
        name: 'columnTitle'
    })
], ColumnTitlePipe);

var SdChipMinItemValidator_1;
let SdChipMinItemValidator = SdChipMinItemValidator_1 = class SdChipMinItemValidator {
    validate(c) {
        if (this.func && typeof (this.func) === 'function') {
            const result = this.func();
            if (result) {
                return {
                    minItem: result
                };
            }
            return null;
        }
        return null;
    }
};
__decorate([
    Input('sdChipMinItem')
], SdChipMinItemValidator.prototype, "func", void 0);
SdChipMinItemValidator = SdChipMinItemValidator_1 = __decorate([
    Directive({
        selector: '[sdChipMinItem]',
        providers: [{ provide: NG_VALIDATORS, useExisting: SdChipMinItemValidator_1, multi: true }]
    })
], SdChipMinItemValidator);

let EditorValidatePipe = class EditorValidatePipe {
    constructor() {
        this.delay = 1000; // Sau khoảng thời gian delay nếu không có thay đổi thì thì mới bắt đầu thực hiện validate
    }
    transform(value, item, validate) {
        return __awaiter(this, void 0, void 0, function* () {
            this.previous = new Date();
            yield new Promise(resolve => setTimeout(resolve, this.delay));
            const now = new Date();
            const dif = now.getTime() - this.previous.getTime();
            if (dif < this.delay) {
                return true;
            }
            item.editorHandler = item.editorHandler || {};
            if (!validate) {
                item.editorHandler.errorMessage = null;
                return true;
            }
            const result = validate(item);
            if (result instanceof Promise) {
                item.editorHandler.errorMessage = yield result;
                return true;
            }
            else {
                item.editorHandler.errorMessage = result;
                return true;
            }
        });
    }
};
EditorValidatePipe = __decorate([
    Pipe({
        name: 'editorValidate'
    })
], EditorValidatePipe);

let EditorDynamicItemPipe = class EditorDynamicItemPipe {
    constructor() {
        this.previousResults = [];
        this.delay = 200; // Sau khoảng thời gian delay nếu không có thay đổi thì thì mới bắt đầu thực hiện gọi hàm
    }
    transform(value, item, editor) {
        var _a, _b;
        return __awaiter(this, void 0, void 0, function* () {
            this.previous = new Date();
            yield new Promise(resolve => setTimeout(resolve, this.delay));
            const now = new Date();
            const dif = now.getTime() - this.previous.getTime();
            if (dif < this.delay) {
                return this.previousResults;
            }
            if (editor.type === 'default') {
                return editor.items;
            }
            else if (editor.type === 'dependent') {
                const results = (_b = (_a = editor).items) === null || _b === void 0 ? void 0 : _b.call(_a, item);
                if (!results) {
                    this.previousResults = [];
                    return this.previousResults;
                }
                if (results instanceof Promise) {
                    this.previousResults = yield results;
                    return this.previousResults;
                }
                this.previousResults = results;
                return results;
            }
            this.previousResults = [];
            return this.previousResults;
        });
    }
};
EditorDynamicItemPipe = __decorate([
    Pipe({
        name: 'editorDynamicItem'
    })
], EditorDynamicItemPipe);

let ColumnHtmlTemplatePipe = class ColumnHtmlTemplatePipe {
    transform(value, rowData, htmlTemplate) {
        if (typeof (htmlTemplate) !== 'function') {
            return value;
        }
        return htmlTemplate(value, rowData, window.innerWidth < MobileMaxWidth);
    }
};
ColumnHtmlTemplatePipe = __decorate([
    Pipe({
        name: 'columnHtmlTemplate'
    })
], ColumnHtmlTemplatePipe);

let ColumnCommandFilterPipe = class ColumnCommandFilterPipe {
    transform(commands, item) {
        return __awaiter(this, void 0, void 0, function* () {
            const results = [];
            if (!commands) {
                return results;
            }
            for (const command of commands) {
                const { hiddenByItem } = command;
                if (!hiddenByItem) {
                    results.push(command);
                }
                else {
                    const hidden = hiddenByItem(item);
                    if (hidden instanceof Promise) {
                        if (!(yield hidden)) {
                            results.push(command);
                        }
                    }
                    else {
                        if (!hidden) {
                            results.push(command);
                        }
                    }
                }
            }
            return results;
        });
    }
};
ColumnCommandFilterPipe = __decorate([
    Pipe({
        name: 'columnCommandFilter'
    })
], ColumnCommandFilterPipe);

// https://stackoverflow.com/questions/4459379/preview-an-image-before-it-is-uploaded
let UploadFileControlComponent = class UploadFileControlComponent {
    constructor(ref, notifyService, translateService) {
        this.ref = ref;
        this.notifyService = notifyService;
        this.translateService = translateService;
        this.id = `I${v4()}`;
        this.previewFiles = [];
        this.type = 'file';
        this.disabled = false;
        this.extensions = [];
        this.max = 1;
        this.srcs = [];
        this.align = 'center';
        this.sdChange = new EventEmitter();
        this.reload = (previewFiles) => {
            if (previewFiles) {
                this.previewFiles = previewFiles;
                return;
            }
            this.previewFiles = this.srcs.map(src => ({
                file: null,
                previewSrc: null,
                src,
                isPreviewImage: this.type === 'image'
            }));
        };
        this.validate = (file) => __awaiter(this, void 0, void 0, function* () {
            var _a;
            if (this.type === 'image') {
                if (file.type.split('/')[0] !== 'image') {
                    return `[${file.name}] ${this.translateService.translate('Uploaded file is not an image')}`;
                }
            }
            if ((_a = this.extensions) === null || _a === void 0 ? void 0 : _a.length) {
                const lastDot = file.name.lastIndexOf('.');
                const extension = file.name.substring(lastDot + 1);
                if (!this.extensions.some(e => e.toUpperCase() === extension.toUpperCase())) {
                    return `[${file.name}] ${this.translateService.translate('Uploaded file is not match extension')} ${this.extensions.join(', ')}`;
                }
            }
            if (this.maxSize) {
                if (this.maxSize * 1024 * 1024 < file.size) {
                    return `[${file.name}] ${this.translateService.translate('Max file size')} ${this.maxSize} Mbs`;
                }
            }
            if (this.type === 'image' && (this.maxWidth || this.maxHeight)) {
                const message = yield new Promise(resolve => {
                    const URL = window.URL || window.webkitURL;
                    const img = new Image();
                    img.onload = () => {
                        if (this.maxWidth && img.width > this.maxWidth) {
                            resolve(`[${file.name}] ${this.translateService.translate('Max image width')} ${this.maxWidth}px`);
                        }
                        if (this.maxHeight && img.height > this.maxHeight) {
                            resolve(`[${file.name}] ${this.translateService.translate('Max image height')} ${this.maxHeight}px`);
                        }
                        resolve();
                    };
                    img.src = URL.createObjectURL(file);
                });
                if (message) {
                    return message;
                }
            }
            return null;
        });
        this.preview = () => {
            for (const previewFile of this.previewFiles.filter(e => e.file)) {
                const reader = new FileReader();
                reader.onload = (evt) => {
                    var _a;
                    previewFile.previewSrc = evt.target.result;
                    previewFile.isPreviewImage = ((_a = previewFile.file) === null || _a === void 0 ? void 0 : _a.type.split('/')[0]) === 'image';
                    this.ref.detectChanges();
                };
                reader.readAsDataURL(previewFile.file);
            }
        };
    }
    ngOnInit() {
        this.previewFiles = this.srcs.map(src => ({
            file: null,
            previewSrc: null,
            src,
            isPreviewImage: this.type === 'image'
        }));
    }
    ngAfterViewInit() {
    }
    onUpload(previewFile) {
        if ($$1(`#${this.id}`).length) {
            $$1('body').children(`#${this.id}`).remove();
        }
        if (previewFile || this.max === 1) {
            $$1('body').append(`<input id="${this.id}" style="display: none" type="file" />`);
        }
        else {
            $$1('body').append(`<input id="${this.id}" style="display: none" type="file" multiple />`);
        }
        $$1(`#${this.id}`).on('change', (evt) => __awaiter(this, void 0, void 0, function* () {
            const target = evt.target;
            if (!target.files.length) {
                return;
            }
            if (!previewFile) {
                if (target.files.length + this.previewFiles.length > this.max) {
                    this.notifyService.notify.warning(`${this.translateService.translate('Max number of files')} ${this.max}`);
                    return;
                }
                for (let i = 0; i < target.files.length; i++) {
                    const message = yield this.validate(target.files.item(i));
                    if (message) {
                        this.notifyService.notify.warning(message);
                        return;
                    }
                }
                // tslint:disable-next-line: prefer-for-of
                for (let i = 0; i < target.files.length; i++) {
                    const file = target.files.item(i);
                    const lastDot = file.name.lastIndexOf('.');
                    const extension = file.name.substring(lastDot + 1);
                    this.previewFiles.push({
                        file: target.files.item(i),
                        isPreviewImage: false,
                        previewSrc: null,
                        src: null,
                        fileName: file.name,
                        extension
                    });
                }
            }
            else {
                const idx = this.previewFiles.indexOf(previewFile);
                const file = target.files.item(0);
                const lastDot = file.name.lastIndexOf('.');
                const extension = file.name.substring(lastDot + 1);
                this.previewFiles[idx] = {
                    file: target.files.item(0),
                    isPreviewImage: false,
                    previewSrc: null,
                    src: null,
                    fileName: file.name,
                    extension
                };
            }
            this.preview();
            this.sdChange.emit(this.previewFiles);
            $$1('body').children(`#${this.id}`).remove();
            this.ref.detectChanges();
        }));
        $$1(`#${this.id}`).trigger('click');
    }
    onRemove(previewFile) {
        const idx = this.previewFiles.indexOf(previewFile);
        this.previewFiles.splice(idx, 1);
        this.sdChange.emit(this.previewFiles);
    }
};
UploadFileControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: NotifyService },
    { type: TranslateService }
];
__decorate([
    Input()
], UploadFileControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "extensions", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "max", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "maxSize", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "maxWidth", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "maxHeight", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "srcs", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "previewWidth", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "previewHeight", void 0);
__decorate([
    Input()
], UploadFileControlComponent.prototype, "align", void 0);
__decorate([
    Output()
], UploadFileControlComponent.prototype, "sdChange", void 0);
UploadFileControlComponent = __decorate([
    Component({
        selector: 'sd-upload-file-control',
        template: "<label *ngIf=\"label\" class=\"sd-label d-block\">{{label}}</label>\r\n<div class=\"row c-upload-file-control\" [ngClass]=\"{'justify-content-center': align === 'center', 'justify-content-start': align === 'left'}\">\r\n  <div *ngFor=\"let file of previewFiles\" class=\"c-area c-view\" [ngStyle]=\"{'width': previewWidth, 'height': previewHeight}\">\r\n    <div class=\"c-preview\">\r\n      <div class=\"c-img-container\">\r\n        <ng-container *ngIf=\"file.previewSrc;else elseOrigin\">\r\n          <img *ngIf=\"file.isPreviewImage\" class=\"c-img\" [src]=\"file.previewSrc\" alt=\"Preview\" />\r\n          <i *ngIf=\"!file.isPreviewImage\" class=\"fa fa-file-text-o fa-fw c-icon-file\"></i>\r\n        </ng-container>\r\n        <ng-template #elseOrigin>\r\n          <img *ngIf=\"type === 'image'\" class=\"c-img\" [src]=\"file.src\" alt=\"Preview\" />\r\n          <i *ngIf=\"type !== 'image'\" class=\"fa fa-file-text-o fa-fw c-icon-file\"></i>\r\n        </ng-template>\r\n      </div>\r\n      <div *ngIf=\"!disabled\" class=\"c-action\">\r\n        <i class=\"fa fa-upload c-icon-upload\" (click)=\"onUpload(file)\"></i>\r\n        <i class=\"fa fa-times c-icon-remove\" (click)=\"onRemove(file)\"></i>\r\n      </div>\r\n    </div>\r\n  </div>\r\n  <div *ngIf=\"previewFiles?.length < max && !disabled\" class=\"c-area\" [ngStyle]=\"{'width': previewWidth, 'height': previewHeight}\">\r\n    <i class=\"fa fa-fw c-icon\" [ngClass]=\"{'fa-upload': type === 'file', 'fa-picture-o': type === 'image'}\"\r\n      (click)=\"onUpload()\"></i>\r\n  </div>\r\n</div>",
        styles: [".sd-label{font-weight:500;color:#919191!important}.sd-label.sd-label-primary{color:#c82c37!important}.sd-label.sd-label-success{color:#4caf50!important}.sd-label.sd-label-info{color:#00bcd4!important}.sd-label.sd-label-warning{color:#ff9800!important}.sd-label.sd-label-danger{color:#f44336!important}", ".c-upload-file-control{width:100%;padding:5px 10px}.c-upload-file-control .c-area{border:2px dashed grey;border-radius:5px;display:table;text-align:center;margin:3px;opacity:.6}.c-upload-file-control .c-area.c-view{border:2px solid grey;opacity:.9}.c-upload-file-control .c-area:hover{opacity:.9}.c-upload-file-control .c-area .c-icon{vertical-align:middle;display:table-cell;margin:16px;font-size:50px;color:grey;cursor:pointer}.c-upload-file-control .c-area .c-preview{vertical-align:middle;display:table-cell}.c-upload-file-control .c-area .c-preview .c-img-container{width:100%;padding:5px 10px 0;height:calc(100% - 20px);display:table}.c-upload-file-control .c-area .c-preview .c-img-container .c-img{max-width:calc(100% - 20px);max-height:calc(100% - 5px)}.c-upload-file-control .c-area .c-preview .c-img-container .c-icon-file{font-size:50px;color:grey;vertical-align:middle;display:table-cell}.c-upload-file-control .c-area .c-preview .c-action{padding:0 5px;width:100%;height:20px}.c-upload-file-control .c-area .c-preview .c-action .c-icon-upload{color:grey;float:left;cursor:pointer}.c-upload-file-control .c-area .c-preview .c-action .c-icon-remove{color:red;float:right;cursor:pointer}"]
    })
], UploadFileControlComponent);

Date.equal = (date1, date2) => {
    if (!Date.isDate(date1) && !Date.isDate(date2)) {
        return true;
    }
    if (!Date.isDate(date1) || !Date.isDate(date2)) {
        return false;
    }
    return new Date(date1).getTime() === new Date(date2).getTime();
};
Date.parseFrom = (value, format) => {
    if (!value) {
        return null;
    }
    if (!format) {
        return null;
    }
    value = value.toString();
    let dd = format.indexOf('dd') > -1 ? value.substr(format.indexOf('dd'), 'dd'.length) : '';
    let MM = format.indexOf('MM') > -1 ? value.substr(format.indexOf('MM'), 'MM'.length) : '';
    let yyyy = format.indexOf('yyyy') > -1 ? value.substr(format.indexOf('yyyy'), 'yyyy'.length) : '';
    const HH = format.indexOf('HH') > -1 ? value.substr(format.indexOf('HH'), 'HH'.length) : '00';
    const mm = format.indexOf('mm') > -1 ? value.substr(format.indexOf('mm'), 'mm'.length) : '00';
    const ss = format.indexOf('ss') > -1 ? value.substr(format.indexOf('ss'), 'ss'.length) : '00';
    const today = new Date();
    let strDate = '';
    if (yyyy && MM && dd) {
        strDate += `${MM}/${dd}/${yyyy}`;
    }
    else {
        yyyy = today.getFullYear().toString();
        MM = (today.getMonth() + 1).toString().padStart(2, '0');
        dd = today.getDate().toString().padStart(2, '0');
        strDate += `${MM}/${dd}/${yyyy}`;
    }
    strDate += ` ${HH}:${mm}:${ss}`;
    return new Date(strDate.trim());
};
Date.isDate = (value) => {
    if (!value) {
        return false;
    }
    const date = new Date(value);
    return !isNaN(date.getTime());
};
Date.toFormat = (value, format) => {
    if (!Date.isDate(value)) {
        return '';
    }
    const date = new Date(value);
    return date.toFormat(format);
};
Date.addMiliseconds = (value, miliseconds) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addMiliseconds(miliseconds);
};
Date.addHours = (value, hours) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addHours(hours);
};
Date.addDays = (value, days) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addDays(days);
};
Date.addMonths = (value, months) => {
    if (!Date.isDate(value)) {
        return null;
    }
    const date = new Date(value);
    return date.addMonths(months);
};
Date.begin = (value) => {
    if (!Date.isDate(value)) {
        return null;
    }
    return new Date(value.toFormat('MM/dd/yyyy'));
};
Date.end = (value) => {
    if (!Date.isDate(value)) {
        return null;
    }
    return new Date(value).addDays(1).begin().addMiliseconds(-1);
};
Date.prototype.begin = function () {
    const date = this;
    return new Date(date.toFormat('MM/dd/yyyy'));
};
Date.prototype.end = function () {
    const date = this;
    return date.addDays(1).begin().addMiliseconds(-1);
};
Date.prototype.addMiliseconds = function (miliseconds) {
    const date = this;
    date.setMilliseconds(date.getMilliseconds() + miliseconds);
    return date;
};
Date.prototype.addHours = function (hours) {
    const date = this;
    date.setHours(date.getHours() + hours);
    return date;
};
Date.prototype.addDays = function (days) {
    const date = this;
    date.setDate(date.getDate() + days);
    return date;
};
Date.prototype.addMonths = function (months) {
    const date = this;
    date.setMonth(date.getMonth() + months);
    return date;
};
Date.prototype.toFormat = function (format) {
    const date = this;
    let result = format;
    result = result.replace('yyyy', date.getFullYear().toString());
    result = result.replace('MM', (date.getMonth() + 1).toString().padStart(2, '0'));
    result = result.replace('dd', date.getDate().toString().padStart(2, '0'));
    result = result.replace('HH', date.getHours().toString().padStart(2, '0'));
    result = result.replace('mm', date.getMinutes().toString().padStart(2, '0'));
    result = result.replace('ss', date.getSeconds().toString().padStart(2, '0'));
    return result;
};

let InputTooltipPipe = class InputTooltipPipe {
    transform(value, tooltip) {
        if (typeof (tooltip) === 'string') {
            return tooltip;
        }
        return tooltip(value);
    }
};
InputTooltipPipe = __decorate([
    Pipe({
        name: 'inputTooltipPipe'
    })
], InputTooltipPipe);

let CellClassNamePipe = class CellClassNamePipe {
    transform(value, rowData, column, isChildren) {
        const classNames = [];
        if (column.click) {
            classNames.push('cursor-pointer');
        }
        if (isChildren) {
            classNames.push('c-children');
        }
        if (IsMobile) {
            classNames.push('c-mobile-value');
        }
        if (column.badge) {
            const badge = column.badge(rowData, value);
            if (badge) {
                classNames.push('badge');
                if (IsMobile) {
                    classNames.push('c-mobile-badge');
                }
                else {
                    classNames.push('c-badge');
                }
                if (badge === 'PRIMARY') {
                    classNames.push('badge-primary');
                }
                else if (badge === 'SECONDARY') {
                    classNames.push('badge-secondary');
                }
                else if (badge === 'WARNING') {
                    classNames.push('badge-warning');
                }
                else if (badge === 'SUCCESS') {
                    classNames.push('badge-success');
                }
                else if (badge === 'DANGER') {
                    classNames.push('badge-danger');
                }
                else if (badge === 'LIGHT') {
                    classNames.push('badge-light');
                }
                else if (badge === 'DARK') {
                    classNames.push('badge-dark');
                }
            }
        }
        return classNames.join(' ');
    }
};
CellClassNamePipe = __decorate([
    Pipe({
        name: 'cellClassName'
    })
], CellClassNamePipe);

let ValueTransformPipe = class ValueTransformPipe {
    // tslint:disable-next-line: max-line-length
    transform(value, rowData, column) {
        if (column.transform) {
            return column.transform(value, rowData);
        }
        return value;
    }
};
ValueTransformPipe = __decorate([
    Pipe({
        name: 'valueTransform'
    })
], ValueTransformPipe);

let EditorSubInformationHandlerPipe = class EditorSubInformationHandlerPipe {
    transform(value, item, columns) {
        const visible = (column) => {
            if (column.type === 'children') {
                return false;
            }
            let isDisabled = false;
            // Kiểm tra xem có bị disabled hay không?
            if (column.editor) {
                isDisabled = typeof (column.editor.disabled) === 'function' ? column.editor.disabled(item) : column.editor.disabled;
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            // Nếu bị disabled return false
            if (isDisabled) {
                return false;
            }
            // Hiển thị editor nếu dòng đó:
            // Đang được edit: editingStatus
            return item.editingStatus
                // Được thiết lập alwayDisplay
                || (column.editor && column.editor.alwayDisplay);
        };
        item.editorHandler = item.editorHandler || {};
        for (const column of columns) {
            item.editorHandler.disabled = false;
            item.editorHandler[column.field] = {};
            if (item.editorHandler.disabled) {
                item.editorHandler[column.field].visible = false;
            }
            else {
                item.editorHandler[column.field].visible = visible(column);
            }
        }
        return true;
    }
};
EditorSubInformationHandlerPipe = __decorate([
    Pipe({
        name: 'editorSubInformationHandler'
    })
], EditorSubInformationHandlerPipe);

let SafeHtmlPipe = class SafeHtmlPipe {
    constructor(sanitizer) {
        this.sanitizer = sanitizer;
    }
    transform(html) {
        return this.sanitizer.bypassSecurityTrustHtml(html);
    }
};
SafeHtmlPipe.ctorParameters = () => [
    { type: DomSanitizer }
];
SafeHtmlPipe = __decorate([
    Pipe({
        name: 'safeHtml',
    })
], SafeHtmlPipe);

let GridDesktopColumnViewComponent = class GridDesktopColumnViewComponent {
    constructor() { }
};
__decorate([
    Input()
], GridDesktopColumnViewComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridDesktopColumnViewComponent.prototype, "item", void 0);
GridDesktopColumnViewComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-column-view',
        template: "<ng-container *ngIf=\"column && item\">\r\n  <ng-container *ngIf=\"column.htmlTemplate;else useDefaultView\">\r\n    <div [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\">\r\n    </div>\r\n  </ng-container>\r\n  <ng-template #useDefaultView>\r\n    <div *ngIf=\"column.type === 'string'\">\r\n      <span [className]=\"item[column.field] | cellDesktopClassName:item:column\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n        <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n          (click)=\"column.click(item[column.field], item)\">{{item[column.field]}}</a>\r\n        <ng-container *ngIf=\"!column.click\">{{item[column.field]}}</ng-container>\r\n      </span>\r\n      <ng-container *ngIf=\"column.commands | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n        <button *ngFor=\"let columnCommand of filteredColumnCommands\" (click)=\"columnCommand.click(item)\" type=\"button\"\r\n          class=\"c-btn-icon\" [matTooltip]=\"columnCommand.title | commandTitle:item\">\r\n          <i class=\"{{columnCommand.icon | commandIcon:item}}\" aria-hidden=\"true\"></i>\r\n        </button>\r\n      </ng-container>\r\n    </div>\r\n    <div *ngIf=\"column.type === 'color'\">\r\n      <input disabled=\"true\" type=\"color\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"\r\n        (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n    </div>\r\n    <div *ngIf=\"column.type === 'number'\">\r\n      <span [className]=\"item[column.field] | cellDesktopClassName:item:column\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n        <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n          (click)=\"column.click(item[column.field], item)\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</a>\r\n        <ng-container *ngIf=\"!column.click\">\r\n          {{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</ng-container>\r\n      </span>\r\n    </div>\r\n    <div class=\"text-center\" *ngIf=\"column.type === 'date'\">\r\n      {{item[column.field] | date:'dd/MM/yyyy'}}\r\n    </div>\r\n    <div class=\"text-center\" *ngIf=\"column.type === 'datetime'\">\r\n      {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}\r\n    </div>\r\n    <div class=\"text-center\" *ngIf=\"column.type === 'time'\">\r\n      {{item[column.field] | date:'HH:mm'}}\r\n    </div>\r\n    <div class=\"align-middle text-center\" *ngIf=\"column.type === 'bool'\">\r\n      <span *ngIf=\"!item.editorHandler[column.field].visible && item[column.field]\"\r\n        class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n      <span *ngIf=\"!item.editorHandler[column.field].visible && !item[column.field]\"\r\n        class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n    </div>\r\n    <div *ngIf=\"column.type === 'values'\">\r\n      <ng-container *ngIf=\"column?.dictionary[item[column.field]] as dic; else elseNotInDic\">\r\n        <div *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status\"\r\n          [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n          {{dic.text}}\r\n        </div>\r\n        <ng-template #elseNoStatus>\r\n          <div class=\"text-left\">\r\n            {{dic.text}}\r\n          </div>\r\n        </ng-template>\r\n      </ng-container>\r\n      <ng-template #elseNotInDic>\r\n        <div class=\"text-left\">\r\n          {{item[column.field]}}\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n    <div *ngIf=\"column.type === 'radio'\">\r\n      {{item[column.field]}}\r\n    </div>\r\n    <div class=\"align-middle text-center\" *ngIf=\"column.type === 'image'\">\r\n      <img *ngIf=\"item[column.field]\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n        [height]=\"column.display?.height\" style=\"margin: 5px 0\"\r\n        (click)=\"column.click && column.click(item[column.field], item)\" [ngClass]=\"{'c-clickable':column.click}\">\r\n      <i *ngIf=\"!item[column.field]\" class=\"fa fa-picture-o fa-fw c-img\"\r\n        [ngClass]=\"{'c-clickable':column.click}\" (click)=\"column.click && column.click(item[column.field], item)\"></i>\r\n    </div>\r\n  </ng-template>\r\n</ng-container>",
        styles: [".c-badge{display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:12px;max-width:80%;margin:0 auto}.c-badge a{color:#fff}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:center;text-transform:uppercase;width:100%}.status-success{color:#4caf50}.status-danger{color:#f44336}.c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.c-clickable{cursor:pointer}.c-img{font-size:50px;opacity:.5}.c-img.c-clickable:hover{opacity:.9}"]
    })
], GridDesktopColumnViewComponent);

let GridDesktopColumnEditComponent = class GridDesktopColumnEditComponent {
    constructor(ref) {
        this.ref = ref;
        this.sdChange = new EventEmitter();
        this.onEditorChange = (column, item, value) => {
            var _a, _b, _c;
            if (column.type !== 'children') {
                (_c = (_a = column.editor) === null || _a === void 0 ? void 0 : (_b = _a).change) === null || _c === void 0 ? void 0 : _c.call(_b, item, value);
                this.ref.detectChanges();
                this.sdChange.emit();
            }
        };
        this.onSearch = (searchValue, item, column) => {
            item[column.field] = searchValue;
        };
    }
};
GridDesktopColumnEditComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], GridDesktopColumnEditComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridDesktopColumnEditComponent.prototype, "item", void 0);
__decorate([
    Output()
], GridDesktopColumnEditComponent.prototype, "sdChange", void 0);
GridDesktopColumnEditComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-column-edit',
        template: "<ng-container *ngIf=\"column && item\">\r\n  <div *ngIf=\"column.type === 'string'\">\r\n    <div *ngIf=\"column.editor?.item;else elseUseInput\">\r\n      <ng-container *ngIf=\"column.editor.autocomplete; else elseUseSelect\">\r\n        <sd-grid-autocomplete-control *ngIf=\"column.editor.item.type === 'dependent'\"\r\n          [items]=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async\"\r\n          [valueField]=\"column.editor.item.value\" [displayField]=\"column.editor.item.display\"\r\n          [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,$event)\"\r\n          (search)=\"onSearch($event, item, column)\">\r\n        </sd-grid-autocomplete-control>\r\n        <sd-grid-autocomplete-control *ngIf=\"column.editor.item.type === 'default'\"\r\n          [items]=\"'' | editorDynamicItem:item:column.editor.item | async\" [valueField]=\"column.editor.item.value\"\r\n          [displayField]=\"column.editor.item.display\" [(model)]=\"item[column.field]\"\r\n          (sdChange)=\"onEditorChange(column,item,$event)\">\r\n        </sd-grid-autocomplete-control>\r\n      </ng-container>\r\n      <ng-template #elseUseSelect>\r\n        <select *ngIf=\"column.editor.item.type === 'dependent'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,item[column.field])\">\r\n          <ng-container\r\n            *ngIf=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async; let dynamicItems\">\r\n            <ng-container *ngIf=\"dynamicItems?.subscribe;else elseIsArray\">\r\n              <option *ngFor=\"let data of dynamicItems | async\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-container>\r\n            <ng-template #elseIsArray>\r\n              <option *ngFor=\"let data of (dynamicItems || [])\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-template>\r\n          </ng-container>\r\n        </select>\r\n        <select *ngIf=\"column.editor.item?.type === 'default'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,item[column.field])\">\r\n          <ng-container *ngIf=\"'' | editorDynamicItem:item:column.editor.item | async; let dynamicItems\">\r\n            <option *ngFor=\"let data of dynamicItems\" [value]=\"data[column.editor.item.value]\">\r\n              {{data[column.editor.item.display]}}\r\n            </option>\r\n          </ng-container>\r\n        </select>\r\n      </ng-template>\r\n    </div>\r\n    <ng-template #elseUseInput>\r\n      <div class=\"input-group\">\r\n        <input class=\"form-control c-input-xs\" [ngClass]=\"{'border-right-0':column.editor && column.editor.click}\"\r\n          [(ngModel)]=\"item[column.field]\" (keyup.enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n          (change)=\"onEditorChange(column,item,item[column.field])\">\r\n        <div *ngIf=\"column.editor?.click\" class=\"input-group-append cursor-pointer\">\r\n          <span class=\"input-group-text border-0 py-0 px-1\" style=\"background:#FFF\" (click)=\"column.editor.click(item)\">\r\n            <i class=\"fa fa-search\"></i>\r\n          </span>\r\n        </div>\r\n      </div>\r\n    </ng-template>\r\n  </div>\r\n  <div *ngIf=\"column.type === 'color'\">\r\n    <input type=\"color\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"\r\n      (change)=\"onEditorChange(column,item,item[column.field])\">\r\n  </div>\r\n  <div *ngIf=\"column.type === 'number'\">\r\n    <input type=\"number\" class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"\r\n      (keyup.Enter)=\"column.editor?.keyupEnter && column.editor?.keyupEnter(item)\"\r\n      (change)=\"onEditorChange(column,item,item[column.field])\">\r\n  </div>\r\n  <div *ngIf=\"column.type === 'date'\">\r\n    <sd-grid-date-picker-control [(model)]=\"item[column.field]\" type=\"date\"></sd-grid-date-picker-control>\r\n  </div>\r\n  <div class=\"text-center\" *ngIf=\"column.type === 'datetime'\">\r\n    <sd-grid-date-picker-control [(model)]=\"item[column.field]\" type=\"datetime\"></sd-grid-date-picker-control>\r\n  </div>\r\n  <div class=\"text-center\" *ngIf=\"column.type === 'time'\">\r\n    <sd-grid-date-picker-control [(model)]=\"item[column.field]\" type=\"time\"></sd-grid-date-picker-control>\r\n  </div>\r\n  <div class=\"align-middle text-center\" *ngIf=\"column.type === 'bool'\">\r\n    <sd-switch-control [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,item[column.field])\">\r\n    </sd-switch-control>\r\n    <!-- <mat-slide-toggle [(ngModel)]=\"item[column.field]\"\r\n      (change)=\"onEditorChange(column,item,item[column.field])\" color=\"primary\">\r\n    </mat-slide-toggle> -->\r\n  </div>\r\n  <div *ngIf=\"column.type === 'values'\">\r\n    <ng-container *ngIf=\"column.editor?.autocomplete;else elseUseSelect\">\r\n      <ng-container *ngIf=\"column.editor.item;else elseUseValues\">\r\n        <sd-grid-autocomplete-control *ngIf=\"column.editor.item.type === 'dependent'\"\r\n          [items]=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async\"\r\n          [valueField]=\"column.editor.item.value\" [displayField]=\"column.editor.item.display\"\r\n          [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,$event)\"\r\n          (search)=\"onSearch($event, item, column)\">\r\n        </sd-grid-autocomplete-control>\r\n        <ng-template #elseDynamicByValue>\r\n          <sd-grid-autocomplete-control [items]=\"column.editor.item.items\" [valueField]=\"column.editor.item.value\"\r\n            [displayField]=\"column.editor.item.display\" [(model)]=\"item[column.field]\"\r\n            (sdChange)=\"onEditorChange(column,item,$event)\">\r\n          </sd-grid-autocomplete-control>\r\n        </ng-template>\r\n      </ng-container>\r\n      <ng-template #elseUseValues>\r\n        <sd-grid-autocomplete-control [items]=\"column.values\" valueField=\"value\" displayField=\"text\"\r\n          [(model)]=\"item[column.field]\" (sdChange)=\"onEditorChange(column,item,$event)\">\r\n        </sd-grid-autocomplete-control>\r\n      </ng-template>\r\n    </ng-container>\r\n    <ng-template #elseUseSelect>\r\n      <ng-container *ngIf=\"column.editor?.item;else elseUseValues\">\r\n        <select *ngIf=\"column.editor.item.type === 'dependent'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,$event)\">\r\n          <option value=\"\">{{'Please select' | sdTranslate}}</option>\r\n          <ng-container *ngIf=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item\r\n             | async; let dynamicItems\">\r\n            <ng-container *ngIf=\"dynamicItems?.subscribe;else elseIsArray\">\r\n              <option *ngFor=\"let data of dynamicItems | async\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-container>\r\n            <ng-template #elseIsArray>\r\n              <option *ngFor=\"let data of (dynamicItems || [])\" [value]=\"data[column.editor.item.value]\">\r\n                {{data[column.editor.item.display]}}\r\n              </option>\r\n            </ng-template>\r\n          </ng-container>\r\n        </select>\r\n        <select *ngIf=\"column.editor.item.type === 'dependent'\" class=\"form-control form-control-xs\"\r\n          [(ngModel)]=\"item[column.field]\" (change)=\"onEditorChange(column,item,item[column.field])\">\r\n          <option value=\"\">{{'Please select' | sdTranslate}}</option>\r\n          <ng-container\r\n            *ngIf=\"item[column.editor.item.dependOnField] | editorDynamicItem:item:column.editor.item | async; let dynamicItems\">\r\n            <option *ngFor=\"let data of dynamicItems\" [value]=\"data[column.editor.item.value]\">\r\n              {{data[column.editor.item.display]}}\r\n            </option>\r\n          </ng-container>\r\n        </select>\r\n      </ng-container>\r\n      <ng-template #elseUseValues>\r\n        <select class=\"form-control form-control-xs\" [(ngModel)]=\"item[column.field]\"\r\n          (change)=\"column.editor?.change && column.editor.change(item)\">\r\n          <option value=\"\">{{'Please select' | sdTranslate}}</option>\r\n          <option *ngFor=\"let data of column.values\" [value]=\"data.value\">{{data.text}}\r\n          </option>\r\n        </select>\r\n      </ng-template>\r\n    </ng-template>\r\n  </div>\r\n  <div *ngIf=\"column.type === 'radio'\">\r\n    <section class=\"mt-2 ml-3\" style=\"align-content: center; align-items: center;\">\r\n      <mat-radio-group style=\"display: flex\" [(ngModel)]=\"item[column.field]\"\r\n        (change)=\"column.editor?.change && column.editor?.change(item)\">\r\n        <mat-radio-button *ngIf=\"!column.editor?.required\" color=\"warn\" class=\"mr-2\" value=\"\">\r\n          {{'Please select' | sdTranslate}}\r\n        </mat-radio-button>\r\n        <mat-radio-button color=\"primary\" class=\"mr-2\" *ngFor=\"let data of column.values\"\r\n          [value]=\"data[column.valueField]\">\r\n          {{data[column.displayField]}}\r\n        </mat-radio-button>\r\n      </mat-radio-group>\r\n    </section>\r\n  </div>\r\n  <div class=\"align-middle text-center\" *ngIf=\"column.type === 'image'\">\r\n    <img [src]=\"item[column.field]\" [width]=\"column.display?.width\" [height]=\"column.display?.height\"\r\n      style=\"margin: 5px 0\" (click)=\"column.click && column.click(item[column.field], item)\">\r\n  </div>\r\n</ng-container>",
        changeDetection: ChangeDetectionStrategy.OnPush,
        styles: [".form-control-xs,.input-group-xs>.form-control,.input-group-xs>.input-group-append>.input-group-text{font-size:13px!important;line-height:1.5!important;padding:3px 25px 3px 3px!important;height:28px!important}", "select.form-control-xs:not([size]):not([multiple]){height:28px}"]
    })
], GridDesktopColumnEditComponent);

let GridDesktopInlineFilterComponent = class GridDesktopInlineFilterComponent {
    constructor(deviceService) {
        this.deviceService = deviceService;
        this.externalFilters = [];
        this.columns = [];
        this.externalFilter = {};
        this.filter = {};
        this.showInlineFilter = false;
        this.showColumnInlineFilter = false;
        this.sdChange = new EventEmitter();
        this.displayKey = 'SDCUSTOM';
        this.onUpdateFilter = () => {
            this.sdChange.emit();
        };
        this.isDesktop = this.deviceService.isDesktop();
    }
};
GridDesktopInlineFilterComponent.ctorParameters = () => [
    { type: DeviceDetectorService }
];
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "externalFilters", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "columns", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "externalFilter", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "filter", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "showInlineFilter", void 0);
__decorate([
    Input()
], GridDesktopInlineFilterComponent.prototype, "showColumnInlineFilter", void 0);
__decorate([
    Output()
], GridDesktopInlineFilterComponent.prototype, "sdChange", void 0);
GridDesktopInlineFilterComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-inline-filter',
        template: "<ng-container *ngIf=\"isDesktop && showInlineFilter\">\r\n  <div *ngIf=\"externalFilters?.length\" class=\"row\">\r\n    <ng-container *ngFor=\"let item of externalFilters\">\r\n      <div *ngIf=\"item.type !=='daterange' && item.type !=='numberrange';else elseFilterRange\"\r\n        class=\"col-lg-2 col-md-3 col-sm-6\">\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\"\r\n          [(model)]=\"externalFilter[item.field]\" (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n          [(model)]=\"externalFilter[item.field]\" (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\"[{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n          [(model)]=\"externalFilter[item.field]\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-select-control>\r\n        <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-radio-control>\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'custom'\"\r\n          [(model)]=\"externalFilter[displayKey + item.field]\"\r\n          (sdClick)=\"item?.onClick(externalFilter, item.field, displayKey + item.field)\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <ng-container *ngIf=\"item.type === 'values'\">\r\n          <sd-select-control *ngIf=\"item.selection === 'MULTIPLE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\" multiple=\"true\">\r\n          </sd-select-control>\r\n          <sd-autocomplete-control *ngIf=\"item.selection === 'AUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\">\r\n          </sd-autocomplete-control>\r\n          <sd-chip-control *ngIf=\"item.selection === 'MULTIPLEAUTOCOMPLETE'\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\">\r\n          </sd-chip-control>\r\n          <sd-select-control *ngIf=\"!item.selection\" [label]=\"item.title\" [items]=\"item.values\"\r\n            [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n            (sdChange)=\"onUpdateFilter()\">\r\n          </sd-select-control>\r\n        </ng-container>\r\n        <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.field]\"\r\n          type=\"date\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-date-picker-control>\r\n        <sd-date-range-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='daterangefull'\"\r\n          [(fromDate)]=\"externalFilter[item.field].from\" [(toDate)]=\"externalFilter[item.field].to\"\r\n          [minDate]=\"item.minDate\" [maxDate]=\"item.maxDate\" type=\"date\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-date-range-picker-control>\r\n      </div>\r\n      <ng-template #elseFilterRange>\r\n        <ng-container *ngIf=\"item.type ==='daterange' && externalFilter[item.field]\">\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-date-picker-control [label]=\"item.fromTitle\" [(model)]=\"externalFilter[item.field].from\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate\"\r\n              [maxDate]=\"externalFilter[item.field].to || item.maxDate\" (sdChange)=\"onUpdateFilter()\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-date-picker-control [label]=\"item.toTitle\" [(model)]=\"externalFilter[item.field].to\"\r\n              [type]=\"item.enableTime ? 'datetime' : 'date'\" [minDate]=\"item.minDate || externalFilter[item.field].from\"\r\n              [maxDate]=\"item.maxDate\" (sdChange)=\"onUpdateFilter()\">\r\n            </sd-date-picker-control>\r\n          </div>\r\n        </ng-container>\r\n        <ng-container *ngIf=\"item.type ==='numberrange' && externalFilter[item.field]\">\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-input-control [label]=\"item.fromTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].from\"\r\n              (sdChange)=\"onUpdateFilter()\">\r\n            </sd-input-control>\r\n          </div>\r\n          <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n            <sd-input-control [label]=\"item.toTitle\" type=\" number\" [(model)]=\"externalFilter[item.field].to\"\r\n              (sdChange)=\"onUpdateFilter()\">\r\n            </sd-input-control>\r\n          </div>\r\n        </ng-container>\r\n      </ng-template>\r\n    </ng-container>\r\n  </div>\r\n\r\n  <div *ngIf=\"columns?.length && showColumnInlineFilter\" class=\"row\">\r\n    <ng-container *ngFor=\"let item of columns\">\r\n      <div class=\"col-lg-2 col-md-3 col-sm-6\">\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'string'\" type=\"text\" [(model)]=\"filter[item.field]\"\r\n          (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-input-control [label]=\"item.title\" *ngIf=\"item.type === 'number'\" type=\"number\"\r\n          [(model)]=\"filter[item.field]\" (keyupEnter)=\"onUpdateFilter()\">\r\n        </sd-input-control>\r\n        <sd-select-control [label]=\"item.title\" *ngIf=\"item.type === 'bool'\" [items]=\"[{value:'1',display:item.trueValue || 'True' },\r\n          {value:'0',display:item.falseValue || 'False' }]\" valueField=\"value\" displayField=\"display\"\r\n          [(model)]=\"filter[item.field]\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-select-control>\r\n        <sd-radio-control [label]=\"item.title\" *ngIf=\"item.type === 'radio'\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-radio-control>\r\n        <sd-select-control *ngIf=\"item.type === 'values'\" [label]=\"item.title\" [items]=\"item.values\"\r\n          [valueField]=\"item.valueField\" [displayField]=\"item.displayField\" [(model)]=\"externalFilter[item.field]\"\r\n          (sdChange)=\"onUpdateFilter()\">\r\n        </sd-select-control>\r\n        <sd-date-picker-control [label]=\"item.title\" *ngIf=\"item.type ==='date'\" [(model)]=\"externalFilter[item.field]\"\r\n          type=\"date\" (sdChange)=\"onUpdateFilter()\">\r\n        </sd-date-picker-control>\r\n      </div>\r\n    </ng-container>\r\n  </div>\r\n</ng-container>",
        styles: [""]
    })
], GridDesktopInlineFilterComponent);

let CellDesktopClassNamePipe = class CellDesktopClassNamePipe {
    transform(value, rowData, column, isChildren) {
        const classNames = [];
        if (column.click) {
            classNames.push('cursor-pointer');
        }
        if (isChildren) {
            classNames.push('c-children');
        }
        if (column.badge) {
            const badge = column.badge(rowData, value);
            if (badge) {
                classNames.push('c-badge');
                classNames.push('badge');
                if (badge === 'PRIMARY') {
                    classNames.push('badge-primary');
                }
                else if (badge === 'SECONDARY') {
                    classNames.push('badge-secondary');
                }
                else if (badge === 'WARNING') {
                    classNames.push('badge-warning');
                }
                else if (badge === 'SUCCESS') {
                    classNames.push('badge-success');
                }
                else if (badge === 'DANGER') {
                    classNames.push('badge-danger');
                }
                else if (badge === 'LIGHT') {
                    classNames.push('badge-light');
                }
                else if (badge === 'DARK') {
                    classNames.push('badge-dark');
                }
            }
        }
        return classNames.join(' ');
    }
};
CellDesktopClassNamePipe = __decorate([
    Pipe({
        name: 'cellDesktopClassName'
    })
], CellDesktopClassNamePipe);

let GridDesktopColumnChildrenViewComponent = class GridDesktopColumnChildrenViewComponent {
    constructor() { }
};
__decorate([
    Input()
], GridDesktopColumnChildrenViewComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridDesktopColumnChildrenViewComponent.prototype, "item", void 0);
GridDesktopColumnChildrenViewComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-column-children-view',
        template: "<ng-container *ngIf=\"column.children?.length\">\r\n  <div class=\"row mx-n2 c-cell-padding\">\r\n    <div *ngFor=\"let childColumn of column.children | filterMobile:item\" class=\"px-2\"\r\n      [ngClass]=\"{'col-sm-6': childColumn?.colSpan === 1, 'col-sm-12': !childColumn?.colSpan || childColumn?.colSpan === 2}\">\r\n      <span class=\"c-title\">\r\n        {{item | columnTitle:childColumn.title:childColumn.dynamicTitle | async}}:\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'string'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field]}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field]}}</ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'number'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{(item[childColumn.field]  | valueTransform:item:childColumn) | number : '1.0-2'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{(item[childColumn.field]  | valueTransform:item:childColumn) | number : '1.0-2'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'datetime'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field] | date:'dd/MM/yyyy HH:mm'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'date'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'dd/MM/yyyy'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field] | date:'dd/MM/yyyy'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'time'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\">\r\n        <a *ngIf=\"childColumn.click\" href=\"javascript:;\"\r\n          (click)=\"childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field] | date:'HH:mm'}}</a>\r\n        <ng-container *ngIf=\"!childColumn.click\">\r\n          {{item[childColumn.field] | date:'HH:mm'}}\r\n        </ng-container>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'bool'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n        (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n        <span *ngIf=\"item[childColumn.field]\"\r\n          class=\"status status-success\">{{childColumn.trueValue || 'True'}}</span>\r\n        <span *ngIf=\"!item[childColumn.field]\"\r\n          class=\"status status-danger\">{{childColumn.falseValue || 'False'}}</span>\r\n      </span>\r\n      <span *ngIf=\"childColumn.type === 'color'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n        (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\"><input\r\n          disabled=\"true\" type=\"color\" class=\"form-control c-input-xs\"\r\n          [(ngModel)]=\"item[childColumn.field]\"></span>\r\n      <ng-container *ngIf=\"childColumn.type === 'values'\">\r\n        <ng-container\r\n          *ngIf=\"childColumn?.dictionary[item[childColumn.field]] as dic; else elseNotInDic\">\r\n          <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\"\r\n            class=\"status c-children\"\r\n            [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n            {{dic.text}}\r\n          </span>\r\n          <ng-template #elseNoStatus>\r\n            <span [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n              (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n              {{dic.text}}\r\n            </span>\r\n          </ng-template>\r\n        </ng-container>\r\n        <ng-template #elseNotInDic>\r\n          <span [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n            [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n            (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">\r\n            {{item[childColumn.field]}}\r\n          </span>\r\n        </ng-template>\r\n      </ng-container>\r\n      <span *ngIf=\"childColumn.type === 'radio'\"\r\n        [className]=\"item[childColumn.field] | cellDesktopClassName:item:childColumn:true\"\r\n        [ngClass]=\"{'blinker': item.blinker && item.blinker[childColumn.field]}\"\r\n        (click)=\"childColumn.click && childColumn.click(item[childColumn.field], item)\">{{item[childColumn.field]}}</span>\r\n      <img *ngIf=\"childColumn.type === 'image'\" [src]=\"item[childColumn.field]\"\r\n        [width]=\"childColumn.display?.width\" [height]=\"childColumn.display?.height\"\r\n        style=\"margin: 5px 0\" (click)=\"column.click && column.click(item[column.field], item)\">\r\n    </div>\r\n  </div>\r\n</ng-container>",
        styles: [".c-title{font-size:13px;margin-right:3px;font-weight:700;color:#212529;line-height:1.7}.c-badge{display:block!important;border-radius:10rem;font-weight:500;max-width:80%;margin:0 auto;padding:5px!important;font-size:14px;color:#212529}.c-badge a{color:#fff}.c-children{font-size:14px;overflow-wrap:break-word;color:#212529}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:left!important;text-transform:uppercase}.status-success{color:#4caf50}.status-danger{color:#f44336}.c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.c-clickable{cursor:pointer}.c-img{font-size:50px;opacity:.5}.c-img.c-clickable:hover{opacity:.9}"]
    })
], GridDesktopColumnChildrenViewComponent);

let GridMobileColumnViewComponent = class GridMobileColumnViewComponent {
    constructor() { }
};
__decorate([
    Input()
], GridMobileColumnViewComponent.prototype, "column", void 0);
__decorate([
    Input()
], GridMobileColumnViewComponent.prototype, "item", void 0);
GridMobileColumnViewComponent = __decorate([
    Component({
        selector: 'sd-grid-desktop-mobile-view',
        template: "<!-- <ng-container *ngIf=\"column && item\">\r\n  <div class=\"row c-mobile-row\" (click)=\"check(item)\">\r\n    <div class=\"col-5\">\r\n      <span class=\"c-mobile-title\">\r\n        {{item | columnTitle:column.title:column.dynamicTitle | async}}:\r\n      </span>\r\n    </div>\r\n    <div class=\"col-7\">\r\n      <ng-container *ngIf=\"column.htmlTemplate;else useDefaultView\">\r\n        <span class=\"c-mobile-value\"\r\n          [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\"></span>\r\n      </ng-container>\r\n      <ng-template #useDefaultView>\r\n        <div class=\"row c-mobile-row\" (click)=\"check(item)\">\r\n          <div class=\"col-5\">\r\n            <span class=\"c-mobile-title\">\r\n              {{item | columnTitle:column.title:column.dynamicTitle | async}}:\r\n            </span>\r\n          </div>\r\n          <div class=\"col-7\">\r\n            <ng-container *ngIf=\"column.type === 'string'\">\r\n              <span *ngIf=\"!column.htmlTemplate; else elseUseTemplate\"\r\n                [className]=\"item[column.field] | cellClassName:item:column\"\r\n                [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n                <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                  (click)=\"column.click(item[column.field], item)\">{{item[column.field]}}</a>\r\n                <ng-container *ngIf=\"!column.click\">\r\n                  {{item[column.field]}}</ng-container>\r\n              </span>\r\n              <ng-template #elseUseTemplate>\r\n                <span class=\"c-mobile-value\"\r\n                  [innerHTML]=\"(item[column.field] | columnHtmlTemplate:item:column.htmlTemplate) | safeHtml\"></span>\r\n              </ng-template>\r\n              <ng-container\r\n                *ngIf=\"column.commands | columnCommandFilter:item | async; $implicit as filteredColumnCommands\">\r\n                <button *ngFor=\"let columnCommand of filteredColumnCommands\" (click)=\"columnCommand.click(item)\"\r\n                  type=\"button\" class=\"c-btn-icon\" [matTooltip]=\"columnCommand.title | commandTitle:item\">\r\n                  <i class=\"{{columnCommand.icon | commandIcon:item}}\" aria-hidden=\"true\" style=\"font-size: 14px;\"></i>\r\n                </button>\r\n              </ng-container>\r\n            </ng-container>\r\n            <span *ngIf=\"column.type === 'number'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{(item[column.field] | valueTransform:item:column) | number : '1.0-2'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'datetime'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{item[column.field] | date:'dd/MM/yyyy HH:mm'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'date'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'dd/MM/yyyy'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{item[column.field] | date:'dd/MM/yyyy'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'time'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\">\r\n              <a *ngIf=\"column.click\" href=\"javascript:;\"\r\n                (click)=\"column.click(item[column.field], item)\">{{item[column.field] | date:'HH:mm'}}</a>\r\n              <ng-container *ngIf=\"!column.click\">\r\n                {{item[column.field] | date:'HH:mm'}}</ng-container>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'bool'\" [className]=\"item[column.field] | cellClassName:item:column\"\r\n              [ngClass]=\"{'blinker': item.blinker && item.blinker[column.field]}\"\r\n              (click)=\"column.click && column.click(item[column.field], item)\">\r\n              <span *ngIf=\"item[column.field]\" class=\"status status-success\">{{column.trueValue || 'True'}}</span>\r\n              <span *ngIf=\"!item[column.field]\" class=\"status status-danger\">{{column.falseValue || 'False'}}</span>\r\n            </span>\r\n            <span *ngIf=\"column.type === 'color'\" class=\"c-mobile-value\"><input disabled=\"true\" type=\"color\"\r\n                class=\"form-control c-input-xs\" [(ngModel)]=\"item[column.field]\"></span>\r\n            <ng-container *ngIf=\"column.type === 'values'\">\r\n              <ng-container *ngIf=\"column?.dictionary[item[column.field]] as dic; else elseNotInDic\">\r\n                <span *ngIf=\"dic.color || dic.backgroundColor; else elseNoStatus\" class=\"status c-mobile-value\"\r\n                  [ngStyle]=\"{'color':dic.color, 'background-color': dic.backgroundColor}\">\r\n                  {{dic.text}}\r\n                </span>\r\n                <ng-template #elseNoStatus>\r\n                  <span class=\"c-mobile-value\">\r\n                    {{dic.text}}\r\n                  </span>\r\n                </ng-template>\r\n              </ng-container>\r\n              <ng-template #elseNotInDic>\r\n                <span class=\"c-mobile-value\">\r\n                  {{item[column.field]}}\r\n                </span>\r\n              </ng-template>\r\n            </ng-container>\r\n            <span *ngIf=\"column.type === 'radio'\" class=\"c-mobile-value\">{{item[column.field]}}</span>\r\n            <img *ngIf=\"column.type === 'image'\" [src]=\"item[column.field]\" [width]=\"column.display?.width\"\r\n              [height]=\"column.display?.height\" style=\"margin: 5px 0\"\r\n              (click)=\"column.click && column.click(item[column.field], item)\">\r\n          </div>\r\n        </div>\r\n      </ng-template>\r\n    </div>\r\n  </div>\r\n</ng-container> -->",
        styles: [".c-badge{display:block!important;border-radius:10rem;padding:.3rem!important;font-weight:500;font-size:12px;max-width:80%;margin:0 auto}.c-badge a{color:#fff}.status{font-weight:500;padding:4px 8px;border-radius:1.5rem;display:inline-block;text-align:center;text-transform:uppercase;width:100%}.status-success{color:#4caf50}.status-danger{color:#f44336}.c-btn-icon{background:0 0!important;border:none;opacity:.8;height:20px;display:inline-flex;padding:0 3px}.c-btn-icon:hover{cursor:pointer;opacity:1}.c-btn-icon:disabled{background:0 0!important;border:none;cursor:not-allowed;opacity:.3}.c-clickable{cursor:pointer}.c-img{font-size:50px;opacity:.5}.c-img.c-clickable:hover{opacity:.9}"]
    })
], GridMobileColumnViewComponent);

// Document: http://www.daterangepicker.com/
let DateRangePickerControlComponent = class DateRangePickerControlComponent {
    constructor(ref, deviceService, translateService) {
        this.ref = ref;
        this.translateService = translateService;
        this.isMobileOrTablet = false;
        this.initialized = false;
        this.pMinDate = null;
        this.pMaxDate = null;
        this.name = v4();
        this.model = '';
        this.type = 'datetime';
        this.disabled = false;
        this.required = false;
        this.sdChange = new EventEmitter();
        this.fromDateChange = new EventEmitter();
        this.toDateChange = new EventEmitter();
        this.onFocus = () => {
            $$1(this.control.nativeElement).trigger('blur');
        };
        this.onChanges = () => {
        };
        this.clear = () => {
            // ($(this.control.nativeElement) as any).val('');
            this.model = '';
            const fromDate = null;
            const toDate = null;
            this.pFromDate = fromDate;
            this.pToDate = toDate;
            this.fromDateChange.emit(this.pFromDate);
            this.toDateChange.emit(this.pToDate);
            this.sdChange.emit({ fromDate, toDate });
            this.ref.detectChanges();
        };
        this.reload = (startDate, endDate) => {
            this.model = startDate + ' - ' + endDate;
            // ($(this.control.nativeElement) as any).val(startDate + ' - ' + endDate);
            this.ref.detectChanges();
        };
        this.isMobileOrTablet = !deviceService.isDesktop();
    }
    get format() {
        let format = 'DD/MM/YYYY';
        if (this.type === 'datetime') {
            format = 'DD/MM/YYYY hh:mm';
        }
        else if (this.type === 'time') {
            format = 'hh:mm';
        }
        return format;
    }
    set minDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        this.pMinDate = val;
        if (this.initialized) {
            this.setOption();
        }
    }
    set maxDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        this.pMaxDate = val;
        if (this.initialized) {
            this.setOption();
        }
    }
    set fromDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        else {
            val = Date.toFormat(val, 'MM/dd/yyyy HH:mm');
        }
        if (this.initialized) {
            if (this.pFromDate !== val) {
                if (val) {
                    $$1(this.control.nativeElement)
                        .data('daterangepicker').setStartDate(moment(val, 'MM/DD/YYYY hh:mm').format(this.format));
                    this.reload(val, this.pToDate);
                }
            }
        }
        this.pFromDate = val;
        this.ref.detectChanges();
    }
    set toDate(val) {
        if (!Date.isDate(val)) {
            val = null;
        }
        else {
            val = Date.toFormat(val, 'MM/dd/yyyy HH:mm');
        }
        if (this.initialized) {
            if (this.pToDate !== val) {
                if (val) {
                    $$1(this.control.nativeElement)
                        .data('daterangepicker').setEndDate(moment(val, 'MM/DD/YYYY hh:mm').format(this.format));
                    this.reload(this.pFromDate, val);
                }
            }
        }
        this.pToDate = val;
        this.ref.detectChanges();
    }
    ngOnDestroy() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.removeControl(this.formModel);
    }
    ngAfterViewInit() {
        var _a;
        (_a = this.form) === null || _a === void 0 ? void 0 : _a.addControl(this.formModel);
        this.onChanges();
        this.initialized = true;
        this.setOption();
        this.ref.detectChanges();
    }
    setOption() {
        if (this.initialized) {
            $$1(this.control.nativeElement).daterangepicker({
                autoUpdateInput: false,
                timePicker: this.type === 'datetime' || this.type === 'time',
                timePicker24Hour: true,
                locale: {
                    // format: this.format,
                    // separator: ' - ',
                    applyLabel: this.translateService.translate('Apply'),
                    cancelLabel: this.translateService.translate('Clear'),
                    fromLabel: this.translateService.translate('From'),
                    toLabel: this.translateService.translate('To'),
                    customRangeLabel: this.translateService.translate('Custom'),
                    weekLabel: 'W',
                    daysOfWeek: [
                        this.translateService.translate('Su'),
                        this.translateService.translate('Mo'),
                        this.translateService.translate('Tu'),
                        this.translateService.translate('We'),
                        this.translateService.translate('Th'),
                        this.translateService.translate('Fr'),
                        this.translateService.translate('Sa')
                    ],
                    monthNames: [
                        this.translateService.translate('January'),
                        this.translateService.translate('February'),
                        this.translateService.translate('March'),
                        this.translateService.translate('April'),
                        this.translateService.translate('May'),
                        this.translateService.translate('June'),
                        this.translateService.translate('July'),
                        this.translateService.translate('August'),
                        this.translateService.translate('September'),
                        this.translateService.translate('October'),
                        this.translateService.translate('November'),
                        this.translateService.translate('December')
                    ],
                    firstDay: 1
                },
                startDate: Date.isDate(this.pFromDate) ? moment(this.pFromDate).format(this.format) : undefined,
                endDate: Date.isDate(this.pToDate) ? moment(this.pToDate).format(this.format) : undefined,
                minDate: Date.isDate(this.pMinDate) ? moment(this.pMinDate).format(this.format) : undefined,
                maxDate: Date.isDate(this.pMaxDate) ? moment(this.pMaxDate).format(this.format) : undefined,
            }, (fDate, tDate, label) => {
                const fromDate = fDate.format('MM/DD/YYYY HH:mm');
                const toDate = tDate.format('MM/DD/YYYY HH:mm');
                this.pFromDate = fromDate;
                this.pToDate = toDate;
                this.fromDateChange.emit(this.pFromDate);
                this.toDateChange.emit(this.pToDate);
                this.sdChange.emit({ fromDate, toDate });
                this.ref.detectChanges();
            });
            $$1(this.control.nativeElement).on('apply.daterangepicker', (ev, picker) => {
                if (picker.startDate && picker.endDate) {
                    const startDate = picker.startDate.format(this.format);
                    const endDate = picker.endDate.format(this.format);
                    this.reload(startDate, endDate);
                }
            });
            $$1(this.control.nativeElement).on('cancel.daterangepicker', this.clear);
        }
    }
};
DateRangePickerControlComponent.ctorParameters = () => [
    { type: ChangeDetectorRef },
    { type: DeviceDetectorService },
    { type: TranslateService }
];
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "form", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "type", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "disabled", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "required", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "label", void 0);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "minDate", null);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "maxDate", null);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "fromDate", null);
__decorate([
    Input()
], DateRangePickerControlComponent.prototype, "toDate", null);
__decorate([
    Output()
], DateRangePickerControlComponent.prototype, "sdChange", void 0);
__decorate([
    Output()
], DateRangePickerControlComponent.prototype, "fromDateChange", void 0);
__decorate([
    Output()
], DateRangePickerControlComponent.prototype, "toDateChange", void 0);
__decorate([
    ViewChild('control')
], DateRangePickerControlComponent.prototype, "control", void 0);
__decorate([
    ViewChild('formModel')
], DateRangePickerControlComponent.prototype, "formModel", void 0);
DateRangePickerControlComponent = __decorate([
    Component({
        selector: 'sd-date-range-picker-control',
        template: "<mat-form-field class=\"sd-form\" appearance=\"outline\">\r\n  <mat-label *ngIf=\"label\">{{label}}</mat-label>\r\n  <input #formModel=\"ngModel\" [ngModel]=\"model\" class=\"sd-input\" [name]=\"name\" autocomplete=\"false\" #control matInput\r\n    placeholder=\"{{label}}\" (focus)=\"onFocus()\" [required]=\"required\" [disabled]=\"disabled\" autocomplete=\"off\">\r\n  <mat-icon *ngIf=\"type !== 'time'\" matSuffix>date_range</mat-icon>\r\n  <mat-icon *ngIf=\"type === 'time'\" matSuffix>schedule</mat-icon>\r\n</mat-form-field>",
        encapsulation: ViewEncapsulation.None,
        styles: [".sd-form{width:100%;font-size:12px}.sd-form.sd-form-with-information{width:calc(100% - 30px)}.sd-form .sd-input,.sd-form .sd-select{font-size:14px}.sd-form .sd-input::-webkit-input-placeholder,.sd-form .sd-select::-webkit-input-placeholder{font-size:12px!important}.sd-form .sd-input::-moz-placeholder,.sd-form .sd-select::-moz-placeholder{font-size:12px!important}.sd-form .sd-input::-ms-input-placeholder,.sd-form .sd-select::-ms-input-placeholder{font-size:12px!important}.sd-form .sd-input::placeholder,.sd-form .sd-select::placeholder{font-size:12px!important}@media (max-width:768px){.sd-form{font-size:10px}}.sd-form.sd-form-sm{font-size:10px}.sd-form.sd-form-xs{font-size:8px}.sd-form.mat-form-field-appearance-outline .mat-form-field-infix{padding:.7em 0}.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-outline.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{color:#333}.sd-form .mat-form-field-required-marker{color:#ff4081}.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float .mat-input-server:focus+.mat-form-field-label-wrapper .mat-form-field-label,.sd-form.mat-form-field-appearance-legacy.mat-form-field-can-float.mat-form-field-should-float .mat-form-field-label{transform:translateY(-1.28125em) scale(.9);color:#333}.sd-information{display:inline-block;text-align:center;margin:auto;width:30px}sd-grid-control .mat-form-field-wrapper{padding-bottom:0}.cdk-overlay-container .mat-option{font-size:12px}.swal2-popup .swal2-content .swal2-html-container{line-height:1.7;color:#7c7c7e}.xdsoft_datetimepicker .xdsoft_calendar td.xdsoft_other_month{opacity:1;cursor:pointer}"]
    })
], DateRangePickerControlComponent);

let BottomSheetComponent = class BottomSheetComponent {
    constructor(bottomSheet) {
        this.bottomSheet = bottomSheet;
        this.isOpened = false;
        this.open = () => {
            this.isOpened = true;
            this.bottomSheet.open(this.templateRef);
        };
        this.close = () => {
            this.bottomSheet.dismiss();
        };
    }
};
BottomSheetComponent.ctorParameters = () => [
    { type: MatBottomSheet }
];
__decorate([
    ViewChild('templateRef')
], BottomSheetComponent.prototype, "templateRef", void 0);
__decorate([
    Input()
], BottomSheetComponent.prototype, "title", void 0);
BottomSheetComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet',
        template: "<ng-template #templateRef>\r\n  <ng-container *ngIf=\"isOpened\">\r\n    <sd-bottom-sheet-header *ngIf=\"title\">{{title}}</sd-bottom-sheet-header>\r\n    <ng-content></ng-content>\r\n  </ng-container>\r\n</ng-template>"
    })
], BottomSheetComponent);

let BottomSheetBodyComponent = class BottomSheetBodyComponent {
    constructor() {
        this.height = 'auto';
    }
    ngOnInit() {
    }
};
__decorate([
    Input()
], BottomSheetBodyComponent.prototype, "height", void 0);
BottomSheetBodyComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet-body',
        template: "<div class=\"c-body\" [ngStyle]=\"{'height': height}\">\r\n  <ng-content></ng-content>\r\n<div>",
        styles: ["::-webkit-scrollbar{width:7px;height:7px}::-webkit-scrollbar-track{background:#f1f1f1}::-webkit-scrollbar-thumb{background:#888;border-radius:50px}::-webkit-scrollbar-thumb:hover{background:#555}", ".c-body{display:block;margin:0 -16px;padding:0 16px;max-height:65vh;overflow:auto}"]
    })
], BottomSheetBodyComponent);

let BottomSheetFooterComponent = class BottomSheetFooterComponent {
    constructor() { }
    ngOnInit() {
    }
};
BottomSheetFooterComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet-footer',
        template: "<!-- <div class=\"modal-footer\" style=\"padding:5px\"><ng-content></ng-content></div> -->\r\n<div class=\"c-footer\">\r\n  <ng-content></ng-content>\r\n</div>",
        styles: [".c-footer{padding-top:5px;flex:auto;display:flex}"]
    })
], BottomSheetFooterComponent);

let BottomSheetHeaderComponent = class BottomSheetHeaderComponent {
    constructor() { }
    ngOnInit() {
    }
};
BottomSheetHeaderComponent = __decorate([
    Component({
        selector: 'sd-bottom-sheet-header',
        template: "<h3 mat-dialog-title><ng-content></ng-content></h3>"
    })
], BottomSheetHeaderComponent);

let ButtonComponent = class ButtonComponent {
    constructor(ref) {
        this.ref = ref;
        this.pDisabled = false;
        this.initialized = false;
        this.isDisabled = false;
        this.color = undefined;
        this.loading = false;
        this.action = new EventEmitter();
        this.onClick = ($event) => {
            if (this.loading) {
                return;
            }
            this.action.emit($event);
        };
    }
    set disabled(value) {
        this.pDisabled = value || false;
        if (this.initialized) {
            this.onChanges();
        }
    }
    ngOnInit() {
    }
    ngAfterViewInit() {
        this.initialized = true;
        this.onChanges();
    }
    onChanges() {
        this.isDisabled = this.pDisabled;
        this.ref.detectChanges();
    }
};
ButtonComponent.ctorParameters = () => [
    { type: ChangeDetectorRef }
];
__decorate([
    Input()
], ButtonComponent.prototype, "color", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "title", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "icon", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "width", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "size", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "tooltip", void 0);
__decorate([
    Input()
], ButtonComponent.prototype, "disabled", null);
__decorate([
    Input()
], ButtonComponent.prototype, "loading", void 0);
__decorate([
    Output()
], ButtonComponent.prototype, "action", void 0);
ButtonComponent = __decorate([
    Component({
        selector: 'sd-button',
        template: "<button *ngIf=\"title\" [ngStyle]=\"{'width':width}\" [ngClass]=\"{'c-sm':size === 'sm'}\" type=\"button\" class=\"c-button\"\r\n  (click)=\"onClick($event)\" [color]=\"color\" [disabled]=\"isDisabled\" matTooltipPosition=\"above\"\r\n  [matTooltip]=\"tooltip\" mat-raised-button>\r\n  <mat-icon>{{icon}}</mat-icon>\r\n  {{title}}\r\n</button>\r\n<button *ngIf=\"!title\" [ngStyle]=\"{'width':width}\" [ngClass]=\"{'c-sm':size === 'sm'}\" type=\"button\" class=\"c-button\"\r\n  (click)=\"onClick($event)\" [color]=\"color\" [disabled]=\"isDisabled\" matTooltipPosition=\"above\"\r\n  [matTooltip]=\"tooltip\" mat-icon-button>\r\n  <mat-icon>{{icon}}</mat-icon>\r\n</button>",
        styles: ["button.c-button.c-sm{font-size:12px;line-height:24px;padding:2px 8px}button.c-button:focus{outline:0}"]
    })
], ButtonComponent);

let DesktopDirective = class DesktopDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isDesktop()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
DesktopDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
DesktopDirective = __decorate([
    Directive({
        selector: '[sdDesktop]'
    })
], DesktopDirective);

let MobileDirective = class MobileDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isMobile()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
MobileDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
MobileDirective = __decorate([
    Directive({
        selector: '[sdMobile]'
    })
], MobileDirective);

let TabletDirective = class TabletDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isTablet()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
TabletDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
TabletDirective = __decorate([
    Directive({
        selector: '[sdTablet]'
    })
], TabletDirective);

let MobileTabletDirective = class MobileTabletDirective {
    constructor(templateRef, viewContainerRef, deviceService) {
        this.templateRef = templateRef;
        this.viewContainerRef = viewContainerRef;
        if (deviceService.isMobile() || deviceService.isTablet()) {
            this.viewContainerRef.createEmbeddedView(this.templateRef);
        }
    }
};
MobileTabletDirective.ctorParameters = () => [
    { type: TemplateRef },
    { type: ViewContainerRef },
    { type: DeviceDetectorService }
];
MobileTabletDirective = __decorate([
    Directive({
        selector: '[sdMobileTablet]'
    })
], MobileTabletDirective);

var SuperdevAngularCoreModule_1;
let SuperdevAngularCoreModule = SuperdevAngularCoreModule_1 = class SuperdevAngularCoreModule {
    static forRoot() {
        return {
            ngModule: SuperdevAngularCoreModule_1,
            providers: [
                DatePipe,
                HandlerLocal,
                HandlerDotnet,
                ApiService,
                ConfigurationService,
                NotifyService,
                UtilityService,
                EditorHandlerPipe,
                TranslateService,
                CacheService,
                ExcelService,
                LoadingService,
                SettingService
            ]
        };
    }
    static forChild() {
        return {
            ngModule: SuperdevAngularCoreModule_1,
            providers: []
        };
    }
};
SuperdevAngularCoreModule = SuperdevAngularCoreModule_1 = __decorate([
    NgModule({
        imports: [
            CommonModule,
            FormsModule,
            ReactiveFormsModule,
            HttpClientModule,
            MaterialModule,
            CKEditorModule,
            DeviceDetectorModule.forRoot()
        ],
        declarations: [
            GridControlComponent,
            GridConfigComponent,
            GridPopupExportExcelComponent,
            GridImportExcelComponent,
            GridPopupEditorComponent,
            GridSubInformationComponent,
            GridDesktopColumnViewComponent,
            GridDesktopColumnEditComponent,
            GridDesktopColumnChildrenViewComponent,
            GridDesktopInlineFilterComponent,
            GridMobileColumnViewComponent,
            UploadExcelConfigComponent,
            UploadExcelControlComponent,
            InputControlComponent,
            SelectControlComponent,
            ModalControl,
            DatePickerControlComponent,
            DateRangePickerControlComponent,
            ModalHeaderComponent,
            ModalBodyComponent,
            ModalFooterComponent,
            TextareaControlComponent,
            AutocompleteControlComponent,
            GridDatePickerControlComponent,
            GridAutocompleteControl,
            GridPopupFilterComponent,
            DesktopDirective,
            MobileDirective,
            TabletDirective,
            MobileTabletDirective,
            CheckboxControlComponent,
            SwitchControlComponent,
            RadioControlComponent,
            CkeditorControlComponent,
            ChartControlComponent,
            ChipControlComponent,
            UploadFileControlComponent,
            BottomSheetComponent,
            BottomSheetBodyComponent,
            BottomSheetFooterComponent,
            BottomSheetHeaderComponent,
            ButtonComponent,
            // Login Form
            Login01Component,
            // Pipes
            TranslatePipe,
            EditorHandlerPipe,
            EditorValidatePipe,
            EditorDynamicItemPipe,
            FilterMobilePipe,
            MobileCommandFilterPipe,
            ColumnHtmlTemplatePipe,
            ColumnTitlePipe,
            CommandIconPipe,
            CommandTitlePipe,
            CommandDisabledPipe,
            CommandHiddenByItemPipe,
            ColumnCommandFilterPipe,
            CellClassNamePipe,
            CellDesktopClassNamePipe,
            InputTooltipPipe,
            ValueTransformPipe,
            EditorSubInformationHandlerPipe,
            SafeHtmlPipe,
            // Validators
            SdMinDateValidator,
            SdMaxDateValidator,
            SdCustomValidator,
            SdChipMinItemValidator
        ],
        exports: [
            MaterialModule,
            // Controls
            InputControlComponent,
            SelectControlComponent,
            DatePickerControlComponent,
            DateRangePickerControlComponent,
            GridControlComponent,
            UploadExcelControlComponent,
            TextareaControlComponent,
            AutocompleteControlComponent,
            ModalControl,
            ModalHeaderComponent,
            ModalBodyComponent,
            ModalFooterComponent,
            CheckboxControlComponent,
            SwitchControlComponent,
            RadioControlComponent,
            CkeditorControlComponent,
            ChartControlComponent,
            ChipControlComponent,
            UploadFileControlComponent,
            BottomSheetComponent,
            BottomSheetBodyComponent,
            BottomSheetFooterComponent,
            BottomSheetHeaderComponent,
            ButtonComponent,
            // Directives
            DesktopDirective,
            MobileDirective,
            TabletDirective,
            MobileTabletDirective,
            // Pipes
            TranslatePipe,
            // Components
            Login01Component
        ]
    })
], SuperdevAngularCoreModule);

/*
 * Public API Surface of superdev-angular-core
 */

/**
 * Generated bundle index. Do not edit.
 */

export { ApiService, AutocompleteControlComponent, BottomSheetBodyComponent, BottomSheetComponent, BottomSheetFooterComponent, BottomSheetHeaderComponent, ButtonComponent, CacheService, ChartControlComponent, CheckboxControlComponent, CkeditorControlComponent, ConfigurationService, DatePickerControlComponent, DateRangePickerControlComponent, DesktopDirective, ExcelService, GridControlComponent, HandlerDotnet, HandlerLocal, InputControlComponent, LoadingService, MobileDirective, MobileTabletDirective, ModalBodyComponent, ModalControl, ModalFooterComponent, ModalHeaderComponent, NotifyService, RadioControlComponent, SelectControlComponent, SettingService, SuperdevAngularCoreModule, SwitchControlComponent, TabletDirective, TextareaControlComponent, TranslatePipe, TranslateService, UploadExcelControlComponent, UploadFileControlComponent, UtilityService, defaultGridOption, MaterialModule as ɵa, GridControlComponent as ɵb, SelectControlComponent as ɵba, ModalControl as ɵbb, DatePickerControlComponent as ɵbc, DateRangePickerControlComponent as ɵbd, ModalHeaderComponent as ɵbe, ModalBodyComponent as ɵbf, ModalFooterComponent as ɵbg, TextareaControlComponent as ɵbh, AutocompleteControlComponent as ɵbi, GridDatePickerControlComponent as ɵbj, GridAutocompleteControl as ɵbk, GridPopupFilterComponent as ɵbl, DesktopDirective as ɵbm, MobileDirective as ɵbn, TabletDirective as ɵbo, MobileTabletDirective as ɵbp, CheckboxControlComponent as ɵbq, SwitchControlComponent as ɵbr, RadioControlComponent as ɵbs, CkeditorControlComponent as ɵbt, ChartControlComponent as ɵbu, ChipControlComponent as ɵbv, UploadFileControlComponent as ɵbw, BottomSheetComponent as ɵbx, BottomSheetBodyComponent as ɵby, BottomSheetFooterComponent as ɵbz, GridImportExcelComponent as ɵc, BottomSheetHeaderComponent as ɵca, ButtonComponent as ɵcb, Login01Component as ɵcc, TranslatePipe as ɵcd, EditorValidatePipe as ɵce, EditorDynamicItemPipe as ɵcf, FilterMobilePipe as ɵcg, MobileCommandFilterPipe as ɵch, ColumnHtmlTemplatePipe as ɵci, ColumnTitlePipe as ɵcj, CommandIconPipe as ɵck, CommandTitlePipe as ɵcl, CommandDisabledPipe as ɵcm, CommandHiddenByItemPipe as ɵcn, ColumnCommandFilterPipe as ɵco, CellClassNamePipe as ɵcp, CellDesktopClassNamePipe as ɵcq, InputTooltipPipe as ɵcr, ValueTransformPipe as ɵcs, EditorSubInformationHandlerPipe as ɵct, SafeHtmlPipe as ɵcu, SdMinDateValidator as ɵcv, SdMaxDateValidator as ɵcw, SdCustomValidator as ɵcx, SdChipMinItemValidator as ɵcy, CacheService as ɵcz, GridPopupExportExcelComponent as ɵd, LoadingService as ɵe, ExcelService as ɵf, ConfigurationService as ɵg, NotifyService as ɵh, TranslateService as ɵi, HandlerLocal as ɵj, HandlerDotnet as ɵk, UtilityService as ɵl, ApiService as ɵm, EditorHandlerPipe as ɵn, GridConfigComponent as ɵo, SettingService as ɵp, GridPopupEditorComponent as ɵq, GridSubInformationComponent as ɵr, GridDesktopColumnViewComponent as ɵs, GridDesktopColumnEditComponent as ɵt, GridDesktopColumnChildrenViewComponent as ɵu, GridDesktopInlineFilterComponent as ɵv, GridMobileColumnViewComponent as ɵw, UploadExcelConfigComponent as ɵx, UploadExcelControlComponent as ɵy, InputControlComponent as ɵz };
//# sourceMappingURL=superdev-angular-core.js.map
